<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'kyss: voksen, voksen, hudtype 1–2, hudtype 3',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'kyss: voksen, voksen, hudtype 1–2, hudtype 4',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'kyss: voksen, voksen, hudtype 1–2, hudtype 5',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'kyss: voksen, voksen, hudtype 1–2, hudtype 6',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'kyss: voksen, voksen, hudtype 3, hudtype 1–2',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'kyss: voksen, voksen, hudtype 3, hudtype 4',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'kyss: voksen, voksen, hudtype 3, hudtype 5',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'kyss: voksen, voksen, hudtype 3, hudtype 6',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'kyss: voksen, voksen, hudtype 4, hudtype 1–2',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'kyss: voksen, voksen, hudtype 4, hudtype 3',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'kyss: voksen, voksen, hudtype 4, hudtype 5',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'kyss: voksen, voksen, hudtype 4, hudtype 6',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'kyss: voksen, voksen, hudtype 5, hudtype 1–2',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'kyss: voksen, voksen, hudtype 5, hudtype 3',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'kyss: voksen, voksen, hudtype 5, hudtype 4',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'kyss: voksen, voksen, hudtype 5, hudtype 6',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'kyss: voksen, voksen, hudtype 6, hudtype 1–2',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'kyss: voksen, voksen, hudtype 6, hudtype 3',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'kyss: voksen, voksen, hudtype 6, hudtype 4',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'kyss: voksen, voksen, hudtype 6, hudtype 5',
    '👨🏻‍❤‍💋‍👨🏻' => 'kyss: mann, mann, hudtype 1–2',
    '👨🏻‍❤‍💋‍👨🏼' => 'kyss: mann, mann, hudtype 1–2, hudtype 3',
    '👨🏻‍❤‍💋‍👨🏽' => 'kyss: mann, mann, hudtype 1–2, hudtype 4',
    '👨🏻‍❤‍💋‍👨🏾' => 'kyss: mann, mann, hudtype 1–2, hudtype 5',
    '👨🏻‍❤‍💋‍👨🏿' => 'kyss: mann, mann, hudtype 1–2, hudtype 6',
    '👨🏼‍❤‍💋‍👨🏻' => 'kyss: mann, mann, hudtype 3, hudtype 1–2',
    '👨🏼‍❤‍💋‍👨🏼' => 'kyss: mann, mann, hudtype 3',
    '👨🏼‍❤‍💋‍👨🏽' => 'kyss: mann, mann, hudtype 3, hudtype 4',
    '👨🏼‍❤‍💋‍👨🏾' => 'kyss: mann, mann, hudtype 3, hudtype 5',
    '👨🏼‍❤‍💋‍👨🏿' => 'kyss: mann, mann, hudtype 3, hudtype 6',
    '👨🏽‍❤‍💋‍👨🏻' => 'kyss: mann, mann, hudtype 4, hudtype 1–2',
    '👨🏽‍❤‍💋‍👨🏼' => 'kyss: mann, mann, hudtype 4, hudtype 3',
    '👨🏽‍❤‍💋‍👨🏽' => 'kyss: mann, mann, hudtype 4',
    '👨🏽‍❤‍💋‍👨🏾' => 'kyss: mann, mann, hudtype 4, hudtype 5',
    '👨🏽‍❤‍💋‍👨🏿' => 'kyss: mann, mann, hudtype 4, hudtype 6',
    '👨🏾‍❤‍💋‍👨🏻' => 'kyss: mann, mann, hudtype 5, hudtype 1–2',
    '👨🏾‍❤‍💋‍👨🏼' => 'kyss: mann, mann, hudtype 5, hudtype 3',
    '👨🏾‍❤‍💋‍👨🏽' => 'kyss: mann, mann, hudtype 5, hudtype 4',
    '👨🏾‍❤‍💋‍👨🏾' => 'kyss: mann, mann, hudtype 5',
    '👨🏾‍❤‍💋‍👨🏿' => 'kyss: mann, mann, hudtype 5, hudtype 6',
    '👨🏿‍❤‍💋‍👨🏻' => 'kyss: mann, mann, hudtype 6, hudtype 1–2',
    '👨🏿‍❤‍💋‍👨🏼' => 'kyss: mann, mann, hudtype 6, hudtype 3',
    '👨🏿‍❤‍💋‍👨🏽' => 'kyss: mann, mann, hudtype 6, hudtype 4',
    '👨🏿‍❤‍💋‍👨🏾' => 'kyss: mann, mann, hudtype 6, hudtype 5',
    '👨🏿‍❤‍💋‍👨🏿' => 'kyss: mann, mann, hudtype 6',
    '👩🏻‍❤‍💋‍👨🏻' => 'kyss: kvinne, mann, hudtype 1–2',
    '👩🏻‍❤‍💋‍👨🏼' => 'kyss: kvinne, mann, hudtype 1–2, hudtype 3',
    '👩🏻‍❤‍💋‍👨🏽' => 'kyss: kvinne, mann, hudtype 1–2, hudtype 4',
    '👩🏻‍❤‍💋‍👨🏾' => 'kyss: kvinne, mann, hudtype 1–2, hudtype 5',
    '👩🏻‍❤‍💋‍👨🏿' => 'kyss: kvinne, mann, hudtype 1–2, hudtype 6',
    '👩🏼‍❤‍💋‍👨🏻' => 'kyss: kvinne, mann, hudtype 3, hudtype 1–2',
    '👩🏼‍❤‍💋‍👨🏼' => 'kyss: kvinne, mann, hudtype 3',
    '👩🏼‍❤‍💋‍👨🏽' => 'kyss: kvinne, mann, hudtype 3, hudtype 4',
    '👩🏼‍❤‍💋‍👨🏾' => 'kyss: kvinne, mann, hudtype 3, hudtype 5',
    '👩🏼‍❤‍💋‍👨🏿' => 'kyss: kvinne, mann, hudtype 3, hudtype 6',
    '👩🏽‍❤‍💋‍👨🏻' => 'kyss: kvinne, mann, hudtype 4, hudtype 1–2',
    '👩🏽‍❤‍💋‍👨🏼' => 'kyss: kvinne, mann, hudtype 4, hudtype 3',
    '👩🏽‍❤‍💋‍👨🏽' => 'kyss: kvinne, mann, hudtype 4',
    '👩🏽‍❤‍💋‍👨🏾' => 'kyss: kvinne, mann, hudtype 4, hudtype 5',
    '👩🏽‍❤‍💋‍👨🏿' => 'kyss: kvinne, mann, hudtype 4, hudtype 6',
    '👩🏾‍❤‍💋‍👨🏻' => 'kyss: kvinne, mann, hudtype 5, hudtype 1–2',
    '👩🏾‍❤‍💋‍👨🏼' => 'kyss: kvinne, mann, hudtype 5, hudtype 3',
    '👩🏾‍❤‍💋‍👨🏽' => 'kyss: kvinne, mann, hudtype 5, hudtype 4',
    '👩🏾‍❤‍💋‍👨🏾' => 'kyss: kvinne, mann, hudtype 5',
    '👩🏾‍❤‍💋‍👨🏿' => 'kyss: kvinne, mann, hudtype 5, hudtype 6',
    '👩🏿‍❤‍💋‍👨🏻' => 'kyss: kvinne, mann, hudtype 6, hudtype 1–2',
    '👩🏿‍❤‍💋‍👨🏼' => 'kyss: kvinne, mann, hudtype 6, hudtype 3',
    '👩🏿‍❤‍💋‍👨🏽' => 'kyss: kvinne, mann, hudtype 6, hudtype 4',
    '👩🏿‍❤‍💋‍👨🏾' => 'kyss: kvinne, mann, hudtype 6, hudtype 5',
    '👩🏿‍❤‍💋‍👨🏿' => 'kyss: kvinne, mann, hudtype 6',
    '👩🏻‍❤‍💋‍👩🏻' => 'kyss: kvinne, kvinne, hudtype 1–2',
    '👩🏻‍❤‍💋‍👩🏼' => 'kyss: kvinne, kvinne, hudtype 1–2, hudtype 3',
    '👩🏻‍❤‍💋‍👩🏽' => 'kyss: kvinne, kvinne, hudtype 1–2, hudtype 4',
    '👩🏻‍❤‍💋‍👩🏾' => 'kyss: kvinne, kvinne, hudtype 1–2, hudtype 5',
    '👩🏻‍❤‍💋‍👩🏿' => 'kyss: kvinne, kvinne, hudtype 1–2, hudtype 6',
    '👩🏼‍❤‍💋‍👩🏻' => 'kyss: kvinne, kvinne, hudtype 3, hudtype 1–2',
    '👩🏼‍❤‍💋‍👩🏼' => 'kyss: kvinne, kvinne, hudtype 3',
    '👩🏼‍❤‍💋‍👩🏽' => 'kyss: kvinne, kvinne, hudtype 3, hudtype 4',
    '👩🏼‍❤‍💋‍👩🏾' => 'kyss: kvinne, kvinne, hudtype 3, hudtype 5',
    '👩🏼‍❤‍💋‍👩🏿' => 'kyss: kvinne, kvinne, hudtype 3, hudtype 6',
    '👩🏽‍❤‍💋‍👩🏻' => 'kyss: kvinne, kvinne, hudtype 4, hudtype 1–2',
    '👩🏽‍❤‍💋‍👩🏼' => 'kyss: kvinne, kvinne, hudtype 4, hudtype 3',
    '👩🏽‍❤‍💋‍👩🏽' => 'kyss: kvinne, kvinne, hudtype 4',
    '👩🏽‍❤‍💋‍👩🏾' => 'kyss: kvinne, kvinne, hudtype 4, hudtype 5',
    '👩🏽‍❤‍💋‍👩🏿' => 'kyss: kvinne, kvinne, hudtype 4, hudtype 6',
    '👩🏾‍❤‍💋‍👩🏻' => 'kyss: kvinne, kvinne, hudtype 5, hudtype 1–2',
    '👩🏾‍❤‍💋‍👩🏼' => 'kyss: kvinne, kvinne, hudtype 5, hudtype 3',
    '👩🏾‍❤‍💋‍👩🏽' => 'kyss: kvinne, kvinne, hudtype 5, hudtype 4',
    '👩🏾‍❤‍💋‍👩🏾' => 'kyss: kvinne, kvinne, hudtype 5',
    '👩🏾‍❤‍💋‍👩🏿' => 'kyss: kvinne, kvinne, hudtype 5, hudtype 6',
    '👩🏿‍❤‍💋‍👩🏻' => 'kyss: kvinne, kvinne, hudtype 6, hudtype 1–2',
    '👩🏿‍❤‍💋‍👩🏼' => 'kyss: kvinne, kvinne, hudtype 6, hudtype 3',
    '👩🏿‍❤‍💋‍👩🏽' => 'kyss: kvinne, kvinne, hudtype 6, hudtype 4',
    '👩🏿‍❤‍💋‍👩🏾' => 'kyss: kvinne, kvinne, hudtype 6, hudtype 5',
    '👩🏿‍❤‍💋‍👩🏿' => 'kyss: kvinne, kvinne, hudtype 6',
    '🧑🏻‍🫯‍🧑🏼' => 'brytere: hudtype 1–2, hudtype 3',
    '🧑🏻‍🫯‍🧑🏽' => 'brytere: hudtype 1–2, hudtype 4',
    '🧑🏻‍🫯‍🧑🏾' => 'brytere: hudtype 1–2, hudtype 5',
    '🧑🏻‍🫯‍🧑🏿' => 'brytere: hudtype 1–2, hudtype 6',
    '🧑🏼‍🫯‍🧑🏻' => 'brytere: hudtype 3, hudtype 1–2',
    '🧑🏼‍🫯‍🧑🏽' => 'brytere: hudtype 3, hudtype 4',
    '🧑🏼‍🫯‍🧑🏾' => 'brytere: hudtype 3, hudtype 5',
    '🧑🏼‍🫯‍🧑🏿' => 'brytere: hudtype 3, hudtype 6',
    '🧑🏽‍🫯‍🧑🏻' => 'brytere: hudtype 4, hudtype 1–2',
    '🧑🏽‍🫯‍🧑🏼' => 'brytere: hudtype 4, hudtype 3',
    '🧑🏽‍🫯‍🧑🏾' => 'brytere: hudtype 4, hudtype 5',
    '🧑🏽‍🫯‍🧑🏿' => 'brytere: hudtype 4, hudtype 6',
    '🧑🏾‍🫯‍🧑🏻' => 'brytere: hudtype 5, hudtype 1–2',
    '🧑🏾‍🫯‍🧑🏼' => 'brytere: hudtype 5, hudtype 3',
    '🧑🏾‍🫯‍🧑🏽' => 'brytere: hudtype 5, hudtype 4',
    '🧑🏾‍🫯‍🧑🏿' => 'brytere: hudtype 5, hudtype 6',
    '🧑🏿‍🫯‍🧑🏻' => 'brytere: hudtype 6, hudtype 1–2',
    '🧑🏿‍🫯‍🧑🏼' => 'brytere: hudtype 6, hudtype 3',
    '🧑🏿‍🫯‍🧑🏽' => 'brytere: hudtype 6, hudtype 4',
    '🧑🏿‍🫯‍🧑🏾' => 'brytere: hudtype 6, hudtype 5',
    '🧑🏻‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, hudtype 1–2, hudtype 3',
    '🧑🏻‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, hudtype 1–2, hudtype 4',
    '🧑🏻‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, hudtype 1–2, hudtype 5',
    '🧑🏻‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, hudtype 1–2, hudtype 6',
    '🧑🏼‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, hudtype 3, hudtype 1–2',
    '🧑🏼‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, hudtype 3, hudtype 4',
    '🧑🏼‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, hudtype 3, hudtype 5',
    '🧑🏼‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, hudtype 3, hudtype 6',
    '🧑🏽‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, hudtype 4, hudtype 1–2',
    '🧑🏽‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, hudtype 4, hudtype 3',
    '🧑🏽‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, hudtype 4, hudtype 5',
    '🧑🏽‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, hudtype 4, hudtype 6',
    '🧑🏾‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, hudtype 5, hudtype 1–2',
    '🧑🏾‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, hudtype 5, hudtype 3',
    '🧑🏾‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, hudtype 5, hudtype 4',
    '🧑🏾‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, hudtype 5, hudtype 6',
    '🧑🏿‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, hudtype 6, hudtype 1–2',
    '🧑🏿‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, hudtype 6, hudtype 3',
    '🧑🏿‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, hudtype 6, hudtype 4',
    '🧑🏿‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, hudtype 6, hudtype 5',
    '🧑🏻‍🐰‍🧑🏼' => 'personer med kaninører: hudtype 1–2, hudtype 3',
    '🧑🏻‍🐰‍🧑🏽' => 'personer med kaninører: hudtype 1–2, hudtype 4',
    '🧑🏻‍🐰‍🧑🏾' => 'personer med kaninører: hudtype 1–2, hudtype 5',
    '🧑🏻‍🐰‍🧑🏿' => 'personer med kaninører: hudtype 1–2, hudtype 6',
    '🧑🏼‍🐰‍🧑🏻' => 'personer med kaninører: hudtype 3, hudtype 1–2',
    '🧑🏼‍🐰‍🧑🏽' => 'personer med kaninører: hudtype 3, hudtype 4',
    '🧑🏼‍🐰‍🧑🏾' => 'personer med kaninører: hudtype 3, hudtype 5',
    '🧑🏼‍🐰‍🧑🏿' => 'personer med kaninører: hudtype 3, hudtype 6',
    '🧑🏽‍🐰‍🧑🏻' => 'personer med kaninører: hudtype 4, hudtype 1–2',
    '🧑🏽‍🐰‍🧑🏼' => 'personer med kaninører: hudtype 4, hudtype 3',
    '🧑🏽‍🐰‍🧑🏾' => 'personer med kaninører: hudtype 4, hudtype 5',
    '🧑🏽‍🐰‍🧑🏿' => 'personer med kaninører: hudtype 4, hudtype 6',
    '🧑🏾‍🐰‍🧑🏻' => 'personer med kaninører: hudtype 5, hudtype 1–2',
    '🧑🏾‍🐰‍🧑🏼' => 'personer med kaninører: hudtype 5, hudtype 3',
    '🧑🏾‍🐰‍🧑🏽' => 'personer med kaninører: hudtype 5, hudtype 4',
    '🧑🏾‍🐰‍🧑🏿' => 'personer med kaninører: hudtype 5, hudtype 6',
    '🧑🏿‍🐰‍🧑🏻' => 'personer med kaninører: hudtype 6, hudtype 1–2',
    '🧑🏿‍🐰‍🧑🏼' => 'personer med kaninører: hudtype 6, hudtype 3',
    '🧑🏿‍🐰‍🧑🏽' => 'personer med kaninører: hudtype 6, hudtype 4',
    '🧑🏿‍🐰‍🧑🏾' => 'personer med kaninører: hudtype 6, hudtype 5',
    '👨🏻‍🫯‍👨🏼' => 'mannlige brytere: hudtype 1–2, hudtype 3',
    '👨🏻‍🫯‍👨🏽' => 'mannlige brytere: hudtype 1–2, hudtype 4',
    '👨🏻‍🫯‍👨🏾' => 'mannlige brytere: hudtype 1–2, hudtype 5',
    '👨🏻‍🫯‍👨🏿' => 'mannlige brytere: hudtype 1–2, hudtype 6',
    '👨🏼‍🫯‍👨🏻' => 'mannlige brytere: hudtype 3, hudtype 1–2',
    '👨🏼‍🫯‍👨🏽' => 'mannlige brytere: hudtype 3, hudtype 4',
    '👨🏼‍🫯‍👨🏾' => 'mannlige brytere: hudtype 3, hudtype 5',
    '👨🏼‍🫯‍👨🏿' => 'mannlige brytere: hudtype 3, hudtype 6',
    '👨🏽‍🫯‍👨🏻' => 'mannlige brytere: hudtype 4, hudtype 1–2',
    '👨🏽‍🫯‍👨🏼' => 'mannlige brytere: hudtype 4, hudtype 3',
    '👨🏽‍🫯‍👨🏾' => 'mannlige brytere: hudtype 4, hudtype 5',
    '👨🏽‍🫯‍👨🏿' => 'mannlige brytere: hudtype 4, hudtype 6',
    '👨🏾‍🫯‍👨🏻' => 'mannlige brytere: hudtype 5, hudtype 1–2',
    '👨🏾‍🫯‍👨🏼' => 'mannlige brytere: hudtype 5, hudtype 3',
    '👨🏾‍🫯‍👨🏽' => 'mannlige brytere: hudtype 5, hudtype 4',
    '👨🏾‍🫯‍👨🏿' => 'mannlige brytere: hudtype 5, hudtype 6',
    '👨🏿‍🫯‍👨🏻' => 'mannlige brytere: hudtype 6, hudtype 1–2',
    '👨🏿‍🫯‍👨🏼' => 'mannlige brytere: hudtype 6, hudtype 3',
    '👨🏿‍🫯‍👨🏽' => 'mannlige brytere: hudtype 6, hudtype 4',
    '👨🏿‍🫯‍👨🏾' => 'mannlige brytere: hudtype 6, hudtype 5',
    '👨🏻‍❤‍👨🏻' => 'par med hjerte: mann, mann, hudtype 1–2',
    '👨🏻‍❤‍👨🏼' => 'par med hjerte: mann, mann, hudtype 1–2, hudtype 3',
    '👨🏻‍❤‍👨🏽' => 'par med hjerte: mann, mann, hudtype 1–2, hudtype 4',
    '👨🏻‍❤‍👨🏾' => 'par med hjerte: mann, mann, hudtype 1–2, hudtype 5',
    '👨🏻‍❤‍👨🏿' => 'par med hjerte: mann, mann, hudtype 1–2, hudtype 6',
    '👨🏼‍❤‍👨🏻' => 'par med hjerte: mann, mann, hudtype 3, hudtype 1–2',
    '👨🏼‍❤‍👨🏼' => 'par med hjerte: mann, mann, hudtype 3',
    '👨🏼‍❤‍👨🏽' => 'par med hjerte: mann, mann, hudtype 3, hudtype 4',
    '👨🏼‍❤‍👨🏾' => 'par med hjerte: mann, mann, hudtype 3, hudtype 5',
    '👨🏼‍❤‍👨🏿' => 'par med hjerte: mann, mann, hudtype 3, hudtype 6',
    '👨🏽‍❤‍👨🏻' => 'par med hjerte: mann, mann, hudtype 4, hudtype 1–2',
    '👨🏽‍❤‍👨🏼' => 'par med hjerte: mann, mann, hudtype 4, hudtype 3',
    '👨🏽‍❤‍👨🏽' => 'par med hjerte: mann, mann, hudtype 4',
    '👨🏽‍❤‍👨🏾' => 'par med hjerte: mann, mann, hudtype 4, hudtype 5',
    '👨🏽‍❤‍👨🏿' => 'par med hjerte: mann, mann, hudtype 4, hudtype 6',
    '👨🏾‍❤‍👨🏻' => 'par med hjerte: mann, mann, hudtype 5, hudtype 1–2',
    '👨🏾‍❤‍👨🏼' => 'par med hjerte: mann, mann, hudtype 5, hudtype 3',
    '👨🏾‍❤‍👨🏽' => 'par med hjerte: mann, mann, hudtype 5, hudtype 4',
    '👨🏾‍❤‍👨🏾' => 'par med hjerte: mann, mann, hudtype 5',
    '👨🏾‍❤‍👨🏿' => 'par med hjerte: mann, mann, hudtype 5, hudtype 6',
    '👨🏿‍❤‍👨🏻' => 'par med hjerte: mann, mann, hudtype 6, hudtype 1–2',
    '👨🏿‍❤‍👨🏼' => 'par med hjerte: mann, mann, hudtype 6, hudtype 3',
    '👨🏿‍❤‍👨🏽' => 'par med hjerte: mann, mann, hudtype 6, hudtype 4',
    '👨🏿‍❤‍👨🏾' => 'par med hjerte: mann, mann, hudtype 6, hudtype 5',
    '👨🏿‍❤‍👨🏿' => 'par med hjerte: mann, mann, hudtype 6',
    '👨🏻‍🐰‍👨🏼' => 'menn med kaninører: hudtype 1–2, hudtype 3',
    '👨🏻‍🐰‍👨🏽' => 'menn med kaninører: hudtype 1–2, hudtype 4',
    '👨🏻‍🐰‍👨🏾' => 'menn med kaninører: hudtype 1–2, hudtype 5',
    '👨🏻‍🐰‍👨🏿' => 'menn med kaninører: hudtype 1–2, hudtype 6',
    '👨🏼‍🐰‍👨🏻' => 'menn med kaninører: hudtype 3, hudtype 1–2',
    '👨🏼‍🐰‍👨🏽' => 'menn med kaninører: hudtype 3, hudtype 4',
    '👨🏼‍🐰‍👨🏾' => 'menn med kaninører: hudtype 3, hudtype 5',
    '👨🏼‍🐰‍👨🏿' => 'menn med kaninører: hudtype 3, hudtype 6',
    '👨🏽‍🐰‍👨🏻' => 'menn med kaninører: hudtype 4, hudtype 1–2',
    '👨🏽‍🐰‍👨🏼' => 'menn med kaninører: hudtype 4, hudtype 3',
    '👨🏽‍🐰‍👨🏾' => 'menn med kaninører: hudtype 4, hudtype 5',
    '👨🏽‍🐰‍👨🏿' => 'menn med kaninører: hudtype 4, hudtype 6',
    '👨🏾‍🐰‍👨🏻' => 'menn med kaninører: hudtype 5, hudtype 1–2',
    '👨🏾‍🐰‍👨🏼' => 'menn med kaninører: hudtype 5, hudtype 3',
    '👨🏾‍🐰‍👨🏽' => 'menn med kaninører: hudtype 5, hudtype 4',
    '👨🏾‍🐰‍👨🏿' => 'menn med kaninører: hudtype 5, hudtype 6',
    '👨🏿‍🐰‍👨🏻' => 'menn med kaninører: hudtype 6, hudtype 1–2',
    '👨🏿‍🐰‍👨🏼' => 'menn med kaninører: hudtype 6, hudtype 3',
    '👨🏿‍🐰‍👨🏽' => 'menn med kaninører: hudtype 6, hudtype 4',
    '👨🏿‍🐰‍👨🏾' => 'menn med kaninører: hudtype 6, hudtype 5',
    '👩🏻‍🫯‍👩🏼' => 'kvinnelige brytere: hudtype 1–2, hudtype 3',
    '👩🏻‍🫯‍👩🏽' => 'kvinnelige brytere: hudtype 1–2, hudtype 4',
    '👩🏻‍🫯‍👩🏾' => 'kvinnelige brytere: hudtype 1–2, hudtype 5',
    '👩🏻‍🫯‍👩🏿' => 'kvinnelige brytere: hudtype 1–2, hudtype 6',
    '👩🏼‍🫯‍👩🏻' => 'kvinnelige brytere: hudtype 3, hudtype 1–2',
    '👩🏼‍🫯‍👩🏽' => 'kvinnelige brytere: hudtype 3, hudtype 4',
    '👩🏼‍🫯‍👩🏾' => 'kvinnelige brytere: hudtype 3, hudtype 5',
    '👩🏼‍🫯‍👩🏿' => 'kvinnelige brytere: hudtype 3, hudtype 6',
    '👩🏽‍🫯‍👩🏻' => 'kvinnelige brytere: hudtype 4, hudtype 1–2',
    '👩🏽‍🫯‍👩🏼' => 'kvinnelige brytere: hudtype 4, hudtype 3',
    '👩🏽‍🫯‍👩🏾' => 'kvinnelige brytere: hudtype 4, hudtype 5',
    '👩🏽‍🫯‍👩🏿' => 'kvinnelige brytere: hudtype 4, hudtype 6',
    '👩🏾‍🫯‍👩🏻' => 'kvinnelige brytere: hudtype 5, hudtype 1–2',
    '👩🏾‍🫯‍👩🏼' => 'kvinnelige brytere: hudtype 5, hudtype 3',
    '👩🏾‍🫯‍👩🏽' => 'kvinnelige brytere: hudtype 5, hudtype 4',
    '👩🏾‍🫯‍👩🏿' => 'kvinnelige brytere: hudtype 5, hudtype 6',
    '👩🏿‍🫯‍👩🏻' => 'kvinnelige brytere: hudtype 6, hudtype 1–2',
    '👩🏿‍🫯‍👩🏼' => 'kvinnelige brytere: hudtype 6, hudtype 3',
    '👩🏿‍🫯‍👩🏽' => 'kvinnelige brytere: hudtype 6, hudtype 4',
    '👩🏿‍🫯‍👩🏾' => 'kvinnelige brytere: hudtype 6, hudtype 5',
    '👩🏻‍❤‍👨🏻' => 'par med hjerte: kvinne, mann, hudtype 1–2',
    '👩🏻‍❤‍👨🏼' => 'par med hjerte: kvinne, mann, hudtype 1–2, hudtype 3',
    '👩🏻‍❤‍👨🏽' => 'par med hjerte: kvinne, mann, hudtype 1–2, hudtype 4',
    '👩🏻‍❤‍👨🏾' => 'par med hjerte: kvinne, mann, hudtype 1–2, hudtype 5',
    '👩🏻‍❤‍👨🏿' => 'par med hjerte: kvinne, mann, hudtype 1–2, hudtype 6',
    '👩🏼‍❤‍👨🏻' => 'par med hjerte: kvinne, mann, hudtype 3, hudtype 1–2',
    '👩🏼‍❤‍👨🏼' => 'par med hjerte: kvinne, mann, hudtype 3',
    '👩🏼‍❤‍👨🏽' => 'par med hjerte: kvinne, mann, hudtype 3, hudtype 4',
    '👩🏼‍❤‍👨🏾' => 'par med hjerte: kvinne, mann, hudtype 3, hudtype 5',
    '👩🏼‍❤‍👨🏿' => 'par med hjerte: kvinne, mann, hudtype 3, hudtype 6',
    '👩🏽‍❤‍👨🏻' => 'par med hjerte: kvinne, mann, hudtype 4, hudtype 1–2',
    '👩🏽‍❤‍👨🏼' => 'par med hjerte: kvinne, mann, hudtype 4, hudtype 3',
    '👩🏽‍❤‍👨🏽' => 'par med hjerte: kvinne, mann, hudtype 4',
    '👩🏽‍❤‍👨🏾' => 'par med hjerte: kvinne, mann, hudtype 4, hudtype 5',
    '👩🏽‍❤‍👨🏿' => 'par med hjerte: kvinne, mann, hudtype 4, hudtype 6',
    '👩🏾‍❤‍👨🏻' => 'par med hjerte: kvinne, mann, hudtype 5, hudtype 1–2',
    '👩🏾‍❤‍👨🏼' => 'par med hjerte: kvinne, mann, hudtype 5, hudtype 3',
    '👩🏾‍❤‍👨🏽' => 'par med hjerte: kvinne, mann, hudtype 5, hudtype 4',
    '👩🏾‍❤‍👨🏾' => 'par med hjerte: kvinne, mann, hudtype 5',
    '👩🏾‍❤‍👨🏿' => 'par med hjerte: kvinne, mann, hudtype 5, hudtype 6',
    '👩🏿‍❤‍👨🏻' => 'par med hjerte: kvinne, mann, hudtype 6, hudtype 1–2',
    '👩🏿‍❤‍👨🏼' => 'par med hjerte: kvinne, mann, hudtype 6, hudtype 3',
    '👩🏿‍❤‍👨🏽' => 'par med hjerte: kvinne, mann, hudtype 6, hudtype 4',
    '👩🏿‍❤‍👨🏾' => 'par med hjerte: kvinne, mann, hudtype 6, hudtype 5',
    '👩🏿‍❤‍👨🏿' => 'par med hjerte: kvinne, mann, hudtype 6',
    '👩🏻‍❤‍👩🏻' => 'par med hjerte: kvinne, kvinne, hudtype 1–2',
    '👩🏻‍❤‍👩🏼' => 'par med hjerte: kvinne, kvinne, hudtype 1–2, hudtype 3',
    '👩🏻‍❤‍👩🏽' => 'par med hjerte: kvinne, kvinne, hudtype 1–2, hudtype 4',
    '👩🏻‍❤‍👩🏾' => 'par med hjerte: kvinne, kvinne, hudtype 1–2, hudtype 5',
    '👩🏻‍❤‍👩🏿' => 'par med hjerte: kvinne, kvinne, hudtype 1–2, hudtype 6',
    '👩🏼‍❤‍👩🏻' => 'par med hjerte: kvinne, kvinne, hudtype 3, hudtype 1–2',
    '👩🏼‍❤‍👩🏼' => 'par med hjerte: kvinne, kvinne, hudtype 3',
    '👩🏼‍❤‍👩🏽' => 'par med hjerte: kvinne, kvinne, hudtype 3, hudtype 4',
    '👩🏼‍❤‍👩🏾' => 'par med hjerte: kvinne, kvinne, hudtype 3, hudtype 5',
    '👩🏼‍❤‍👩🏿' => 'par med hjerte: kvinne, kvinne, hudtype 3, hudtype 6',
    '👩🏽‍❤‍👩🏻' => 'par med hjerte: kvinne, kvinne, hudtype 4, hudtype 1–2',
    '👩🏽‍❤‍👩🏼' => 'par med hjerte: kvinne, kvinne, hudtype 4, hudtype 3',
    '👩🏽‍❤‍👩🏽' => 'par med hjerte: kvinne, kvinne, hudtype 4',
    '👩🏽‍❤‍👩🏾' => 'par med hjerte: kvinne, kvinne, hudtype 4, hudtype 5',
    '👩🏽‍❤‍👩🏿' => 'par med hjerte: kvinne, kvinne, hudtype 4, hudtype 6',
    '👩🏾‍❤‍👩🏻' => 'par med hjerte: kvinne, kvinne, hudtype 5, hudtype 1–2',
    '👩🏾‍❤‍👩🏼' => 'par med hjerte: kvinne, kvinne, hudtype 5, hudtype 3',
    '👩🏾‍❤‍👩🏽' => 'par med hjerte: kvinne, kvinne, hudtype 5, hudtype 4',
    '👩🏾‍❤‍👩🏾' => 'par med hjerte: kvinne, kvinne, hudtype 5',
    '👩🏾‍❤‍👩🏿' => 'par med hjerte: kvinne, kvinne, hudtype 5, hudtype 6',
    '👩🏿‍❤‍👩🏻' => 'par med hjerte: kvinne, kvinne, hudtype 6, hudtype 1–2',
    '👩🏿‍❤‍👩🏼' => 'par med hjerte: kvinne, kvinne, hudtype 6, hudtype 3',
    '👩🏿‍❤‍👩🏽' => 'par med hjerte: kvinne, kvinne, hudtype 6, hudtype 4',
    '👩🏿‍❤‍👩🏾' => 'par med hjerte: kvinne, kvinne, hudtype 6, hudtype 5',
    '👩🏿‍❤‍👩🏿' => 'par med hjerte: kvinne, kvinne, hudtype 6',
    '👩🏻‍🐰‍👩🏼' => 'kvinner med kaninører: hudtype 1–2, hudtype 3',
    '👩🏻‍🐰‍👩🏽' => 'kvinner med kaninører: hudtype 1–2, hudtype 4',
    '👩🏻‍🐰‍👩🏾' => 'kvinner med kaninører: hudtype 1–2, hudtype 5',
    '👩🏻‍🐰‍👩🏿' => 'kvinner med kaninører: hudtype 1–2, hudtype 6',
    '👩🏼‍🐰‍👩🏻' => 'kvinner med kaninører: hudtype 3, hudtype 1–2',
    '👩🏼‍🐰‍👩🏽' => 'kvinner med kaninører: hudtype 3, hudtype 4',
    '👩🏼‍🐰‍👩🏾' => 'kvinner med kaninører: hudtype 3, hudtype 5',
    '👩🏼‍🐰‍👩🏿' => 'kvinner med kaninører: hudtype 3, hudtype 6',
    '👩🏽‍🐰‍👩🏻' => 'kvinner med kaninører: hudtype 4, hudtype 1–2',
    '👩🏽‍🐰‍👩🏼' => 'kvinner med kaninører: hudtype 4, hudtype 3',
    '👩🏽‍🐰‍👩🏾' => 'kvinner med kaninører: hudtype 4, hudtype 5',
    '👩🏽‍🐰‍👩🏿' => 'kvinner med kaninører: hudtype 4, hudtype 6',
    '👩🏾‍🐰‍👩🏻' => 'kvinner med kaninører: hudtype 5, hudtype 1–2',
    '👩🏾‍🐰‍👩🏼' => 'kvinner med kaninører: hudtype 5, hudtype 3',
    '👩🏾‍🐰‍👩🏽' => 'kvinner med kaninører: hudtype 5, hudtype 4',
    '👩🏾‍🐰‍👩🏿' => 'kvinner med kaninører: hudtype 5, hudtype 6',
    '👩🏿‍🐰‍👩🏻' => 'kvinner med kaninører: hudtype 6, hudtype 1–2',
    '👩🏿‍🐰‍👩🏼' => 'kvinner med kaninører: hudtype 6, hudtype 3',
    '👩🏿‍🐰‍👩🏽' => 'kvinner med kaninører: hudtype 6, hudtype 4',
    '👩🏿‍🐰‍👩🏾' => 'kvinner med kaninører: hudtype 6, hudtype 5',
    '🧑🏻‍🤝‍🧑🏻' => 'personer som leier: hudtype 1–2',
    '🧑🏻‍🤝‍🧑🏼' => 'personer som leier: hudtype 1–2, hudtype 3',
    '🧑🏻‍🤝‍🧑🏽' => 'personer som leier: hudtype 1–2, hudtype 4',
    '🧑🏻‍🤝‍🧑🏾' => 'personer som leier: hudtype 1–2, hudtype 5',
    '🧑🏻‍🤝‍🧑🏿' => 'personer som leier: hudtype 1–2, hudtype 6',
    '🧑🏼‍🤝‍🧑🏻' => 'personer som leier: hudtype 3, hudtype 1–2',
    '🧑🏼‍🤝‍🧑🏼' => 'personer som leier: hudtype 3',
    '🧑🏼‍🤝‍🧑🏽' => 'personer som leier: hudtype 3, hudtype 4',
    '🧑🏼‍🤝‍🧑🏾' => 'personer som leier: hudtype 3, hudtype 5',
    '🧑🏼‍🤝‍🧑🏿' => 'personer som leier: hudtype 3, hudtype 6',
    '🧑🏽‍🤝‍🧑🏻' => 'personer som leier: hudtype 4, hudtype 1–2',
    '🧑🏽‍🤝‍🧑🏼' => 'personer som leier: hudtype 4, hudtype 3',
    '🧑🏽‍🤝‍🧑🏽' => 'personer som leier: hudtype 4',
    '🧑🏽‍🤝‍🧑🏾' => 'personer som leier: hudtype 4, hudtype 5',
    '🧑🏽‍🤝‍🧑🏿' => 'personer som leier: hudtype 4, hudtype 6',
    '🧑🏾‍🤝‍🧑🏻' => 'personer som leier: hudtype 5, hudtype 1–2',
    '🧑🏾‍🤝‍🧑🏼' => 'personer som leier: hudtype 5, hudtype 3',
    '🧑🏾‍🤝‍🧑🏽' => 'personer som leier: hudtype 5, hudtype 4',
    '🧑🏾‍🤝‍🧑🏾' => 'personer som leier: hudtype 5',
    '🧑🏾‍🤝‍🧑🏿' => 'personer som leier: hudtype 5, hudtype 6',
    '🧑🏿‍🤝‍🧑🏻' => 'personer som leier: hudtype 6, hudtype 1–2',
    '🧑🏿‍🤝‍🧑🏼' => 'personer som leier: hudtype 6, hudtype 3',
    '🧑🏿‍🤝‍🧑🏽' => 'personer som leier: hudtype 6, hudtype 4',
    '🧑🏿‍🤝‍🧑🏾' => 'personer som leier: hudtype 6, hudtype 5',
    '🧑🏿‍🤝‍🧑🏿' => 'personer som leier: hudtype 6',
    '👩🏻‍🤝‍👩🏼' => 'kvinner som leier: hudtype 1–2, hudtype 3',
    '👩🏻‍🤝‍👩🏽' => 'kvinner som leier: hudtype 1–2, hudtype 4',
    '👩🏻‍🤝‍👩🏾' => 'kvinner som leier: hudtype 1–2, hudtype 5',
    '👩🏻‍🤝‍👩🏿' => 'kvinner som leier: hudtype 1–2, hudtype 6',
    '👩🏼‍🤝‍👩🏻' => 'kvinner som leier: hudtype 3, hudtype 1–2',
    '👩🏼‍🤝‍👩🏽' => 'kvinner som leier: hudtype 3, hudtype 4',
    '👩🏼‍🤝‍👩🏾' => 'kvinner som leier: hudtype 3, hudtype 5',
    '👩🏼‍🤝‍👩🏿' => 'kvinner som leier: hudtype 3, hudtype 6',
    '👩🏽‍🤝‍👩🏻' => 'kvinner som leier: hudtype 4, hudtype 1–2',
    '👩🏽‍🤝‍👩🏼' => 'kvinner som leier: hudtype 4, hudtype 3',
    '👩🏽‍🤝‍👩🏾' => 'kvinner som leier: hudtype 4, hudtype 5',
    '👩🏽‍🤝‍👩🏿' => 'kvinner som leier: hudtype 4, hudtype 6',
    '👩🏾‍🤝‍👩🏻' => 'kvinner som leier: hudtype 5, hudtype 1–2',
    '👩🏾‍🤝‍👩🏼' => 'kvinner som leier: hudtype 5, hudtype 3',
    '👩🏾‍🤝‍👩🏽' => 'kvinner som leier: hudtype 5, hudtype 4',
    '👩🏾‍🤝‍👩🏿' => 'kvinner som leier: hudtype 5, hudtype 6',
    '👩🏿‍🤝‍👩🏻' => 'kvinner som leier: hudtype 6, hudtype 1–2',
    '👩🏿‍🤝‍👩🏼' => 'kvinner som leier: hudtype 6, hudtype 3',
    '👩🏿‍🤝‍👩🏽' => 'kvinner som leier: hudtype 6, hudtype 4',
    '👩🏿‍🤝‍👩🏾' => 'kvinner som leier: hudtype 6, hudtype 5',
    '👩🏻‍🤝‍👨🏼' => 'mann og kvinne som leier: hudtype 1–2, hudtype 3',
    '👩🏻‍🤝‍👨🏽' => 'mann og kvinne som leier: hudtype 1–2, hudtype 4',
    '👩🏻‍🤝‍👨🏾' => 'mann og kvinne som leier: hudtype 1–2, hudtype 5',
    '👩🏻‍🤝‍👨🏿' => 'mann og kvinne som leier: hudtype 1–2, hudtype 6',
    '👩🏼‍🤝‍👨🏻' => 'mann og kvinne som leier: hudtype 3, hudtype 1–2',
    '👩🏼‍🤝‍👨🏽' => 'mann og kvinne som leier: hudtype 3, hudtype 4',
    '👩🏼‍🤝‍👨🏾' => 'mann og kvinne som leier: hudtype 3, hudtype 5',
    '👩🏼‍🤝‍👨🏿' => 'mann og kvinne som leier: hudtype 3, hudtype 6',
    '👩🏽‍🤝‍👨🏻' => 'mann og kvinne som leier: hudtype 4, hudtype 1–2',
    '👩🏽‍🤝‍👨🏼' => 'mann og kvinne som leier: hudtype 4, hudtype 3',
    '👩🏽‍🤝‍👨🏾' => 'mann og kvinne som leier: hudtype 4, hudtype 5',
    '👩🏽‍🤝‍👨🏿' => 'mann og kvinne som leier: hudtype 4, hudtype 6',
    '👩🏾‍🤝‍👨🏻' => 'mann og kvinne som leier: hudtype 5, hudtype 1–2',
    '👩🏾‍🤝‍👨🏼' => 'mann og kvinne som leier: hudtype 5, hudtype 3',
    '👩🏾‍🤝‍👨🏽' => 'mann og kvinne som leier: hudtype 5, hudtype 4',
    '👩🏾‍🤝‍👨🏿' => 'mann og kvinne som leier: hudtype 5, hudtype 6',
    '👩🏿‍🤝‍👨🏻' => 'mann og kvinne som leier: hudtype 6, hudtype 1–2',
    '👩🏿‍🤝‍👨🏼' => 'mann og kvinne som leier: hudtype 6, hudtype 3',
    '👩🏿‍🤝‍👨🏽' => 'mann og kvinne som leier: hudtype 6, hudtype 4',
    '👩🏿‍🤝‍👨🏾' => 'mann og kvinne som leier: hudtype 6, hudtype 5',
    '👨🏻‍🤝‍👨🏼' => 'menn som leier: hudtype 1–2, hudtype 3',
    '👨🏻‍🤝‍👨🏽' => 'menn som leier: hudtype 1–2, hudtype 4',
    '👨🏻‍🤝‍👨🏾' => 'menn som leier: hudtype 1–2, hudtype 5',
    '👨🏻‍🤝‍👨🏿' => 'menn som leier: hudtype 1–2, hudtype 6',
    '👨🏼‍🤝‍👨🏻' => 'menn som leier: hudtype 3, hudtype 1–2',
    '👨🏼‍🤝‍👨🏽' => 'menn som leier: hudtype 3, hudtype 4',
    '👨🏼‍🤝‍👨🏾' => 'menn som leier: hudtype 3, hudtype 5',
    '👨🏼‍🤝‍👨🏿' => 'menn som leier: hudtype 3, hudtype 6',
    '👨🏽‍🤝‍👨🏻' => 'menn som leier: hudtype 4, hudtype 1–2',
    '👨🏽‍🤝‍👨🏼' => 'menn som leier: hudtype 4, hudtype 3',
    '👨🏽‍🤝‍👨🏾' => 'menn som leier: hudtype 4, hudtype 5',
    '👨🏽‍🤝‍👨🏿' => 'menn som leier: hudtype 4, hudtype 6',
    '👨🏾‍🤝‍👨🏻' => 'menn som leier: hudtype 5, hudtype 1–2',
    '👨🏾‍🤝‍👨🏼' => 'menn som leier: hudtype 5, hudtype 3',
    '👨🏾‍🤝‍👨🏽' => 'menn som leier: hudtype 5, hudtype 4',
    '👨🏾‍🤝‍👨🏿' => 'menn som leier: hudtype 5, hudtype 6',
    '👨🏿‍🤝‍👨🏻' => 'menn som leier: hudtype 6, hudtype 1–2',
    '👨🏿‍🤝‍👨🏼' => 'menn som leier: hudtype 6, hudtype 3',
    '👨🏿‍🤝‍👨🏽' => 'menn som leier: hudtype 6, hudtype 4',
    '👨🏿‍🤝‍👨🏾' => 'menn som leier: hudtype 6, hudtype 5',
    '👩‍❤‍💋‍👨' => 'kyss: kvinne, mann',
    '👨‍❤‍💋‍👨' => 'kyss: mann, mann',
    '👩‍❤‍💋‍👩' => 'kyss: kvinne, kvinne',
    '👨‍👩‍👧‍👦' => 'familie: mann, kvinne, jente, gutt',
    '👨‍👩‍👦‍👦' => 'familie: mann, kvinne, gutt, gutt',
    '👨‍👩‍👧‍👧' => 'familie: mann, kvinne, jente, jente',
    '👨‍👨‍👧‍👦' => 'familie: mann, mann, jente, gutt',
    '👨‍👨‍👦‍👦' => 'familie: mann, mann, gutt, gutt',
    '👨‍👨‍👧‍👧' => 'familie: mann, mann, jente, jente',
    '👩‍👩‍👧‍👦' => 'familie: kvinne, kvinne, jente, gutt',
    '👩‍👩‍👦‍👦' => 'familie: kvinne, kvinne, gutt, gutt',
    '👩‍👩‍👧‍👧' => 'familie: kvinne, kvinne, jente, jente',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'flagg: England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'flagg: Skottland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'flagg: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'familie: voksen, voksen, barn, barn',
    '🚶🏻‍♀‍➡' => 'kvinnelig fotgjenger: hudtype 1–2, vendt mot høyre',
    '🚶🏼‍♀‍➡' => 'kvinnelig fotgjenger: hudtype 3, vendt mot høyre',
    '🚶🏽‍♀‍➡' => 'kvinnelig fotgjenger: hudtype 4, vendt mot høyre',
    '🚶🏾‍♀‍➡' => 'kvinnelig fotgjenger: hudtype 5, vendt mot høyre',
    '🚶🏿‍♀‍➡' => 'kvinnelig fotgjenger: hudtype 6, vendt mot høyre',
    '🚶🏻‍♂‍➡' => 'mannlig fotgjenger: hudtype 1–2, vendt mot høyre',
    '🚶🏼‍♂‍➡' => 'mannlig fotgjenger: hudtype 3, vendt mot høyre',
    '🚶🏽‍♂‍➡' => 'mannlig fotgjenger: hudtype 4, vendt mot høyre',
    '🚶🏾‍♂‍➡' => 'mannlig fotgjenger: hudtype 5, vendt mot høyre',
    '🚶🏿‍♂‍➡' => 'mannlig fotgjenger: hudtype 6, vendt mot høyre',
    '🧎🏻‍♀‍➡' => 'kvinne som kneler: hudtype 1–2, vendt mot høyre',
    '🧎🏼‍♀‍➡' => 'kvinne som kneler: hudtype 3, vendt mot høyre',
    '🧎🏽‍♀‍➡' => 'kvinne som kneler: hudtype 4, vendt mot høyre',
    '🧎🏾‍♀‍➡' => 'kvinne som kneler: hudtype 5, vendt mot høyre',
    '🧎🏿‍♀‍➡' => 'kvinne som kneler: hudtype 6, vendt mot høyre',
    '🧎🏻‍♂‍➡' => 'mann som kneler: hudtype 1–2, vendt mot høyre',
    '🧎🏼‍♂‍➡' => 'mann som kneler: hudtype 3, vendt mot høyre',
    '🧎🏽‍♂‍➡' => 'mann som kneler: hudtype 4, vendt mot høyre',
    '🧎🏾‍♂‍➡' => 'mann som kneler: hudtype 5, vendt mot høyre',
    '🧎🏿‍♂‍➡' => 'mann som kneler: hudtype 6, vendt mot høyre',
    '🧑🏻‍🦯‍➡' => 'person med blindestokk: hudtype 1–2, vendt mot høyre',
    '🧑🏼‍🦯‍➡' => 'person med blindestokk: hudtype 3, vendt mot høyre',
    '🧑🏽‍🦯‍➡' => 'person med blindestokk: hudtype 4, vendt mot høyre',
    '🧑🏾‍🦯‍➡' => 'person med blindestokk: hudtype 5, vendt mot høyre',
    '🧑🏿‍🦯‍➡' => 'person med blindestokk: hudtype 6, vendt mot høyre',
    '👨🏻‍🦯‍➡' => 'mann med blindestokk: hudtype 1–2, vendt mot høyre',
    '👨🏼‍🦯‍➡' => 'mann med blindestokk: hudtype 3, vendt mot høyre',
    '👨🏽‍🦯‍➡' => 'mann med blindestokk: hudtype 4, vendt mot høyre',
    '👨🏾‍🦯‍➡' => 'mann med blindestokk: hudtype 5, vendt mot høyre',
    '👨🏿‍🦯‍➡' => 'mann med blindestokk: hudtype 6, vendt mot høyre',
    '👩🏻‍🦯‍➡' => 'kvinne med blindestokk: hudtype 1–2, vendt mot høyre',
    '👩🏼‍🦯‍➡' => 'kvinne med blindestokk: hudtype 3, vendt mot høyre',
    '👩🏽‍🦯‍➡' => 'kvinne med blindestokk: hudtype 4, vendt mot høyre',
    '👩🏾‍🦯‍➡' => 'kvinne med blindestokk: hudtype 5, vendt mot høyre',
    '👩🏿‍🦯‍➡' => 'kvinne med blindestokk: hudtype 6, vendt mot høyre',
    '🧑🏻‍🦼‍➡' => 'person i motorisert rullestol: hudtype 1–2, vendt mot høyre',
    '🧑🏼‍🦼‍➡' => 'person i motorisert rullestol: hudtype 3, vendt mot høyre',
    '🧑🏽‍🦼‍➡' => 'person i motorisert rullestol: hudtype 4, vendt mot høyre',
    '🧑🏾‍🦼‍➡' => 'person i motorisert rullestol: hudtype 5, vendt mot høyre',
    '🧑🏿‍🦼‍➡' => 'person i motorisert rullestol: hudtype 6, vendt mot høyre',
    '👨🏻‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 1–2, vendt mot høyre',
    '👨🏼‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 3, vendt mot høyre',
    '👨🏽‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 4, vendt mot høyre',
    '👨🏾‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 5, vendt mot høyre',
    '👨🏿‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 6, vendt mot høyre',
    '👩🏻‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 1–2, vendt mot høyre',
    '👩🏼‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 3, vendt mot høyre',
    '👩🏽‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 4, vendt mot høyre',
    '👩🏾‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 5, vendt mot høyre',
    '👩🏿‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 6, vendt mot høyre',
    '🧑🏻‍🦽‍➡' => 'person i manuell rullestol: hudtype 1–2, vendt mot høyre',
    '🧑🏼‍🦽‍➡' => 'person i manuell rullestol: hudtype 3, vendt mot høyre',
    '🧑🏽‍🦽‍➡' => 'person i manuell rullestol: hudtype 4, vendt mot høyre',
    '🧑🏾‍🦽‍➡' => 'person i manuell rullestol: hudtype 5, vendt mot høyre',
    '🧑🏿‍🦽‍➡' => 'person i manuell rullestol: hudtype 6, vendt mot høyre',
    '👨🏻‍🦽‍➡' => 'mann i manuell rullestol: hudtype 1–2, vendt mot høyre',
    '👨🏼‍🦽‍➡' => 'mann i manuell rullestol: hudtype 3, vendt mot høyre',
    '👨🏽‍🦽‍➡' => 'mann i manuell rullestol: hudtype 4, vendt mot høyre',
    '👨🏾‍🦽‍➡' => 'mann i manuell rullestol: hudtype 5, vendt mot høyre',
    '👨🏿‍🦽‍➡' => 'mann i manuell rullestol: hudtype 6, vendt mot høyre',
    '👩🏻‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 1–2, vendt mot høyre',
    '👩🏼‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 3, vendt mot høyre',
    '👩🏽‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 4, vendt mot høyre',
    '👩🏾‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 5, vendt mot høyre',
    '👩🏿‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 6, vendt mot høyre',
    '🏃🏻‍♀‍➡' => 'kvinnelig løper: hudtype 1–2, vendt mot høyre',
    '🏃🏼‍♀‍➡' => 'kvinnelig løper: hudtype 3, vendt mot høyre',
    '🏃🏽‍♀‍➡' => 'kvinnelig løper: hudtype 4, vendt mot høyre',
    '🏃🏾‍♀‍➡' => 'kvinnelig løper: hudtype 5, vendt mot høyre',
    '🏃🏿‍♀‍➡' => 'kvinnelig løper: hudtype 6, vendt mot høyre',
    '🏃🏻‍♂‍➡' => 'mannlig løper: hudtype 1–2, vendt mot høyre',
    '🏃🏼‍♂‍➡' => 'mannlig løper: hudtype 3, vendt mot høyre',
    '🏃🏽‍♂‍➡' => 'mannlig løper: hudtype 4, vendt mot høyre',
    '🏃🏾‍♂‍➡' => 'mannlig løper: hudtype 5, vendt mot høyre',
    '🏃🏿‍♂‍➡' => 'mannlig løper: hudtype 6, vendt mot høyre',
    '🫱🏻‍🫲🏼' => 'håndhilse: hudtype 1–2, hudtype 3',
    '🫱🏻‍🫲🏽' => 'håndhilse: hudtype 1–2, hudtype 4',
    '🫱🏻‍🫲🏾' => 'håndhilse: hudtype 1–2, hudtype 5',
    '🫱🏻‍🫲🏿' => 'håndhilse: hudtype 1–2, hudtype 6',
    '🫱🏼‍🫲🏻' => 'håndhilse: hudtype 3, hudtype 1–2',
    '🫱🏼‍🫲🏽' => 'håndhilse: hudtype 3, hudtype 4',
    '🫱🏼‍🫲🏾' => 'håndhilse: hudtype 3, hudtype 5',
    '🫱🏼‍🫲🏿' => 'håndhilse: hudtype 3, hudtype 6',
    '🫱🏽‍🫲🏻' => 'håndhilse: hudtype 4, hudtype 1–2',
    '🫱🏽‍🫲🏼' => 'håndhilse: hudtype 4, hudtype 3',
    '🫱🏽‍🫲🏾' => 'håndhilse: hudtype 4, hudtype 5',
    '🫱🏽‍🫲🏿' => 'håndhilse: hudtype 4, hudtype 6',
    '🫱🏾‍🫲🏻' => 'håndhilse: hudtype 5, hudtype 1–2',
    '🫱🏾‍🫲🏼' => 'håndhilse: hudtype 5, hudtype 3',
    '🫱🏾‍🫲🏽' => 'håndhilse: hudtype 5, hudtype 4',
    '🫱🏾‍🫲🏿' => 'håndhilse: hudtype 5, hudtype 6',
    '🫱🏿‍🫲🏻' => 'håndhilse: hudtype 6, hudtype 1–2',
    '🫱🏿‍🫲🏼' => 'håndhilse: hudtype 6, hudtype 3',
    '🫱🏿‍🫲🏽' => 'håndhilse: hudtype 6, hudtype 4',
    '🫱🏿‍🫲🏾' => 'håndhilse: hudtype 6, hudtype 5',
    '🚶‍♀‍➡' => 'kvinnelig fotgjenger: vendt mot høyre',
    '🚶‍♂‍➡' => 'mannlig fotgjenger: vendt mot høyre',
    '🧎‍♀‍➡' => 'kvinne som kneler: vendt mot høyre',
    '🧎‍♂‍➡' => 'mann som kneler: vendt mot høyre',
    '🧑‍🦯‍➡' => 'person med blindestokk: vendt mot høyre',
    '👨‍🦯‍➡' => 'mann med blindestokk: vendt mot høyre',
    '👩‍🦯‍➡' => 'kvinne med blindestokk: vendt mot høyre',
    '🧑‍🦼‍➡' => 'person i motorisert rullestol: vendt mot høyre',
    '👨‍🦼‍➡' => 'mann i motorisert rullestol: vendt mot høyre',
    '👩‍🦼‍➡' => 'kvinne i motorisert rullestol: vendt mot høyre',
    '🧑‍🦽‍➡' => 'person i manuell rullestol: vendt mot høyre',
    '👨‍🦽‍➡' => 'mann i manuell rullestol: vendt mot høyre',
    '👩‍🦽‍➡' => 'kvinne i manuell rullestol: vendt mot høyre',
    '🏃‍♀‍➡' => 'kvinnelig løper: vendt mot høyre',
    '🏃‍♂‍➡' => 'mannlig løper: vendt mot høyre',
    '👩‍❤‍👨' => 'par med hjerte: kvinne, mann',
    '👨‍❤‍👨' => 'par med hjerte: mann, mann',
    '👩‍❤‍👩' => 'par med hjerte: kvinne, kvinne',
    '👨‍👩‍👦' => 'familie: mann, kvinne, gutt',
    '👨‍👩‍👧' => 'familie: mann, kvinne, jente',
    '👨‍👨‍👦' => 'familie: mann, mann, gutt',
    '👨‍👨‍👧' => 'familie: mann, mann, jente',
    '👩‍👩‍👦' => 'familie: kvinne, kvinne, gutt',
    '👩‍👩‍👧' => 'familie: kvinne, kvinne, jente',
    '👨‍👦‍👦' => 'familie: mann, gutt, gutt',
    '👨‍👧‍👦' => 'familie: mann, jente, gutt',
    '👨‍👧‍👧' => 'familie: mann, jente, jente',
    '👩‍👦‍👦' => 'familie: kvinne, gutt, gutt',
    '👩‍👧‍👦' => 'familie: kvinne, jente, gutt',
    '👩‍👧‍👧' => 'familie: kvinne, jente, jente',
    '🧑‍🤝‍🧑' => 'personer som leier',
    '🧑‍🧑‍🧒' => 'familie: voksen, voksen, barn',
    '🧑‍🧒‍🧒' => 'familie: voksen, barn, barn',
    '🧑🏻‍🦰' => 'voksen: hudtype 1–2, rødt hår',
    '🧑🏼‍🦰' => 'voksen: hudtype 3, rødt hår',
    '🧑🏽‍🦰' => 'voksen: hudtype 4, rødt hår',
    '🧑🏾‍🦰' => 'voksen: hudtype 5, rødt hår',
    '🧑🏿‍🦰' => 'voksen: hudtype 6, rødt hår',
    '🧑🏻‍🦱' => 'voksen: hudtype 1–2, kruset hår',
    '🧑🏼‍🦱' => 'voksen: hudtype 3, kruset hår',
    '🧑🏽‍🦱' => 'voksen: hudtype 4, kruset hår',
    '🧑🏾‍🦱' => 'voksen: hudtype 5, kruset hår',
    '🧑🏿‍🦱' => 'voksen: hudtype 6, kruset hår',
    '🧑🏻‍🦳' => 'voksen: hudtype 1–2, grått hår',
    '🧑🏼‍🦳' => 'voksen: hudtype 3, grått hår',
    '🧑🏽‍🦳' => 'voksen: hudtype 4, grått hår',
    '🧑🏾‍🦳' => 'voksen: hudtype 5, grått hår',
    '🧑🏿‍🦳' => 'voksen: hudtype 6, grått hår',
    '🧑🏻‍🦲' => 'voksen: hudtype 1–2, skallet',
    '🧑🏼‍🦲' => 'voksen: hudtype 3, skallet',
    '🧑🏽‍🦲' => 'voksen: hudtype 4, skallet',
    '🧑🏾‍🦲' => 'voksen: hudtype 5, skallet',
    '🧑🏿‍🦲' => 'voksen: hudtype 6, skallet',
    '🧑🏻‍🩰' => 'ballettdanser: hudtype 1–2',
    '🧑🏼‍🩰' => 'ballettdanser: hudtype 3',
    '🧑🏽‍🩰' => 'ballettdanser: hudtype 4',
    '🧑🏾‍🩰' => 'ballettdanser: hudtype 5',
    '🧑🏿‍🩰' => 'ballettdanser: hudtype 6',
    '🧔🏻‍♂' => 'mann: hudtype 1–2, skjegg',
    '🧔🏼‍♂' => 'mann: hudtype 3, skjegg',
    '🧔🏽‍♂' => 'mann: hudtype 4, skjegg',
    '🧔🏾‍♂' => 'mann: hudtype 5, skjegg',
    '🧔🏿‍♂' => 'mann: hudtype 6, skjegg',
    '👱🏻‍♂' => 'mann: hudtype 1–2, blond',
    '👱🏼‍♂' => 'mann: hudtype 3, blond',
    '👱🏽‍♂' => 'mann: hudtype 4, blond',
    '👱🏾‍♂' => 'mann: hudtype 5, blond',
    '👱🏿‍♂' => 'mann: hudtype 6, blond',
    '👨🏻‍🦰' => 'mann: hudtype 1–2, rødt hår',
    '👨🏼‍🦰' => 'mann: hudtype 3, rødt hår',
    '👨🏽‍🦰' => 'mann: hudtype 4, rødt hår',
    '👨🏾‍🦰' => 'mann: hudtype 5, rødt hår',
    '👨🏿‍🦰' => 'mann: hudtype 6, rødt hår',
    '👨🏻‍🦱' => 'mann: hudtype 1–2, kruset hår',
    '👨🏼‍🦱' => 'mann: hudtype 3, kruset hår',
    '👨🏽‍🦱' => 'mann: hudtype 4, kruset hår',
    '👨🏾‍🦱' => 'mann: hudtype 5, kruset hår',
    '👨🏿‍🦱' => 'mann: hudtype 6, kruset hår',
    '👨🏻‍🦳' => 'mann: hudtype 1–2, grått hår',
    '👨🏼‍🦳' => 'mann: hudtype 3, grått hår',
    '👨🏽‍🦳' => 'mann: hudtype 4, grått hår',
    '👨🏾‍🦳' => 'mann: hudtype 5, grått hår',
    '👨🏿‍🦳' => 'mann: hudtype 6, grått hår',
    '👨🏻‍🦲' => 'mann: hudtype 1–2, skallet',
    '👨🏼‍🦲' => 'mann: hudtype 3, skallet',
    '👨🏽‍🦲' => 'mann: hudtype 4, skallet',
    '👨🏾‍🦲' => 'mann: hudtype 5, skallet',
    '👨🏿‍🦲' => 'mann: hudtype 6, skallet',
    '🧔🏻‍♀' => 'kvinne: hudtype 1–2, skjegg',
    '🧔🏼‍♀' => 'kvinne: hudtype 3, skjegg',
    '🧔🏽‍♀' => 'kvinne: hudtype 4, skjegg',
    '🧔🏾‍♀' => 'kvinne: hudtype 5, skjegg',
    '🧔🏿‍♀' => 'kvinne: hudtype 6, skjegg',
    '👱🏻‍♀' => 'kvinne: hudtype 1–2, blond',
    '👱🏼‍♀' => 'kvinne: hudtype 3, blond',
    '👱🏽‍♀' => 'kvinne: hudtype 4, blond',
    '👱🏾‍♀' => 'kvinne: hudtype 5, blond',
    '👱🏿‍♀' => 'kvinne: hudtype 6, blond',
    '👩🏻‍🦰' => 'kvinne: hudtype 1–2, rødt hår',
    '👩🏼‍🦰' => 'kvinne: hudtype 3, rødt hår',
    '👩🏽‍🦰' => 'kvinne: hudtype 4, rødt hår',
    '👩🏾‍🦰' => 'kvinne: hudtype 5, rødt hår',
    '👩🏿‍🦰' => 'kvinne: hudtype 6, rødt hår',
    '👩🏻‍🦱' => 'kvinne: hudtype 1–2, kruset hår',
    '👩🏼‍🦱' => 'kvinne: hudtype 3, kruset hår',
    '👩🏽‍🦱' => 'kvinne: hudtype 4, kruset hår',
    '👩🏾‍🦱' => 'kvinne: hudtype 5, kruset hår',
    '👩🏿‍🦱' => 'kvinne: hudtype 6, kruset hår',
    '👩🏻‍🦳' => 'kvinne: hudtype 1–2, grått hår',
    '👩🏼‍🦳' => 'kvinne: hudtype 3, grått hår',
    '👩🏽‍🦳' => 'kvinne: hudtype 4, grått hår',
    '👩🏾‍🦳' => 'kvinne: hudtype 5, grått hår',
    '👩🏿‍🦳' => 'kvinne: hudtype 6, grått hår',
    '👩🏻‍🦲' => 'kvinne: hudtype 1–2, skallet',
    '👩🏼‍🦲' => 'kvinne: hudtype 3, skallet',
    '👩🏽‍🦲' => 'kvinne: hudtype 4, skallet',
    '👩🏾‍🦲' => 'kvinne: hudtype 5, skallet',
    '👩🏿‍🦲' => 'kvinne: hudtype 6, skallet',
    '🙍🏻‍♂' => 'mann som rynker brynene: hudtype 1–2',
    '🙍🏼‍♂' => 'mann som rynker brynene: hudtype 3',
    '🙍🏽‍♂' => 'mann som rynker brynene: hudtype 4',
    '🙍🏾‍♂' => 'mann som rynker brynene: hudtype 5',
    '🙍🏿‍♂' => 'mann som rynker brynene: hudtype 6',
    '🙍🏻‍♀' => 'kvinne som rynker brynene: hudtype 1–2',
    '🙍🏼‍♀' => 'kvinne som rynker brynene: hudtype 3',
    '🙍🏽‍♀' => 'kvinne som rynker brynene: hudtype 4',
    '🙍🏾‍♀' => 'kvinne som rynker brynene: hudtype 5',
    '🙍🏿‍♀' => 'kvinne som rynker brynene: hudtype 6',
    '🙎🏻‍♂' => 'mann som furter: hudtype 1–2',
    '🙎🏼‍♂' => 'mann som furter: hudtype 3',
    '🙎🏽‍♂' => 'mann som furter: hudtype 4',
    '🙎🏾‍♂' => 'mann som furter: hudtype 5',
    '🙎🏿‍♂' => 'mann som furter: hudtype 6',
    '🙎🏻‍♀' => 'kvinne som furter: hudtype 1–2',
    '🙎🏼‍♀' => 'kvinne som furter: hudtype 3',
    '🙎🏽‍♀' => 'kvinne som furter: hudtype 4',
    '🙎🏾‍♀' => 'kvinne som furter: hudtype 5',
    '🙎🏿‍♀' => 'kvinne som furter: hudtype 6',
    '🙅🏻‍♂' => 'mann som gestikulerer NEI: hudtype 1–2',
    '🙅🏼‍♂' => 'mann som gestikulerer NEI: hudtype 3',
    '🙅🏽‍♂' => 'mann som gestikulerer NEI: hudtype 4',
    '🙅🏾‍♂' => 'mann som gestikulerer NEI: hudtype 5',
    '🙅🏿‍♂' => 'mann som gestikulerer NEI: hudtype 6',
    '🙅🏻‍♀' => 'kvinne som gestikulerer NEI: hudtype 1–2',
    '🙅🏼‍♀' => 'kvinne som gestikulerer NEI: hudtype 3',
    '🙅🏽‍♀' => 'kvinne som gestikulerer NEI: hudtype 4',
    '🙅🏾‍♀' => 'kvinne som gestikulerer NEI: hudtype 5',
    '🙅🏿‍♀' => 'kvinne som gestikulerer NEI: hudtype 6',
    '🙆🏻‍♂' => 'mann som gestikulerer OK: hudtype 1–2',
    '🙆🏼‍♂' => 'mann som gestikulerer OK: hudtype 3',
    '🙆🏽‍♂' => 'mann som gestikulerer OK: hudtype 4',
    '🙆🏾‍♂' => 'mann som gestikulerer OK: hudtype 5',
    '🙆🏿‍♂' => 'mann som gestikulerer OK: hudtype 6',
    '🙆🏻‍♀' => 'kvinne som gestikulerer OK: hudtype 1–2',
    '🙆🏼‍♀' => 'kvinne som gestikulerer OK: hudtype 3',
    '🙆🏽‍♀' => 'kvinne som gestikulerer OK: hudtype 4',
    '🙆🏾‍♀' => 'kvinne som gestikulerer OK: hudtype 5',
    '🙆🏿‍♀' => 'kvinne som gestikulerer OK: hudtype 6',
    '💁🏻‍♂' => 'hjelpende mann: hudtype 1–2',
    '💁🏼‍♂' => 'hjelpende mann: hudtype 3',
    '💁🏽‍♂' => 'hjelpende mann: hudtype 4',
    '💁🏾‍♂' => 'hjelpende mann: hudtype 5',
    '💁🏿‍♂' => 'hjelpende mann: hudtype 6',
    '💁🏻‍♀' => 'hjelpende kvinne: hudtype 1–2',
    '💁🏼‍♀' => 'hjelpende kvinne: hudtype 3',
    '💁🏽‍♀' => 'hjelpende kvinne: hudtype 4',
    '💁🏾‍♀' => 'hjelpende kvinne: hudtype 5',
    '💁🏿‍♀' => 'hjelpende kvinne: hudtype 6',
    '🙋🏻‍♂' => 'mann som rekker opp hånden: hudtype 1–2',
    '🙋🏼‍♂' => 'mann som rekker opp hånden: hudtype 3',
    '🙋🏽‍♂' => 'mann som rekker opp hånden: hudtype 4',
    '🙋🏾‍♂' => 'mann som rekker opp hånden: hudtype 5',
    '🙋🏿‍♂' => 'mann som rekker opp hånden: hudtype 6',
    '🙋🏻‍♀' => 'kvinne som rekker opp hånden: hudtype 1–2',
    '🙋🏼‍♀' => 'kvinne som rekker opp hånden: hudtype 3',
    '🙋🏽‍♀' => 'kvinne som rekker opp hånden: hudtype 4',
    '🙋🏾‍♀' => 'kvinne som rekker opp hånden: hudtype 5',
    '🙋🏿‍♀' => 'kvinne som rekker opp hånden: hudtype 6',
    '🧏🏻‍♂' => 'døv mann: hudtype 1–2',
    '🧏🏼‍♂' => 'døv mann: hudtype 3',
    '🧏🏽‍♂' => 'døv mann: hudtype 4',
    '🧏🏾‍♂' => 'døv mann: hudtype 5',
    '🧏🏿‍♂' => 'døv mann: hudtype 6',
    '🧏🏻‍♀' => 'døv kvinne: hudtype 1–2',
    '🧏🏼‍♀' => 'døv kvinne: hudtype 3',
    '🧏🏽‍♀' => 'døv kvinne: hudtype 4',
    '🧏🏾‍♀' => 'døv kvinne: hudtype 5',
    '🧏🏿‍♀' => 'døv kvinne: hudtype 6',
    '🙇🏻‍♂' => 'bukkende mann: hudtype 1–2',
    '🙇🏼‍♂' => 'bukkende mann: hudtype 3',
    '🙇🏽‍♂' => 'bukkende mann: hudtype 4',
    '🙇🏾‍♂' => 'bukkende mann: hudtype 5',
    '🙇🏿‍♂' => 'bukkende mann: hudtype 6',
    '🙇🏻‍♀' => 'bukkende kvinne: hudtype 1–2',
    '🙇🏼‍♀' => 'bukkende kvinne: hudtype 3',
    '🙇🏽‍♀' => 'bukkende kvinne: hudtype 4',
    '🙇🏾‍♀' => 'bukkende kvinne: hudtype 5',
    '🙇🏿‍♀' => 'bukkende kvinne: hudtype 6',
    '🤦🏻‍♂' => 'mann som slår hånden mot pannen: hudtype 1–2',
    '🤦🏼‍♂' => 'mann som slår hånden mot pannen: hudtype 3',
    '🤦🏽‍♂' => 'mann som slår hånden mot pannen: hudtype 4',
    '🤦🏾‍♂' => 'mann som slår hånden mot pannen: hudtype 5',
    '🤦🏿‍♂' => 'mann som slår hånden mot pannen: hudtype 6',
    '🤦🏻‍♀' => 'kvinne som slår hånden mot pannen: hudtype 1–2',
    '🤦🏼‍♀' => 'kvinne som slår hånden mot pannen: hudtype 3',
    '🤦🏽‍♀' => 'kvinne som slår hånden mot pannen: hudtype 4',
    '🤦🏾‍♀' => 'kvinne som slår hånden mot pannen: hudtype 5',
    '🤦🏿‍♀' => 'kvinne som slår hånden mot pannen: hudtype 6',
    '🤷🏻‍♂' => 'mann som trekker på skuldrene: hudtype 1–2',
    '🤷🏼‍♂' => 'mann som trekker på skuldrene: hudtype 3',
    '🤷🏽‍♂' => 'mann som trekker på skuldrene: hudtype 4',
    '🤷🏾‍♂' => 'mann som trekker på skuldrene: hudtype 5',
    '🤷🏿‍♂' => 'mann som trekker på skuldrene: hudtype 6',
    '🤷🏻‍♀' => 'kvinne som trekker på skuldrene: hudtype 1–2',
    '🤷🏼‍♀' => 'kvinne som trekker på skuldrene: hudtype 3',
    '🤷🏽‍♀' => 'kvinne som trekker på skuldrene: hudtype 4',
    '🤷🏾‍♀' => 'kvinne som trekker på skuldrene: hudtype 5',
    '🤷🏿‍♀' => 'kvinne som trekker på skuldrene: hudtype 6',
    '🧑🏻‍⚕' => 'helsearbeider: hudtype 1–2',
    '🧑🏼‍⚕' => 'helsearbeider: hudtype 3',
    '🧑🏽‍⚕' => 'helsearbeider: hudtype 4',
    '🧑🏾‍⚕' => 'helsearbeider: hudtype 5',
    '🧑🏿‍⚕' => 'helsearbeider: hudtype 6',
    '👨🏻‍⚕' => 'mannlig helsearbeider: hudtype 1–2',
    '👨🏼‍⚕' => 'mannlig helsearbeider: hudtype 3',
    '👨🏽‍⚕' => 'mannlig helsearbeider: hudtype 4',
    '👨🏾‍⚕' => 'mannlig helsearbeider: hudtype 5',
    '👨🏿‍⚕' => 'mannlig helsearbeider: hudtype 6',
    '👩🏻‍⚕' => 'kvinnelig helsearbeider: hudtype 1–2',
    '👩🏼‍⚕' => 'kvinnelig helsearbeider: hudtype 3',
    '👩🏽‍⚕' => 'kvinnelig helsearbeider: hudtype 4',
    '👩🏾‍⚕' => 'kvinnelig helsearbeider: hudtype 5',
    '👩🏿‍⚕' => 'kvinnelig helsearbeider: hudtype 6',
    '🧑🏻‍🎓' => 'student: hudtype 1–2',
    '🧑🏼‍🎓' => 'student: hudtype 3',
    '🧑🏽‍🎓' => 'student: hudtype 4',
    '🧑🏾‍🎓' => 'student: hudtype 5',
    '🧑🏿‍🎓' => 'student: hudtype 6',
    '👨🏻‍🎓' => 'mannlig student: hudtype 1–2',
    '👨🏼‍🎓' => 'mannlig student: hudtype 3',
    '👨🏽‍🎓' => 'mannlig student: hudtype 4',
    '👨🏾‍🎓' => 'mannlig student: hudtype 5',
    '👨🏿‍🎓' => 'mannlig student: hudtype 6',
    '👩🏻‍🎓' => 'kvinnelig student: hudtype 1–2',
    '👩🏼‍🎓' => 'kvinnelig student: hudtype 3',
    '👩🏽‍🎓' => 'kvinnelig student: hudtype 4',
    '👩🏾‍🎓' => 'kvinnelig student: hudtype 5',
    '👩🏿‍🎓' => 'kvinnelig student: hudtype 6',
    '🧑🏻‍🏫' => 'lærer: hudtype 1–2',
    '🧑🏼‍🏫' => 'lærer: hudtype 3',
    '🧑🏽‍🏫' => 'lærer: hudtype 4',
    '🧑🏾‍🏫' => 'lærer: hudtype 5',
    '🧑🏿‍🏫' => 'lærer: hudtype 6',
    '👨🏻‍🏫' => 'mannlig lærer: hudtype 1–2',
    '👨🏼‍🏫' => 'mannlig lærer: hudtype 3',
    '👨🏽‍🏫' => 'mannlig lærer: hudtype 4',
    '👨🏾‍🏫' => 'mannlig lærer: hudtype 5',
    '👨🏿‍🏫' => 'mannlig lærer: hudtype 6',
    '👩🏻‍🏫' => 'kvinnelig lærer: hudtype 1–2',
    '👩🏼‍🏫' => 'kvinnelig lærer: hudtype 3',
    '👩🏽‍🏫' => 'kvinnelig lærer: hudtype 4',
    '👩🏾‍🏫' => 'kvinnelig lærer: hudtype 5',
    '👩🏿‍🏫' => 'kvinnelig lærer: hudtype 6',
    '🧑🏻‍⚖' => 'dommer: hudtype 1–2',
    '🧑🏼‍⚖' => 'dommer: hudtype 3',
    '🧑🏽‍⚖' => 'dommer: hudtype 4',
    '🧑🏾‍⚖' => 'dommer: hudtype 5',
    '🧑🏿‍⚖' => 'dommer: hudtype 6',
    '👨🏻‍⚖' => 'mannlig dommer: hudtype 1–2',
    '👨🏼‍⚖' => 'mannlig dommer: hudtype 3',
    '👨🏽‍⚖' => 'mannlig dommer: hudtype 4',
    '👨🏾‍⚖' => 'mannlig dommer: hudtype 5',
    '👨🏿‍⚖' => 'mannlig dommer: hudtype 6',
    '👩🏻‍⚖' => 'kvinnelig dommer: hudtype 1–2',
    '👩🏼‍⚖' => 'kvinnelig dommer: hudtype 3',
    '👩🏽‍⚖' => 'kvinnelig dommer: hudtype 4',
    '👩🏾‍⚖' => 'kvinnelig dommer: hudtype 5',
    '👩🏿‍⚖' => 'kvinnelig dommer: hudtype 6',
    '🧑🏻‍🌾' => 'gårdbruker: hudtype 1–2',
    '🧑🏼‍🌾' => 'gårdbruker: hudtype 3',
    '🧑🏽‍🌾' => 'gårdbruker: hudtype 4',
    '🧑🏾‍🌾' => 'gårdbruker: hudtype 5',
    '🧑🏿‍🌾' => 'gårdbruker: hudtype 6',
    '👨🏻‍🌾' => 'mannlig gårdbruker: hudtype 1–2',
    '👨🏼‍🌾' => 'mannlig gårdbruker: hudtype 3',
    '👨🏽‍🌾' => 'mannlig gårdbruker: hudtype 4',
    '👨🏾‍🌾' => 'mannlig gårdbruker: hudtype 5',
    '👨🏿‍🌾' => 'mannlig gårdbruker: hudtype 6',
    '👩🏻‍🌾' => 'kvinnelig gårdbruker: hudtype 1–2',
    '👩🏼‍🌾' => 'kvinnelig gårdbruker: hudtype 3',
    '👩🏽‍🌾' => 'kvinnelig gårdbruker: hudtype 4',
    '👩🏾‍🌾' => 'kvinnelig gårdbruker: hudtype 5',
    '👩🏿‍🌾' => 'kvinnelig gårdbruker: hudtype 6',
    '🧑🏻‍🍳' => 'kokk: hudtype 1–2',
    '🧑🏼‍🍳' => 'kokk: hudtype 3',
    '🧑🏽‍🍳' => 'kokk: hudtype 4',
    '🧑🏾‍🍳' => 'kokk: hudtype 5',
    '🧑🏿‍🍳' => 'kokk: hudtype 6',
    '👨🏻‍🍳' => 'mannlig kokk: hudtype 1–2',
    '👨🏼‍🍳' => 'mannlig kokk: hudtype 3',
    '👨🏽‍🍳' => 'mannlig kokk: hudtype 4',
    '👨🏾‍🍳' => 'mannlig kokk: hudtype 5',
    '👨🏿‍🍳' => 'mannlig kokk: hudtype 6',
    '👩🏻‍🍳' => 'kvinnelig kokk: hudtype 1–2',
    '👩🏼‍🍳' => 'kvinnelig kokk: hudtype 3',
    '👩🏽‍🍳' => 'kvinnelig kokk: hudtype 4',
    '👩🏾‍🍳' => 'kvinnelig kokk: hudtype 5',
    '👩🏿‍🍳' => 'kvinnelig kokk: hudtype 6',
    '🧑🏻‍🔧' => 'mekaniker: hudtype 1–2',
    '🧑🏼‍🔧' => 'mekaniker: hudtype 3',
    '🧑🏽‍🔧' => 'mekaniker: hudtype 4',
    '🧑🏾‍🔧' => 'mekaniker: hudtype 5',
    '🧑🏿‍🔧' => 'mekaniker: hudtype 6',
    '👨🏻‍🔧' => 'mannlig mekaniker: hudtype 1–2',
    '👨🏼‍🔧' => 'mannlig mekaniker: hudtype 3',
    '👨🏽‍🔧' => 'mannlig mekaniker: hudtype 4',
    '👨🏾‍🔧' => 'mannlig mekaniker: hudtype 5',
    '👨🏿‍🔧' => 'mannlig mekaniker: hudtype 6',
    '👩🏻‍🔧' => 'kvinnelig mekaniker: hudtype 1–2',
    '👩🏼‍🔧' => 'kvinnelig mekaniker: hudtype 3',
    '👩🏽‍🔧' => 'kvinnelig mekaniker: hudtype 4',
    '👩🏾‍🔧' => 'kvinnelig mekaniker: hudtype 5',
    '👩🏿‍🔧' => 'kvinnelig mekaniker: hudtype 6',
    '🧑🏻‍🏭' => 'industriarbeider: hudtype 1–2',
    '🧑🏼‍🏭' => 'industriarbeider: hudtype 3',
    '🧑🏽‍🏭' => 'industriarbeider: hudtype 4',
    '🧑🏾‍🏭' => 'industriarbeider: hudtype 5',
    '🧑🏿‍🏭' => 'industriarbeider: hudtype 6',
    '👨🏻‍🏭' => 'mannlig industriarbeider: hudtype 1–2',
    '👨🏼‍🏭' => 'mannlig industriarbeider: hudtype 3',
    '👨🏽‍🏭' => 'mannlig industriarbeider: hudtype 4',
    '👨🏾‍🏭' => 'mannlig industriarbeider: hudtype 5',
    '👨🏿‍🏭' => 'mannlig industriarbeider: hudtype 6',
    '👩🏻‍🏭' => 'kvinnelig industriarbeider: hudtype 1–2',
    '👩🏼‍🏭' => 'kvinnelig industriarbeider: hudtype 3',
    '👩🏽‍🏭' => 'kvinnelig industriarbeider: hudtype 4',
    '👩🏾‍🏭' => 'kvinnelig industriarbeider: hudtype 5',
    '👩🏿‍🏭' => 'kvinnelig industriarbeider: hudtype 6',
    '🧑🏻‍💼' => 'kontorarbeider: hudtype 1–2',
    '🧑🏼‍💼' => 'kontorarbeider: hudtype 3',
    '🧑🏽‍💼' => 'kontorarbeider: hudtype 4',
    '🧑🏾‍💼' => 'kontorarbeider: hudtype 5',
    '🧑🏿‍💼' => 'kontorarbeider: hudtype 6',
    '👨🏻‍💼' => 'mannlig kontorarbeider: hudtype 1–2',
    '👨🏼‍💼' => 'mannlig kontorarbeider: hudtype 3',
    '👨🏽‍💼' => 'mannlig kontorarbeider: hudtype 4',
    '👨🏾‍💼' => 'mannlig kontorarbeider: hudtype 5',
    '👨🏿‍💼' => 'mannlig kontorarbeider: hudtype 6',
    '👩🏻‍💼' => 'kvinnelig kontorarbeider: hudtype 1–2',
    '👩🏼‍💼' => 'kvinnelig kontorarbeider: hudtype 3',
    '👩🏽‍💼' => 'kvinnelig kontorarbeider: hudtype 4',
    '👩🏾‍💼' => 'kvinnelig kontorarbeider: hudtype 5',
    '👩🏿‍💼' => 'kvinnelig kontorarbeider: hudtype 6',
    '🧑🏻‍🔬' => 'forsker: hudtype 1–2',
    '🧑🏼‍🔬' => 'forsker: hudtype 3',
    '🧑🏽‍🔬' => 'forsker: hudtype 4',
    '🧑🏾‍🔬' => 'forsker: hudtype 5',
    '🧑🏿‍🔬' => 'forsker: hudtype 6',
    '👨🏻‍🔬' => 'mannlig forsker: hudtype 1–2',
    '👨🏼‍🔬' => 'mannlig forsker: hudtype 3',
    '👨🏽‍🔬' => 'mannlig forsker: hudtype 4',
    '👨🏾‍🔬' => 'mannlig forsker: hudtype 5',
    '👨🏿‍🔬' => 'mannlig forsker: hudtype 6',
    '👩🏻‍🔬' => 'kvinnelig forsker: hudtype 1–2',
    '👩🏼‍🔬' => 'kvinnelig forsker: hudtype 3',
    '👩🏽‍🔬' => 'kvinnelig forsker: hudtype 4',
    '👩🏾‍🔬' => 'kvinnelig forsker: hudtype 5',
    '👩🏿‍🔬' => 'kvinnelig forsker: hudtype 6',
    '🧑🏻‍💻' => 'IT-ekspert: hudtype 1–2',
    '🧑🏼‍💻' => 'IT-ekspert: hudtype 3',
    '🧑🏽‍💻' => 'IT-ekspert: hudtype 4',
    '🧑🏾‍💻' => 'IT-ekspert: hudtype 5',
    '🧑🏿‍💻' => 'IT-ekspert: hudtype 6',
    '👨🏻‍💻' => 'mannlig IT-ekspert: hudtype 1–2',
    '👨🏼‍💻' => 'mannlig IT-ekspert: hudtype 3',
    '👨🏽‍💻' => 'mannlig IT-ekspert: hudtype 4',
    '👨🏾‍💻' => 'mannlig IT-ekspert: hudtype 5',
    '👨🏿‍💻' => 'mannlig IT-ekspert: hudtype 6',
    '👩🏻‍💻' => 'kvinnelig IT-ekspert: hudtype 1–2',
    '👩🏼‍💻' => 'kvinnelig IT-ekspert: hudtype 3',
    '👩🏽‍💻' => 'kvinnelig IT-ekspert: hudtype 4',
    '👩🏾‍💻' => 'kvinnelig IT-ekspert: hudtype 5',
    '👩🏿‍💻' => 'kvinnelig IT-ekspert: hudtype 6',
    '🧑🏻‍🎤' => 'artist: hudtype 1–2',
    '🧑🏼‍🎤' => 'artist: hudtype 3',
    '🧑🏽‍🎤' => 'artist: hudtype 4',
    '🧑🏾‍🎤' => 'artist: hudtype 5',
    '🧑🏿‍🎤' => 'artist: hudtype 6',
    '👨🏻‍🎤' => 'mannlig artist: hudtype 1–2',
    '👨🏼‍🎤' => 'mannlig artist: hudtype 3',
    '👨🏽‍🎤' => 'mannlig artist: hudtype 4',
    '👨🏾‍🎤' => 'mannlig artist: hudtype 5',
    '👨🏿‍🎤' => 'mannlig artist: hudtype 6',
    '👩🏻‍🎤' => 'kvinnelig artist: hudtype 1–2',
    '👩🏼‍🎤' => 'kvinnelig artist: hudtype 3',
    '👩🏽‍🎤' => 'kvinnelig artist: hudtype 4',
    '👩🏾‍🎤' => 'kvinnelig artist: hudtype 5',
    '👩🏿‍🎤' => 'kvinnelig artist: hudtype 6',
    '🧑🏻‍🎨' => 'kunstner: hudtype 1–2',
    '🧑🏼‍🎨' => 'kunstner: hudtype 3',
    '🧑🏽‍🎨' => 'kunstner: hudtype 4',
    '🧑🏾‍🎨' => 'kunstner: hudtype 5',
    '🧑🏿‍🎨' => 'kunstner: hudtype 6',
    '👨🏻‍🎨' => 'mannlig kunstner: hudtype 1–2',
    '👨🏼‍🎨' => 'mannlig kunstner: hudtype 3',
    '👨🏽‍🎨' => 'mannlig kunstner: hudtype 4',
    '👨🏾‍🎨' => 'mannlig kunstner: hudtype 5',
    '👨🏿‍🎨' => 'mannlig kunstner: hudtype 6',
    '👩🏻‍🎨' => 'kvinnelig kunstner: hudtype 1–2',
    '👩🏼‍🎨' => 'kvinnelig kunstner: hudtype 3',
    '👩🏽‍🎨' => 'kvinnelig kunstner: hudtype 4',
    '👩🏾‍🎨' => 'kvinnelig kunstner: hudtype 5',
    '👩🏿‍🎨' => 'kvinnelig kunstner: hudtype 6',
    '🧑🏻‍✈' => 'pilot: hudtype 1–2',
    '🧑🏼‍✈' => 'pilot: hudtype 3',
    '🧑🏽‍✈' => 'pilot: hudtype 4',
    '🧑🏾‍✈' => 'pilot: hudtype 5',
    '🧑🏿‍✈' => 'pilot: hudtype 6',
    '👨🏻‍✈' => 'mannlig pilot: hudtype 1–2',
    '👨🏼‍✈' => 'mannlig pilot: hudtype 3',
    '👨🏽‍✈' => 'mannlig pilot: hudtype 4',
    '👨🏾‍✈' => 'mannlig pilot: hudtype 5',
    '👨🏿‍✈' => 'mannlig pilot: hudtype 6',
    '👩🏻‍✈' => 'kvinnelig pilot: hudtype 1–2',
    '👩🏼‍✈' => 'kvinnelig pilot: hudtype 3',
    '👩🏽‍✈' => 'kvinnelig pilot: hudtype 4',
    '👩🏾‍✈' => 'kvinnelig pilot: hudtype 5',
    '👩🏿‍✈' => 'kvinnelig pilot: hudtype 6',
    '🧑🏻‍🚀' => 'astronaut: hudtype 1–2',
    '🧑🏼‍🚀' => 'astronaut: hudtype 3',
    '🧑🏽‍🚀' => 'astronaut: hudtype 4',
    '🧑🏾‍🚀' => 'astronaut: hudtype 5',
    '🧑🏿‍🚀' => 'astronaut: hudtype 6',
    '👨🏻‍🚀' => 'mannlig astronaut: hudtype 1–2',
    '👨🏼‍🚀' => 'mannlig astronaut: hudtype 3',
    '👨🏽‍🚀' => 'mannlig astronaut: hudtype 4',
    '👨🏾‍🚀' => 'mannlig astronaut: hudtype 5',
    '👨🏿‍🚀' => 'mannlig astronaut: hudtype 6',
    '👩🏻‍🚀' => 'kvinnelig astronaut: hudtype 1–2',
    '👩🏼‍🚀' => 'kvinnelig astronaut: hudtype 3',
    '👩🏽‍🚀' => 'kvinnelig astronaut: hudtype 4',
    '👩🏾‍🚀' => 'kvinnelig astronaut: hudtype 5',
    '👩🏿‍🚀' => 'kvinnelig astronaut: hudtype 6',
    '🧑🏻‍🚒' => 'brannkonstabel: hudtype 1–2',
    '🧑🏼‍🚒' => 'brannkonstabel: hudtype 3',
    '🧑🏽‍🚒' => 'brannkonstabel: hudtype 4',
    '🧑🏾‍🚒' => 'brannkonstabel: hudtype 5',
    '🧑🏿‍🚒' => 'brannkonstabel: hudtype 6',
    '👨🏻‍🚒' => 'mannlig brannkonstabel: hudtype 1–2',
    '👨🏼‍🚒' => 'mannlig brannkonstabel: hudtype 3',
    '👨🏽‍🚒' => 'mannlig brannkonstabel: hudtype 4',
    '👨🏾‍🚒' => 'mannlig brannkonstabel: hudtype 5',
    '👨🏿‍🚒' => 'mannlig brannkonstabel: hudtype 6',
    '👩🏻‍🚒' => 'kvinnelig brannkonstabel: hudtype 1–2',
    '👩🏼‍🚒' => 'kvinnelig brannkonstabel: hudtype 3',
    '👩🏽‍🚒' => 'kvinnelig brannkonstabel: hudtype 4',
    '👩🏾‍🚒' => 'kvinnelig brannkonstabel: hudtype 5',
    '👩🏿‍🚒' => 'kvinnelig brannkonstabel: hudtype 6',
    '👮🏻‍♂' => 'mannlig politibetjent: hudtype 1–2',
    '👮🏼‍♂' => 'mannlig politibetjent: hudtype 3',
    '👮🏽‍♂' => 'mannlig politibetjent: hudtype 4',
    '👮🏾‍♂' => 'mannlig politibetjent: hudtype 5',
    '👮🏿‍♂' => 'mannlig politibetjent: hudtype 6',
    '👮🏻‍♀' => 'kvinnelig politibetjent: hudtype 1–2',
    '👮🏼‍♀' => 'kvinnelig politibetjent: hudtype 3',
    '👮🏽‍♀' => 'kvinnelig politibetjent: hudtype 4',
    '👮🏾‍♀' => 'kvinnelig politibetjent: hudtype 5',
    '👮🏿‍♀' => 'kvinnelig politibetjent: hudtype 6',
    '🕵🏻‍♂' => 'mannlig detektiv: hudtype 1–2',
    '🕵🏼‍♂' => 'mannlig detektiv: hudtype 3',
    '🕵🏽‍♂' => 'mannlig detektiv: hudtype 4',
    '🕵🏾‍♂' => 'mannlig detektiv: hudtype 5',
    '🕵🏿‍♂' => 'mannlig detektiv: hudtype 6',
    '🕵🏻‍♀' => 'kvinnelig detektiv: hudtype 1–2',
    '🕵🏼‍♀' => 'kvinnelig detektiv: hudtype 3',
    '🕵🏽‍♀' => 'kvinnelig detektiv: hudtype 4',
    '🕵🏾‍♀' => 'kvinnelig detektiv: hudtype 5',
    '🕵🏿‍♀' => 'kvinnelig detektiv: hudtype 6',
    '💂🏻‍♂' => 'mannlig gardist: hudtype 1–2',
    '💂🏼‍♂' => 'mannlig gardist: hudtype 3',
    '💂🏽‍♂' => 'mannlig gardist: hudtype 4',
    '💂🏾‍♂' => 'mannlig gardist: hudtype 5',
    '💂🏿‍♂' => 'mannlig gardist: hudtype 6',
    '💂🏻‍♀' => 'kvinnelig gardist: hudtype 1–2',
    '💂🏼‍♀' => 'kvinnelig gardist: hudtype 3',
    '💂🏽‍♀' => 'kvinnelig gardist: hudtype 4',
    '💂🏾‍♀' => 'kvinnelig gardist: hudtype 5',
    '💂🏿‍♀' => 'kvinnelig gardist: hudtype 6',
    '👷🏻‍♂' => 'mannlig anleggsarbeider: hudtype 1–2',
    '👷🏼‍♂' => 'mannlig anleggsarbeider: hudtype 3',
    '👷🏽‍♂' => 'mannlig anleggsarbeider: hudtype 4',
    '👷🏾‍♂' => 'mannlig anleggsarbeider: hudtype 5',
    '👷🏿‍♂' => 'mannlig anleggsarbeider: hudtype 6',
    '👷🏻‍♀' => 'kvinnelig anleggsarbeider: hudtype 1–2',
    '👷🏼‍♀' => 'kvinnelig anleggsarbeider: hudtype 3',
    '👷🏽‍♀' => 'kvinnelig anleggsarbeider: hudtype 4',
    '👷🏾‍♀' => 'kvinnelig anleggsarbeider: hudtype 5',
    '👷🏿‍♀' => 'kvinnelig anleggsarbeider: hudtype 6',
    '👳🏻‍♂' => 'turbankledd mann: hudtype 1–2',
    '👳🏼‍♂' => 'turbankledd mann: hudtype 3',
    '👳🏽‍♂' => 'turbankledd mann: hudtype 4',
    '👳🏾‍♂' => 'turbankledd mann: hudtype 5',
    '👳🏿‍♂' => 'turbankledd mann: hudtype 6',
    '👳🏻‍♀' => 'turbankledd kvinne: hudtype 1–2',
    '👳🏼‍♀' => 'turbankledd kvinne: hudtype 3',
    '👳🏽‍♀' => 'turbankledd kvinne: hudtype 4',
    '👳🏾‍♀' => 'turbankledd kvinne: hudtype 5',
    '👳🏿‍♀' => 'turbankledd kvinne: hudtype 6',
    '🤵🏻‍♂' => 'mann i smoking: hudtype 1–2',
    '🤵🏼‍♂' => 'mann i smoking: hudtype 3',
    '🤵🏽‍♂' => 'mann i smoking: hudtype 4',
    '🤵🏾‍♂' => 'mann i smoking: hudtype 5',
    '🤵🏿‍♂' => 'mann i smoking: hudtype 6',
    '🤵🏻‍♀' => 'kvinne i smoking: hudtype 1–2',
    '🤵🏼‍♀' => 'kvinne i smoking: hudtype 3',
    '🤵🏽‍♀' => 'kvinne i smoking: hudtype 4',
    '🤵🏾‍♀' => 'kvinne i smoking: hudtype 5',
    '🤵🏿‍♀' => 'kvinne i smoking: hudtype 6',
    '👰🏻‍♂' => 'mann med slør: hudtype 1–2',
    '👰🏼‍♂' => 'mann med slør: hudtype 3',
    '👰🏽‍♂' => 'mann med slør: hudtype 4',
    '👰🏾‍♂' => 'mann med slør: hudtype 5',
    '👰🏿‍♂' => 'mann med slør: hudtype 6',
    '👰🏻‍♀' => 'kvinne med slør: hudtype 1–2',
    '👰🏼‍♀' => 'kvinne med slør: hudtype 3',
    '👰🏽‍♀' => 'kvinne med slør: hudtype 4',
    '👰🏾‍♀' => 'kvinne med slør: hudtype 5',
    '👰🏿‍♀' => 'kvinne med slør: hudtype 6',
    '👩🏻‍🍼' => 'kvinne som mater baby: hudtype 1–2',
    '👩🏼‍🍼' => 'kvinne som mater baby: hudtype 3',
    '👩🏽‍🍼' => 'kvinne som mater baby: hudtype 4',
    '👩🏾‍🍼' => 'kvinne som mater baby: hudtype 5',
    '👩🏿‍🍼' => 'kvinne som mater baby: hudtype 6',
    '👨🏻‍🍼' => 'mann som mater baby: hudtype 1–2',
    '👨🏼‍🍼' => 'mann som mater baby: hudtype 3',
    '👨🏽‍🍼' => 'mann som mater baby: hudtype 4',
    '👨🏾‍🍼' => 'mann som mater baby: hudtype 5',
    '👨🏿‍🍼' => 'mann som mater baby: hudtype 6',
    '🧑🏻‍🍼' => 'person som mater baby: hudtype 1–2',
    '🧑🏼‍🍼' => 'person som mater baby: hudtype 3',
    '🧑🏽‍🍼' => 'person som mater baby: hudtype 4',
    '🧑🏾‍🍼' => 'person som mater baby: hudtype 5',
    '🧑🏿‍🍼' => 'person som mater baby: hudtype 6',
    '🧑🏻‍🎄' => 'julenisse: hudtype 1–2',
    '🧑🏼‍🎄' => 'julenisse: hudtype 3',
    '🧑🏽‍🎄' => 'julenisse: hudtype 4',
    '🧑🏾‍🎄' => 'julenisse: hudtype 5',
    '🧑🏿‍🎄' => 'julenisse: hudtype 6',
    '🦸🏻‍♂' => 'mannlig superhelt: hudtype 1–2',
    '🦸🏼‍♂' => 'mannlig superhelt: hudtype 3',
    '🦸🏽‍♂' => 'mannlig superhelt: hudtype 4',
    '🦸🏾‍♂' => 'mannlig superhelt: hudtype 5',
    '🦸🏿‍♂' => 'mannlig superhelt: hudtype 6',
    '🦸🏻‍♀' => 'kvinnelig superhelt: hudtype 1–2',
    '🦸🏼‍♀' => 'kvinnelig superhelt: hudtype 3',
    '🦸🏽‍♀' => 'kvinnelig superhelt: hudtype 4',
    '🦸🏾‍♀' => 'kvinnelig superhelt: hudtype 5',
    '🦸🏿‍♀' => 'kvinnelig superhelt: hudtype 6',
    '🦹🏻‍♂' => 'mannlig superskurk: hudtype 1–2',
    '🦹🏼‍♂' => 'mannlig superskurk: hudtype 3',
    '🦹🏽‍♂' => 'mannlig superskurk: hudtype 4',
    '🦹🏾‍♂' => 'mannlig superskurk: hudtype 5',
    '🦹🏿‍♂' => 'mannlig superskurk: hudtype 6',
    '🦹🏻‍♀' => 'kvinnelig superskurk: hudtype 1–2',
    '🦹🏼‍♀' => 'kvinnelig superskurk: hudtype 3',
    '🦹🏽‍♀' => 'kvinnelig superskurk: hudtype 4',
    '🦹🏾‍♀' => 'kvinnelig superskurk: hudtype 5',
    '🦹🏿‍♀' => 'kvinnelig superskurk: hudtype 6',
    '🧙🏻‍♂' => 'trollmann: hudtype 1–2',
    '🧙🏼‍♂' => 'trollmann: hudtype 3',
    '🧙🏽‍♂' => 'trollmann: hudtype 4',
    '🧙🏾‍♂' => 'trollmann: hudtype 5',
    '🧙🏿‍♂' => 'trollmann: hudtype 6',
    '🧙🏻‍♀' => 'trollkvinne: hudtype 1–2',
    '🧙🏼‍♀' => 'trollkvinne: hudtype 3',
    '🧙🏽‍♀' => 'trollkvinne: hudtype 4',
    '🧙🏾‍♀' => 'trollkvinne: hudtype 5',
    '🧙🏿‍♀' => 'trollkvinne: hudtype 6',
    '🧚🏻‍♂' => 'mannlig fe: hudtype 1–2',
    '🧚🏼‍♂' => 'mannlig fe: hudtype 3',
    '🧚🏽‍♂' => 'mannlig fe: hudtype 4',
    '🧚🏾‍♂' => 'mannlig fe: hudtype 5',
    '🧚🏿‍♂' => 'mannlig fe: hudtype 6',
    '🧚🏻‍♀' => 'kvinnelig fe: hudtype 1–2',
    '🧚🏼‍♀' => 'kvinnelig fe: hudtype 3',
    '🧚🏽‍♀' => 'kvinnelig fe: hudtype 4',
    '🧚🏾‍♀' => 'kvinnelig fe: hudtype 5',
    '🧚🏿‍♀' => 'kvinnelig fe: hudtype 6',
    '🧛🏻‍♂' => 'mannlig vampyr: hudtype 1–2',
    '🧛🏼‍♂' => 'mannlig vampyr: hudtype 3',
    '🧛🏽‍♂' => 'mannlig vampyr: hudtype 4',
    '🧛🏾‍♂' => 'mannlig vampyr: hudtype 5',
    '🧛🏿‍♂' => 'mannlig vampyr: hudtype 6',
    '🧛🏻‍♀' => 'kvinnelig vampyr: hudtype 1–2',
    '🧛🏼‍♀' => 'kvinnelig vampyr: hudtype 3',
    '🧛🏽‍♀' => 'kvinnelig vampyr: hudtype 4',
    '🧛🏾‍♀' => 'kvinnelig vampyr: hudtype 5',
    '🧛🏿‍♀' => 'kvinnelig vampyr: hudtype 6',
    '🧜🏻‍♂' => 'havmann: hudtype 1–2',
    '🧜🏼‍♂' => 'havmann: hudtype 3',
    '🧜🏽‍♂' => 'havmann: hudtype 4',
    '🧜🏾‍♂' => 'havmann: hudtype 5',
    '🧜🏿‍♂' => 'havmann: hudtype 6',
    '🧜🏻‍♀' => 'havfrue: hudtype 1–2',
    '🧜🏼‍♀' => 'havfrue: hudtype 3',
    '🧜🏽‍♀' => 'havfrue: hudtype 4',
    '🧜🏾‍♀' => 'havfrue: hudtype 5',
    '🧜🏿‍♀' => 'havfrue: hudtype 6',
    '🧝🏻‍♂' => 'mannlig alv: hudtype 1–2',
    '🧝🏼‍♂' => 'mannlig alv: hudtype 3',
    '🧝🏽‍♂' => 'mannlig alv: hudtype 4',
    '🧝🏾‍♂' => 'mannlig alv: hudtype 5',
    '🧝🏿‍♂' => 'mannlig alv: hudtype 6',
    '🧝🏻‍♀' => 'kvinnelig alv: hudtype 1–2',
    '🧝🏼‍♀' => 'kvinnelig alv: hudtype 3',
    '🧝🏽‍♀' => 'kvinnelig alv: hudtype 4',
    '🧝🏾‍♀' => 'kvinnelig alv: hudtype 5',
    '🧝🏿‍♀' => 'kvinnelig alv: hudtype 6',
    '💆🏻‍♂' => 'mann som får ansiktsmassasje: hudtype 1–2',
    '💆🏼‍♂' => 'mann som får ansiktsmassasje: hudtype 3',
    '💆🏽‍♂' => 'mann som får ansiktsmassasje: hudtype 4',
    '💆🏾‍♂' => 'mann som får ansiktsmassasje: hudtype 5',
    '💆🏿‍♂' => 'mann som får ansiktsmassasje: hudtype 6',
    '💆🏻‍♀' => 'kvinne som får ansiktsmassasje: hudtype 1–2',
    '💆🏼‍♀' => 'kvinne som får ansiktsmassasje: hudtype 3',
    '💆🏽‍♀' => 'kvinne som får ansiktsmassasje: hudtype 4',
    '💆🏾‍♀' => 'kvinne som får ansiktsmassasje: hudtype 5',
    '💆🏿‍♀' => 'kvinne som får ansiktsmassasje: hudtype 6',
    '💇🏻‍♂' => 'mann som får hårklipp: hudtype 1–2',
    '💇🏼‍♂' => 'mann som får hårklipp: hudtype 3',
    '💇🏽‍♂' => 'mann som får hårklipp: hudtype 4',
    '💇🏾‍♂' => 'mann som får hårklipp: hudtype 5',
    '💇🏿‍♂' => 'mann som får hårklipp: hudtype 6',
    '💇🏻‍♀' => 'kvinne som får hårklipp: hudtype 1–2',
    '💇🏼‍♀' => 'kvinne som får hårklipp: hudtype 3',
    '💇🏽‍♀' => 'kvinne som får hårklipp: hudtype 4',
    '💇🏾‍♀' => 'kvinne som får hårklipp: hudtype 5',
    '💇🏿‍♀' => 'kvinne som får hårklipp: hudtype 6',
    '🚶🏻‍♂' => 'mannlig fotgjenger: hudtype 1–2',
    '🚶🏼‍♂' => 'mannlig fotgjenger: hudtype 3',
    '🚶🏽‍♂' => 'mannlig fotgjenger: hudtype 4',
    '🚶🏾‍♂' => 'mannlig fotgjenger: hudtype 5',
    '🚶🏿‍♂' => 'mannlig fotgjenger: hudtype 6',
    '🚶🏻‍♀' => 'kvinnelig fotgjenger: hudtype 1–2',
    '🚶🏼‍♀' => 'kvinnelig fotgjenger: hudtype 3',
    '🚶🏽‍♀' => 'kvinnelig fotgjenger: hudtype 4',
    '🚶🏾‍♀' => 'kvinnelig fotgjenger: hudtype 5',
    '🚶🏿‍♀' => 'kvinnelig fotgjenger: hudtype 6',
    '🚶🏻‍➡' => 'fotgjenger: hudtype 1–2, vendt mot høyre',
    '🚶🏼‍➡' => 'fotgjenger: hudtype 3, vendt mot høyre',
    '🚶🏽‍➡' => 'fotgjenger: hudtype 4, vendt mot høyre',
    '🚶🏾‍➡' => 'fotgjenger: hudtype 5, vendt mot høyre',
    '🚶🏿‍➡' => 'fotgjenger: hudtype 6, vendt mot høyre',
    '🧍🏻‍♂' => 'mann som står: hudtype 1–2',
    '🧍🏼‍♂' => 'mann som står: hudtype 3',
    '🧍🏽‍♂' => 'mann som står: hudtype 4',
    '🧍🏾‍♂' => 'mann som står: hudtype 5',
    '🧍🏿‍♂' => 'mann som står: hudtype 6',
    '🧍🏻‍♀' => 'kvinne som står: hudtype 1–2',
    '🧍🏼‍♀' => 'kvinne som står: hudtype 3',
    '🧍🏽‍♀' => 'kvinne som står: hudtype 4',
    '🧍🏾‍♀' => 'kvinne som står: hudtype 5',
    '🧍🏿‍♀' => 'kvinne som står: hudtype 6',
    '🧎🏻‍♂' => 'mann som kneler: hudtype 1–2',
    '🧎🏼‍♂' => 'mann som kneler: hudtype 3',
    '🧎🏽‍♂' => 'mann som kneler: hudtype 4',
    '🧎🏾‍♂' => 'mann som kneler: hudtype 5',
    '🧎🏿‍♂' => 'mann som kneler: hudtype 6',
    '🧎🏻‍♀' => 'kvinne som kneler: hudtype 1–2',
    '🧎🏼‍♀' => 'kvinne som kneler: hudtype 3',
    '🧎🏽‍♀' => 'kvinne som kneler: hudtype 4',
    '🧎🏾‍♀' => 'kvinne som kneler: hudtype 5',
    '🧎🏿‍♀' => 'kvinne som kneler: hudtype 6',
    '🧎🏻‍➡' => 'person som kneler: hudtype 1–2, vendt mot høyre',
    '🧎🏼‍➡' => 'person som kneler: hudtype 3, vendt mot høyre',
    '🧎🏽‍➡' => 'person som kneler: hudtype 4, vendt mot høyre',
    '🧎🏾‍➡' => 'person som kneler: hudtype 5, vendt mot høyre',
    '🧎🏿‍➡' => 'person som kneler: hudtype 6, vendt mot høyre',
    '🧑🏻‍🦯' => 'person med blindestokk: hudtype 1–2',
    '🧑🏼‍🦯' => 'person med blindestokk: hudtype 3',
    '🧑🏽‍🦯' => 'person med blindestokk: hudtype 4',
    '🧑🏾‍🦯' => 'person med blindestokk: hudtype 5',
    '🧑🏿‍🦯' => 'person med blindestokk: hudtype 6',
    '👨🏻‍🦯' => 'mann med blindestokk: hudtype 1–2',
    '👨🏼‍🦯' => 'mann med blindestokk: hudtype 3',
    '👨🏽‍🦯' => 'mann med blindestokk: hudtype 4',
    '👨🏾‍🦯' => 'mann med blindestokk: hudtype 5',
    '👨🏿‍🦯' => 'mann med blindestokk: hudtype 6',
    '👩🏻‍🦯' => 'kvinne med blindestokk: hudtype 1–2',
    '👩🏼‍🦯' => 'kvinne med blindestokk: hudtype 3',
    '👩🏽‍🦯' => 'kvinne med blindestokk: hudtype 4',
    '👩🏾‍🦯' => 'kvinne med blindestokk: hudtype 5',
    '👩🏿‍🦯' => 'kvinne med blindestokk: hudtype 6',
    '🧑🏻‍🦼' => 'person i motorisert rullestol: hudtype 1–2',
    '🧑🏼‍🦼' => 'person i motorisert rullestol: hudtype 3',
    '🧑🏽‍🦼' => 'person i motorisert rullestol: hudtype 4',
    '🧑🏾‍🦼' => 'person i motorisert rullestol: hudtype 5',
    '🧑🏿‍🦼' => 'person i motorisert rullestol: hudtype 6',
    '👨🏻‍🦼' => 'mann i motorisert rullestol: hudtype 1–2',
    '👨🏼‍🦼' => 'mann i motorisert rullestol: hudtype 3',
    '👨🏽‍🦼' => 'mann i motorisert rullestol: hudtype 4',
    '👨🏾‍🦼' => 'mann i motorisert rullestol: hudtype 5',
    '👨🏿‍🦼' => 'mann i motorisert rullestol: hudtype 6',
    '👩🏻‍🦼' => 'kvinne i motorisert rullestol: hudtype 1–2',
    '👩🏼‍🦼' => 'kvinne i motorisert rullestol: hudtype 3',
    '👩🏽‍🦼' => 'kvinne i motorisert rullestol: hudtype 4',
    '👩🏾‍🦼' => 'kvinne i motorisert rullestol: hudtype 5',
    '👩🏿‍🦼' => 'kvinne i motorisert rullestol: hudtype 6',
    '🧑🏻‍🦽' => 'person i manuell rullestol: hudtype 1–2',
    '🧑🏼‍🦽' => 'person i manuell rullestol: hudtype 3',
    '🧑🏽‍🦽' => 'person i manuell rullestol: hudtype 4',
    '🧑🏾‍🦽' => 'person i manuell rullestol: hudtype 5',
    '🧑🏿‍🦽' => 'person i manuell rullestol: hudtype 6',
    '👨🏻‍🦽' => 'mann i manuell rullestol: hudtype 1–2',
    '👨🏼‍🦽' => 'mann i manuell rullestol: hudtype 3',
    '👨🏽‍🦽' => 'mann i manuell rullestol: hudtype 4',
    '👨🏾‍🦽' => 'mann i manuell rullestol: hudtype 5',
    '👨🏿‍🦽' => 'mann i manuell rullestol: hudtype 6',
    '👩🏻‍🦽' => 'kvinne i manuell rullestol: hudtype 1–2',
    '👩🏼‍🦽' => 'kvinne i manuell rullestol: hudtype 3',
    '👩🏽‍🦽' => 'kvinne i manuell rullestol: hudtype 4',
    '👩🏾‍🦽' => 'kvinne i manuell rullestol: hudtype 5',
    '👩🏿‍🦽' => 'kvinne i manuell rullestol: hudtype 6',
    '🏃🏻‍♂' => 'mannlig løper: hudtype 1–2',
    '🏃🏼‍♂' => 'mannlig løper: hudtype 3',
    '🏃🏽‍♂' => 'mannlig løper: hudtype 4',
    '🏃🏾‍♂' => 'mannlig løper: hudtype 5',
    '🏃🏿‍♂' => 'mannlig løper: hudtype 6',
    '🏃🏻‍♀' => 'kvinnelig løper: hudtype 1–2',
    '🏃🏼‍♀' => 'kvinnelig løper: hudtype 3',
    '🏃🏽‍♀' => 'kvinnelig løper: hudtype 4',
    '🏃🏾‍♀' => 'kvinnelig løper: hudtype 5',
    '🏃🏿‍♀' => 'kvinnelig løper: hudtype 6',
    '🏃🏻‍➡' => 'løper: hudtype 1–2, vendt mot høyre',
    '🏃🏼‍➡' => 'løper: hudtype 3, vendt mot høyre',
    '🏃🏽‍➡' => 'løper: hudtype 4, vendt mot høyre',
    '🏃🏾‍➡' => 'løper: hudtype 5, vendt mot høyre',
    '🏃🏿‍➡' => 'løper: hudtype 6, vendt mot høyre',
    '👯🏻‍♀' => 'kvinner med kaninører: hudtype 1–2',
    '👯🏼‍♀' => 'kvinner med kaninører: hudtype 3',
    '👯🏽‍♀' => 'kvinner med kaninører: hudtype 4',
    '👯🏾‍♀' => 'kvinner med kaninører: hudtype 5',
    '👯🏿‍♀' => 'kvinner med kaninører: hudtype 6',
    '👯🏻‍♂' => 'menn med kaninører: hudtype 1–2',
    '👯🏼‍♂' => 'menn med kaninører: hudtype 3',
    '👯🏽‍♂' => 'menn med kaninører: hudtype 4',
    '👯🏾‍♂' => 'menn med kaninører: hudtype 5',
    '👯🏿‍♂' => 'menn med kaninører: hudtype 6',
    '🧖🏻‍♂' => 'mann i badstu: hudtype 1–2',
    '🧖🏼‍♂' => 'mann i badstu: hudtype 3',
    '🧖🏽‍♂' => 'mann i badstu: hudtype 4',
    '🧖🏾‍♂' => 'mann i badstu: hudtype 5',
    '🧖🏿‍♂' => 'mann i badstu: hudtype 6',
    '🧖🏻‍♀' => 'kvinne i badstu: hudtype 1–2',
    '🧖🏼‍♀' => 'kvinne i badstu: hudtype 3',
    '🧖🏽‍♀' => 'kvinne i badstu: hudtype 4',
    '🧖🏾‍♀' => 'kvinne i badstu: hudtype 5',
    '🧖🏿‍♀' => 'kvinne i badstu: hudtype 6',
    '🧗🏻‍♂' => 'mannlig klatrer: hudtype 1–2',
    '🧗🏼‍♂' => 'mannlig klatrer: hudtype 3',
    '🧗🏽‍♂' => 'mannlig klatrer: hudtype 4',
    '🧗🏾‍♂' => 'mannlig klatrer: hudtype 5',
    '🧗🏿‍♂' => 'mannlig klatrer: hudtype 6',
    '🧗🏻‍♀' => 'kvinnelig klatrer: hudtype 1–2',
    '🧗🏼‍♀' => 'kvinnelig klatrer: hudtype 3',
    '🧗🏽‍♀' => 'kvinnelig klatrer: hudtype 4',
    '🧗🏾‍♀' => 'kvinnelig klatrer: hudtype 5',
    '🧗🏿‍♀' => 'kvinnelig klatrer: hudtype 6',
    '🏌🏻‍♂' => 'mannlig golfspiller: hudtype 1–2',
    '🏌🏼‍♂' => 'mannlig golfspiller: hudtype 3',
    '🏌🏽‍♂' => 'mannlig golfspiller: hudtype 4',
    '🏌🏾‍♂' => 'mannlig golfspiller: hudtype 5',
    '🏌🏿‍♂' => 'mannlig golfspiller: hudtype 6',
    '🏌🏻‍♀' => 'kvinnelig golfspiller: hudtype 1–2',
    '🏌🏼‍♀' => 'kvinnelig golfspiller: hudtype 3',
    '🏌🏽‍♀' => 'kvinnelig golfspiller: hudtype 4',
    '🏌🏾‍♀' => 'kvinnelig golfspiller: hudtype 5',
    '🏌🏿‍♀' => 'kvinnelig golfspiller: hudtype 6',
    '🏄🏻‍♂' => 'mannlig surfer: hudtype 1–2',
    '🏄🏼‍♂' => 'mannlig surfer: hudtype 3',
    '🏄🏽‍♂' => 'mannlig surfer: hudtype 4',
    '🏄🏾‍♂' => 'mannlig surfer: hudtype 5',
    '🏄🏿‍♂' => 'mannlig surfer: hudtype 6',
    '🏄🏻‍♀' => 'kvinnelig surfer: hudtype 1–2',
    '🏄🏼‍♀' => 'kvinnelig surfer: hudtype 3',
    '🏄🏽‍♀' => 'kvinnelig surfer: hudtype 4',
    '🏄🏾‍♀' => 'kvinnelig surfer: hudtype 5',
    '🏄🏿‍♀' => 'kvinnelig surfer: hudtype 6',
    '🚣🏻‍♂' => 'mann i robåt: hudtype 1–2',
    '🚣🏼‍♂' => 'mann i robåt: hudtype 3',
    '🚣🏽‍♂' => 'mann i robåt: hudtype 4',
    '🚣🏾‍♂' => 'mann i robåt: hudtype 5',
    '🚣🏿‍♂' => 'mann i robåt: hudtype 6',
    '🚣🏻‍♀' => 'kvinne i robåt: hudtype 1–2',
    '🚣🏼‍♀' => 'kvinne i robåt: hudtype 3',
    '🚣🏽‍♀' => 'kvinne i robåt: hudtype 4',
    '🚣🏾‍♀' => 'kvinne i robåt: hudtype 5',
    '🚣🏿‍♀' => 'kvinne i robåt: hudtype 6',
    '🏊🏻‍♂' => 'mannlig svømmer: hudtype 1–2',
    '🏊🏼‍♂' => 'mannlig svømmer: hudtype 3',
    '🏊🏽‍♂' => 'mannlig svømmer: hudtype 4',
    '🏊🏾‍♂' => 'mannlig svømmer: hudtype 5',
    '🏊🏿‍♂' => 'mannlig svømmer: hudtype 6',
    '🏊🏻‍♀' => 'kvinnelig svømmer: hudtype 1–2',
    '🏊🏼‍♀' => 'kvinnelig svømmer: hudtype 3',
    '🏊🏽‍♀' => 'kvinnelig svømmer: hudtype 4',
    '🏊🏾‍♀' => 'kvinnelig svømmer: hudtype 5',
    '🏊🏿‍♀' => 'kvinnelig svømmer: hudtype 6',
    '⛹🏻‍♂' => 'mann med ball: hudtype 1–2',
    '⛹🏼‍♂' => 'mann med ball: hudtype 3',
    '⛹🏽‍♂' => 'mann med ball: hudtype 4',
    '⛹🏾‍♂' => 'mann med ball: hudtype 5',
    '⛹🏿‍♂' => 'mann med ball: hudtype 6',
    '⛹🏻‍♀' => 'kvinne med ball: hudtype 1–2',
    '⛹🏼‍♀' => 'kvinne med ball: hudtype 3',
    '⛹🏽‍♀' => 'kvinne med ball: hudtype 4',
    '⛹🏾‍♀' => 'kvinne med ball: hudtype 5',
    '⛹🏿‍♀' => 'kvinne med ball: hudtype 6',
    '🏋🏻‍♂' => 'mannlig vektløfter: hudtype 1–2',
    '🏋🏼‍♂' => 'mannlig vektløfter: hudtype 3',
    '🏋🏽‍♂' => 'mannlig vektløfter: hudtype 4',
    '🏋🏾‍♂' => 'mannlig vektløfter: hudtype 5',
    '🏋🏿‍♂' => 'mannlig vektløfter: hudtype 6',
    '🏋🏻‍♀' => 'kvinnelig vektløfter: hudtype 1–2',
    '🏋🏼‍♀' => 'kvinnelig vektløfter: hudtype 3',
    '🏋🏽‍♀' => 'kvinnelig vektløfter: hudtype 4',
    '🏋🏾‍♀' => 'kvinnelig vektløfter: hudtype 5',
    '🏋🏿‍♀' => 'kvinnelig vektløfter: hudtype 6',
    '🚴🏻‍♂' => 'mannlig syklist: hudtype 1–2',
    '🚴🏼‍♂' => 'mannlig syklist: hudtype 3',
    '🚴🏽‍♂' => 'mannlig syklist: hudtype 4',
    '🚴🏾‍♂' => 'mannlig syklist: hudtype 5',
    '🚴🏿‍♂' => 'mannlig syklist: hudtype 6',
    '🚴🏻‍♀' => 'kvinnelig syklist: hudtype 1–2',
    '🚴🏼‍♀' => 'kvinnelig syklist: hudtype 3',
    '🚴🏽‍♀' => 'kvinnelig syklist: hudtype 4',
    '🚴🏾‍♀' => 'kvinnelig syklist: hudtype 5',
    '🚴🏿‍♀' => 'kvinnelig syklist: hudtype 6',
    '🚵🏻‍♂' => 'mann på terrengsykkel: hudtype 1–2',
    '🚵🏼‍♂' => 'mann på terrengsykkel: hudtype 3',
    '🚵🏽‍♂' => 'mann på terrengsykkel: hudtype 4',
    '🚵🏾‍♂' => 'mann på terrengsykkel: hudtype 5',
    '🚵🏿‍♂' => 'mann på terrengsykkel: hudtype 6',
    '🚵🏻‍♀' => 'kvinne på terrengsykkel: hudtype 1–2',
    '🚵🏼‍♀' => 'kvinne på terrengsykkel: hudtype 3',
    '🚵🏽‍♀' => 'kvinne på terrengsykkel: hudtype 4',
    '🚵🏾‍♀' => 'kvinne på terrengsykkel: hudtype 5',
    '🚵🏿‍♀' => 'kvinne på terrengsykkel: hudtype 6',
    '🤸🏻‍♂' => 'mann som slår hjul: hudtype 1–2',
    '🤸🏼‍♂' => 'mann som slår hjul: hudtype 3',
    '🤸🏽‍♂' => 'mann som slår hjul: hudtype 4',
    '🤸🏾‍♂' => 'mann som slår hjul: hudtype 5',
    '🤸🏿‍♂' => 'mann som slår hjul: hudtype 6',
    '🤸🏻‍♀' => 'kvinne som slår hjul: hudtype 1–2',
    '🤸🏼‍♀' => 'kvinne som slår hjul: hudtype 3',
    '🤸🏽‍♀' => 'kvinne som slår hjul: hudtype 4',
    '🤸🏾‍♀' => 'kvinne som slår hjul: hudtype 5',
    '🤸🏿‍♀' => 'kvinne som slår hjul: hudtype 6',
    '🤼🏻‍♀' => 'kvinnelige brytere: hudtype 1–2',
    '🤼🏼‍♀' => 'kvinnelige brytere: hudtype 3',
    '🤼🏽‍♀' => 'kvinnelige brytere: hudtype 4',
    '🤼🏾‍♀' => 'kvinnelige brytere: hudtype 5',
    '🤼🏿‍♀' => 'kvinnelige brytere: hudtype 6',
    '🤼🏻‍♂' => 'mannlige brytere: hudtype 1–2',
    '🤼🏼‍♂' => 'mannlige brytere: hudtype 3',
    '🤼🏽‍♂' => 'mannlige brytere: hudtype 4',
    '🤼🏾‍♂' => 'mannlige brytere: hudtype 5',
    '🤼🏿‍♂' => 'mannlige brytere: hudtype 6',
    '🤽🏻‍♂' => 'mannlig vannpolospiller: hudtype 1–2',
    '🤽🏼‍♂' => 'mannlig vannpolospiller: hudtype 3',
    '🤽🏽‍♂' => 'mannlig vannpolospiller: hudtype 4',
    '🤽🏾‍♂' => 'mannlig vannpolospiller: hudtype 5',
    '🤽🏿‍♂' => 'mannlig vannpolospiller: hudtype 6',
    '🤽🏻‍♀' => 'kvinnelig vannpolospiller: hudtype 1–2',
    '🤽🏼‍♀' => 'kvinnelig vannpolospiller: hudtype 3',
    '🤽🏽‍♀' => 'kvinnelig vannpolospiller: hudtype 4',
    '🤽🏾‍♀' => 'kvinnelig vannpolospiller: hudtype 5',
    '🤽🏿‍♀' => 'kvinnelig vannpolospiller: hudtype 6',
    '🤾🏻‍♂' => 'mannlig håndballspiller: hudtype 1–2',
    '🤾🏼‍♂' => 'mannlig håndballspiller: hudtype 3',
    '🤾🏽‍♂' => 'mannlig håndballspiller: hudtype 4',
    '🤾🏾‍♂' => 'mannlig håndballspiller: hudtype 5',
    '🤾🏿‍♂' => 'mannlig håndballspiller: hudtype 6',
    '🤾🏻‍♀' => 'kvinnelig håndballspiller: hudtype 1–2',
    '🤾🏼‍♀' => 'kvinnelig håndballspiller: hudtype 3',
    '🤾🏽‍♀' => 'kvinnelig håndballspiller: hudtype 4',
    '🤾🏾‍♀' => 'kvinnelig håndballspiller: hudtype 5',
    '🤾🏿‍♀' => 'kvinnelig håndballspiller: hudtype 6',
    '🤹🏻‍♂' => 'mannlig sjonglør: hudtype 1–2',
    '🤹🏼‍♂' => 'mannlig sjonglør: hudtype 3',
    '🤹🏽‍♂' => 'mannlig sjonglør: hudtype 4',
    '🤹🏾‍♂' => 'mannlig sjonglør: hudtype 5',
    '🤹🏿‍♂' => 'mannlig sjonglør: hudtype 6',
    '🤹🏻‍♀' => 'kvinnelig sjonglør: hudtype 1–2',
    '🤹🏼‍♀' => 'kvinnelig sjonglør: hudtype 3',
    '🤹🏽‍♀' => 'kvinnelig sjonglør: hudtype 4',
    '🤹🏾‍♀' => 'kvinnelig sjonglør: hudtype 5',
    '🤹🏿‍♀' => 'kvinnelig sjonglør: hudtype 6',
    '🧘🏻‍♂' => 'mann i lotusstilling: hudtype 1–2',
    '🧘🏼‍♂' => 'mann i lotusstilling: hudtype 3',
    '🧘🏽‍♂' => 'mann i lotusstilling: hudtype 4',
    '🧘🏾‍♂' => 'mann i lotusstilling: hudtype 5',
    '🧘🏿‍♂' => 'mann i lotusstilling: hudtype 6',
    '🧘🏻‍♀' => 'kvinne i lotusstilling: hudtype 1–2',
    '🧘🏼‍♀' => 'kvinne i lotusstilling: hudtype 3',
    '🧘🏽‍♀' => 'kvinne i lotusstilling: hudtype 4',
    '🧘🏾‍♀' => 'kvinne i lotusstilling: hudtype 5',
    '🧘🏿‍♀' => 'kvinne i lotusstilling: hudtype 6',
    '🧑‍🦰' => 'voksen: rødt hår',
    '🧑‍🦱' => 'voksen: kruset hår',
    '🧑‍🦳' => 'voksen: grått hår',
    '🧑‍🦲' => 'voksen: skallet',
    '👨‍🦰' => 'mann: rødt hår',
    '👨‍🦱' => 'mann: kruset hår',
    '👨‍🦳' => 'mann: grått hår',
    '👨‍🦲' => 'mann: skallet',
    '👩‍🦰' => 'kvinne: rødt hår',
    '👩‍🦱' => 'kvinne: kruset hår',
    '👩‍🦳' => 'kvinne: grått hår',
    '👩‍🦲' => 'kvinne: skallet',
    '🚶‍➡' => 'fotgjenger: vendt mot høyre',
    '🧎‍➡' => 'person som kneler: vendt mot høyre',
    '🏃‍➡' => 'løper: vendt mot høyre',
    '👨‍👦' => 'familie: mann, gutt',
    '👨‍👧' => 'familie: mann, jente',
    '👩‍👦' => 'familie: kvinne, gutt',
    '👩‍👧' => 'familie: kvinne, jente',
    '😶‍🌫' => 'fjes i skyer',
    '😮‍💨' => 'puster ut',
    '🙂‍↕' => 'nikkende hode',
    '😵‍💫' => 'fjes med spiraløyne',
    '❤‍🔥' => 'hjerte i brann',
    '❤‍🩹' => 'lindret hjerte',
    '👁‍🗨' => 'øye i snakkeboble',
    '🧔‍♂' => 'mann: skjegg',
    '👱‍♂' => 'mann: blond',
    '🧔‍♀' => 'kvinne: skjegg',
    '👱‍♀' => 'kvinne: blond',
    '🙍‍♂' => 'mann som rynker brynene',
    '🙍‍♀' => 'kvinne som rynker brynene',
    '🙎‍♂' => 'mann som furter',
    '🙎‍♀' => 'kvinne som furter',
    '🙅‍♂' => 'mann som gestikulerer NEI',
    '🙅‍♀' => 'kvinne som gestikulerer NEI',
    '🙆‍♂' => 'mann som gestikulerer OK',
    '🙆‍♀' => 'kvinne som gestikulerer OK',
    '💁‍♂' => 'hjelpende mann',
    '💁‍♀' => 'hjelpende kvinne',
    '🙋‍♂' => 'mann som rekker opp hånden',
    '🙋‍♀' => 'kvinne som rekker opp hånden',
    '🧏‍♂' => 'døv mann',
    '🧏‍♀' => 'døv kvinne',
    '🙇‍♂' => 'bukkende mann',
    '🙇‍♀' => 'bukkende kvinne',
    '🤦‍♂' => 'mann som slår hånden mot pannen',
    '🤦‍♀' => 'kvinne som slår hånden mot pannen',
    '🤷‍♂' => 'mann som trekker på skuldrene',
    '🤷‍♀' => 'kvinne som trekker på skuldrene',
    '🧑‍⚕' => 'helsearbeider',
    '👨‍⚕' => 'mannlig helsearbeider',
    '👩‍⚕' => 'kvinnelig helsearbeider',
    '🧑‍🎓' => 'student',
    '👨‍🎓' => 'mannlig student',
    '👩‍🎓' => 'kvinnelig student',
    '🧑‍🏫' => 'lærer',
    '👨‍🏫' => 'mannlig lærer',
    '👩‍🏫' => 'kvinnelig lærer',
    '🧑‍⚖' => 'dommer',
    '👨‍⚖' => 'mannlig dommer',
    '👩‍⚖' => 'kvinnelig dommer',
    '🧑‍🌾' => 'gårdbruker',
    '👨‍🌾' => 'mannlig gårdbruker',
    '👩‍🌾' => 'kvinnelig gårdbruker',
    '🧑‍🍳' => 'kokk',
    '👨‍🍳' => 'mannlig kokk',
    '👩‍🍳' => 'kvinnelig kokk',
    '🧑‍🔧' => 'mekaniker',
    '👨‍🔧' => 'mannlig mekaniker',
    '👩‍🔧' => 'kvinnelig mekaniker',
    '🧑‍🏭' => 'industriarbeider',
    '👨‍🏭' => 'mannlig industriarbeider',
    '👩‍🏭' => 'kvinnelig industriarbeider',
    '🧑‍💼' => 'kontorarbeider',
    '👨‍💼' => 'mannlig kontorarbeider',
    '👩‍💼' => 'kvinnelig kontorarbeider',
    '🧑‍🔬' => 'forsker',
    '👨‍🔬' => 'mannlig forsker',
    '👩‍🔬' => 'kvinnelig forsker',
    '🧑‍💻' => 'IT-ekspert',
    '👨‍💻' => 'mannlig IT-ekspert',
    '👩‍💻' => 'kvinnelig IT-ekspert',
    '🧑‍🎤' => 'artist',
    '👨‍🎤' => 'mannlig artist',
    '👩‍🎤' => 'kvinnelig artist',
    '🧑‍🎨' => 'kunstner',
    '👨‍🎨' => 'mannlig kunstner',
    '👩‍🎨' => 'kvinnelig kunstner',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'mannlig pilot',
    '👩‍✈' => 'kvinnelig pilot',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'mannlig astronaut',
    '👩‍🚀' => 'kvinnelig astronaut',
    '🧑‍🚒' => 'brannkonstabel',
    '👨‍🚒' => 'mannlig brannkonstabel',
    '👩‍🚒' => 'kvinnelig brannkonstabel',
    '👮‍♂' => 'mannlig politibetjent',
    '👮‍♀' => 'kvinnelig politibetjent',
    '🕵‍♂' => 'mannlig detektiv',
    '🕵‍♀' => 'kvinnelig detektiv',
    '💂‍♂' => 'mannlig gardist',
    '💂‍♀' => 'kvinnelig gardist',
    '👷‍♂' => 'mannlig anleggsarbeider',
    '👷‍♀' => 'kvinnelig anleggsarbeider',
    '👳‍♂' => 'turbankledd mann',
    '👳‍♀' => 'turbankledd kvinne',
    '🤵‍♂' => 'mann i smoking',
    '🤵‍♀' => 'kvinne i smoking',
    '👰‍♂' => 'mann med slør',
    '👰‍♀' => 'kvinne med slør',
    '👩‍🍼' => 'kvinne som mater baby',
    '👨‍🍼' => 'mann som mater baby',
    '🧑‍🍼' => 'person som mater baby',
    '🧑‍🎄' => 'julenisse',
    '🦸‍♂' => 'mannlig superhelt',
    '🦸‍♀' => 'kvinnelig superhelt',
    '🦹‍♂' => 'mannlig superskurk',
    '🦹‍♀' => 'kvinnelig superskurk',
    '🧙‍♂' => 'trollmann',
    '🧙‍♀' => 'trollkvinne',
    '🧚‍♂' => 'mannlig fe',
    '🧚‍♀' => 'kvinnelig fe',
    '🧛‍♂' => 'mannlig vampyr',
    '🧛‍♀' => 'kvinnelig vampyr',
    '🧜‍♂' => 'havmann',
    '🧜‍♀' => 'havfrue',
    '🧝‍♂' => 'mannlig alv',
    '🧝‍♀' => 'kvinnelig alv',
    '🧞‍♂' => 'mannlig ånd',
    '🧞‍♀' => 'kvinnelig ånd',
    '🧟‍♂' => 'mannlig zombie',
    '🧟‍♀' => 'kvinnelig zombie',
    '💆‍♂' => 'mann som får ansiktsmassasje',
    '💆‍♀' => 'kvinne som får ansiktsmassasje',
    '💇‍♂' => 'mann som får hårklipp',
    '💇‍♀' => 'kvinne som får hårklipp',
    '🚶‍♂' => 'mannlig fotgjenger',
    '🚶‍♀' => 'kvinnelig fotgjenger',
    '🧍‍♂' => 'mann som står',
    '🧍‍♀' => 'kvinne som står',
    '🧎‍♂' => 'mann som kneler',
    '🧎‍♀' => 'kvinne som kneler',
    '🧑‍🦯' => 'person med blindestokk',
    '👨‍🦯' => 'mann med blindestokk',
    '👩‍🦯' => 'kvinne med blindestokk',
    '🧑‍🦼' => 'person i motorisert rullestol',
    '👨‍🦼' => 'mann i motorisert rullestol',
    '👩‍🦼' => 'kvinne i motorisert rullestol',
    '🧑‍🦽' => 'person i manuell rullestol',
    '👨‍🦽' => 'mann i manuell rullestol',
    '👩‍🦽' => 'kvinne i manuell rullestol',
    '🏃‍♂' => 'mannlig løper',
    '🏃‍♀' => 'kvinnelig løper',
    '🧑‍🩰' => 'ballettdanser',
    '👯‍♂' => 'menn med kaninører',
    '👯‍♀' => 'kvinner med kaninører',
    '🧖‍♂' => 'mann i badstu',
    '🧖‍♀' => 'kvinne i badstu',
    '🧗‍♂' => 'mannlig klatrer',
    '🧗‍♀' => 'kvinnelig klatrer',
    '🏌‍♂' => 'mannlig golfspiller',
    '🏌‍♀' => 'kvinnelig golfspiller',
    '🏄‍♂' => 'mannlig surfer',
    '🏄‍♀' => 'kvinnelig surfer',
    '🚣‍♂' => 'mann i robåt',
    '🚣‍♀' => 'kvinne i robåt',
    '🏊‍♂' => 'mannlig svømmer',
    '🏊‍♀' => 'kvinnelig svømmer',
    '⛹‍♂' => 'mann med ball',
    '⛹‍♀' => 'kvinne med ball',
    '🏋‍♂' => 'mannlig vektløfter',
    '🏋‍♀' => 'kvinnelig vektløfter',
    '🚴‍♂' => 'mannlig syklist',
    '🚴‍♀' => 'kvinnelig syklist',
    '🚵‍♂' => 'mann på terrengsykkel',
    '🚵‍♀' => 'kvinne på terrengsykkel',
    '🤸‍♂' => 'mann som slår hjul',
    '🤸‍♀' => 'kvinne som slår hjul',
    '🤼‍♂' => 'mannlige brytere',
    '🤼‍♀' => 'kvinnelige brytere',
    '🤽‍♂' => 'mannlig vannpolospiller',
    '🤽‍♀' => 'kvinnelig vannpolospiller',
    '🤾‍♂' => 'mannlig håndballspiller',
    '🤾‍♀' => 'kvinnelig håndballspiller',
    '🤹‍♂' => 'mannlig sjonglør',
    '🤹‍♀' => 'kvinnelig sjonglør',
    '🧘‍♂' => 'mann i lotusstilling',
    '🧘‍♀' => 'kvinne i lotusstilling',
    '🧑‍🧒' => 'familie: voksen, barn',
    '🐕‍🦺' => 'servicehund',
    '🐈‍⬛' => 'svart katt',
    '🐻‍❄' => 'isbjørn',
    '🐦‍⬛' => 'svart fugl',
    '🐦‍🔥' => 'føniks',
    '🍋‍🟩' => 'lime',
    '🍄‍🟫' => 'brun sopp',
    '⛓‍💥' => 'brutt lenke',
    '🏳‍🌈' => 'regnbueflagg',
    '🏳‍⚧' => 'transpersonflagg',
    '🏴‍☠' => 'sjørøverflagg',
    '👋🏻' => 'vinkende hånd: hudtype 1–2',
    '👋🏼' => 'vinkende hånd: hudtype 3',
    '👋🏽' => 'vinkende hånd: hudtype 4',
    '👋🏾' => 'vinkende hånd: hudtype 5',
    '👋🏿' => 'vinkende hånd: hudtype 6',
    '🤚🏻' => 'løftet håndbak: hudtype 1–2',
    '🤚🏼' => 'løftet håndbak: hudtype 3',
    '🤚🏽' => 'løftet håndbak: hudtype 4',
    '🤚🏾' => 'løftet håndbak: hudtype 5',
    '🤚🏿' => 'løftet håndbak: hudtype 6',
    '🖐🏻' => 'flat hånd med spredte fingre: hudtype 1–2',
    '🖐🏼' => 'flat hånd med spredte fingre: hudtype 3',
    '🖐🏽' => 'flat hånd med spredte fingre: hudtype 4',
    '🖐🏾' => 'flat hånd med spredte fingre: hudtype 5',
    '🖐🏿' => 'flat hånd med spredte fingre: hudtype 6',
    '✋🏻' => 'hevet hånd: hudtype 1–2',
    '✋🏼' => 'hevet hånd: hudtype 3',
    '✋🏽' => 'hevet hånd: hudtype 4',
    '✋🏾' => 'hevet hånd: hudtype 5',
    '✋🏿' => 'hevet hånd: hudtype 6',
    '🖖🏻' => 'Vulcan-hilsen: hudtype 1–2',
    '🖖🏼' => 'Vulcan-hilsen: hudtype 3',
    '🖖🏽' => 'Vulcan-hilsen: hudtype 4',
    '🖖🏾' => 'Vulcan-hilsen: hudtype 5',
    '🖖🏿' => 'Vulcan-hilsen: hudtype 6',
    '🫱🏻' => 'hånd mot høyre: hudtype 1–2',
    '🫱🏼' => 'hånd mot høyre: hudtype 3',
    '🫱🏽' => 'hånd mot høyre: hudtype 4',
    '🫱🏾' => 'hånd mot høyre: hudtype 5',
    '🫱🏿' => 'hånd mot høyre: hudtype 6',
    '🫲🏻' => 'hånd mot venstre: hudtype 1–2',
    '🫲🏼' => 'hånd mot venstre: hudtype 3',
    '🫲🏽' => 'hånd mot venstre: hudtype 4',
    '🫲🏾' => 'hånd mot venstre: hudtype 5',
    '🫲🏿' => 'hånd mot venstre: hudtype 6',
    '🫳🏻' => 'håndflaten ned: hudtype 1–2',
    '🫳🏼' => 'håndflaten ned: hudtype 3',
    '🫳🏽' => 'håndflaten ned: hudtype 4',
    '🫳🏾' => 'håndflaten ned: hudtype 5',
    '🫳🏿' => 'håndflaten ned: hudtype 6',
    '🫴🏻' => 'håndflaten opp: hudtype 1–2',
    '🫴🏼' => 'håndflaten opp: hudtype 3',
    '🫴🏽' => 'håndflaten opp: hudtype 4',
    '🫴🏾' => 'håndflaten opp: hudtype 5',
    '🫴🏿' => 'håndflaten opp: hudtype 6',
    '🫷🏻' => 'håndflate hevet mot venstre: hudtype 1–2',
    '🫷🏼' => 'håndflate hevet mot venstre: hudtype 3',
    '🫷🏽' => 'håndflate hevet mot venstre: hudtype 4',
    '🫷🏾' => 'håndflate hevet mot venstre: hudtype 5',
    '🫷🏿' => 'håndflate hevet mot venstre: hudtype 6',
    '🫸🏻' => 'håndflate hevet mot høyre: hudtype 1–2',
    '🫸🏼' => 'håndflate hevet mot høyre: hudtype 3',
    '🫸🏽' => 'håndflate hevet mot høyre: hudtype 4',
    '🫸🏾' => 'håndflate hevet mot høyre: hudtype 5',
    '🫸🏿' => 'håndflate hevet mot høyre: hudtype 6',
    '👌🏻' => 'OK-hånd: hudtype 1–2',
    '👌🏼' => 'OK-hånd: hudtype 3',
    '👌🏽' => 'OK-hånd: hudtype 4',
    '👌🏾' => 'OK-hånd: hudtype 5',
    '👌🏿' => 'OK-hånd: hudtype 6',
    '🤌🏻' => 'hånd med fingertuppene sammen: hudtype 1–2',
    '🤌🏼' => 'hånd med fingertuppene sammen: hudtype 3',
    '🤌🏽' => 'hånd med fingertuppene sammen: hudtype 4',
    '🤌🏾' => 'hånd med fingertuppene sammen: hudtype 5',
    '🤌🏿' => 'hånd med fingertuppene sammen: hudtype 6',
    '🤏🏻' => 'hånd som klyper: hudtype 1–2',
    '🤏🏼' => 'hånd som klyper: hudtype 3',
    '🤏🏽' => 'hånd som klyper: hudtype 4',
    '🤏🏾' => 'hånd som klyper: hudtype 5',
    '🤏🏿' => 'hånd som klyper: hudtype 6',
    '✌🏻' => 'seierstegn: hudtype 1–2',
    '✌🏼' => 'seierstegn: hudtype 3',
    '✌🏽' => 'seierstegn: hudtype 4',
    '✌🏾' => 'seierstegn: hudtype 5',
    '✌🏿' => 'seierstegn: hudtype 6',
    '🤞🏻' => 'kryssede fingre: hudtype 1–2',
    '🤞🏼' => 'kryssede fingre: hudtype 3',
    '🤞🏽' => 'kryssede fingre: hudtype 4',
    '🤞🏾' => 'kryssede fingre: hudtype 5',
    '🤞🏿' => 'kryssede fingre: hudtype 6',
    '🫰🏻' => 'hånd med pekefinger og tommel krysset: hudtype 1–2',
    '🫰🏼' => 'hånd med pekefinger og tommel krysset: hudtype 3',
    '🫰🏽' => 'hånd med pekefinger og tommel krysset: hudtype 4',
    '🫰🏾' => 'hånd med pekefinger og tommel krysset: hudtype 5',
    '🫰🏿' => 'hånd med pekefinger og tommel krysset: hudtype 6',
    '🤟🏻' => 'glad i deg-tegn: hudtype 1–2',
    '🤟🏼' => 'glad i deg-tegn: hudtype 3',
    '🤟🏽' => 'glad i deg-tegn: hudtype 4',
    '🤟🏾' => 'glad i deg-tegn: hudtype 5',
    '🤟🏿' => 'glad i deg-tegn: hudtype 6',
    '🤘🏻' => 'rock’n’roll: hudtype 1–2',
    '🤘🏼' => 'rock’n’roll: hudtype 3',
    '🤘🏽' => 'rock’n’roll: hudtype 4',
    '🤘🏾' => 'rock’n’roll: hudtype 5',
    '🤘🏿' => 'rock’n’roll: hudtype 6',
    '🤙🏻' => 'ring meg-hånd: hudtype 1–2',
    '🤙🏼' => 'ring meg-hånd: hudtype 3',
    '🤙🏽' => 'ring meg-hånd: hudtype 4',
    '🤙🏾' => 'ring meg-hånd: hudtype 5',
    '🤙🏿' => 'ring meg-hånd: hudtype 6',
    '👈🏻' => 'peker mot venstre – bakhånd: hudtype 1–2',
    '👈🏼' => 'peker mot venstre – bakhånd: hudtype 3',
    '👈🏽' => 'peker mot venstre – bakhånd: hudtype 4',
    '👈🏾' => 'peker mot venstre – bakhånd: hudtype 5',
    '👈🏿' => 'peker mot venstre – bakhånd: hudtype 6',
    '👉🏻' => 'peker mot høyre – bakhånd: hudtype 1–2',
    '👉🏼' => 'peker mot høyre – bakhånd: hudtype 3',
    '👉🏽' => 'peker mot høyre – bakhånd: hudtype 4',
    '👉🏾' => 'peker mot høyre – bakhånd: hudtype 5',
    '👉🏿' => 'peker mot høyre – bakhånd: hudtype 6',
    '👆🏻' => 'peker opp – bakhånd: hudtype 1–2',
    '👆🏼' => 'peker opp – bakhånd: hudtype 3',
    '👆🏽' => 'peker opp – bakhånd: hudtype 4',
    '👆🏾' => 'peker opp – bakhånd: hudtype 5',
    '👆🏿' => 'peker opp – bakhånd: hudtype 6',
    '🖕🏻' => 'langfinger: hudtype 1–2',
    '🖕🏼' => 'langfinger: hudtype 3',
    '🖕🏽' => 'langfinger: hudtype 4',
    '🖕🏾' => 'langfinger: hudtype 5',
    '🖕🏿' => 'langfinger: hudtype 6',
    '👇🏻' => 'peker ned – bakhånd: hudtype 1–2',
    '👇🏼' => 'peker ned – bakhånd: hudtype 3',
    '👇🏽' => 'peker ned – bakhånd: hudtype 4',
    '👇🏾' => 'peker ned – bakhånd: hudtype 5',
    '👇🏿' => 'peker ned – bakhånd: hudtype 6',
    '☝🏻' => 'peker opp: hudtype 1–2',
    '☝🏼' => 'peker opp: hudtype 3',
    '☝🏽' => 'peker opp: hudtype 4',
    '☝🏾' => 'peker opp: hudtype 5',
    '☝🏿' => 'peker opp: hudtype 6',
    '🫵🏻' => 'pekefinger peker på leseren: hudtype 1–2',
    '🫵🏼' => 'pekefinger peker på leseren: hudtype 3',
    '🫵🏽' => 'pekefinger peker på leseren: hudtype 4',
    '🫵🏾' => 'pekefinger peker på leseren: hudtype 5',
    '🫵🏿' => 'pekefinger peker på leseren: hudtype 6',
    '👍🏻' => 'tommel opp: hudtype 1–2',
    '👍🏼' => 'tommel opp: hudtype 3',
    '👍🏽' => 'tommel opp: hudtype 4',
    '👍🏾' => 'tommel opp: hudtype 5',
    '👍🏿' => 'tommel opp: hudtype 6',
    '👎🏻' => 'tommel ned: hudtype 1–2',
    '👎🏼' => 'tommel ned: hudtype 3',
    '👎🏽' => 'tommel ned: hudtype 4',
    '👎🏾' => 'tommel ned: hudtype 5',
    '👎🏿' => 'tommel ned: hudtype 6',
    '✊🏻' => 'hevet knyttneve: hudtype 1–2',
    '✊🏼' => 'hevet knyttneve: hudtype 3',
    '✊🏽' => 'hevet knyttneve: hudtype 4',
    '✊🏾' => 'hevet knyttneve: hudtype 5',
    '✊🏿' => 'hevet knyttneve: hudtype 6',
    '👊🏻' => 'knyttneve: hudtype 1–2',
    '👊🏼' => 'knyttneve: hudtype 3',
    '👊🏽' => 'knyttneve: hudtype 4',
    '👊🏾' => 'knyttneve: hudtype 5',
    '👊🏿' => 'knyttneve: hudtype 6',
    '🤛🏻' => 'knyttneve mot venstre: hudtype 1–2',
    '🤛🏼' => 'knyttneve mot venstre: hudtype 3',
    '🤛🏽' => 'knyttneve mot venstre: hudtype 4',
    '🤛🏾' => 'knyttneve mot venstre: hudtype 5',
    '🤛🏿' => 'knyttneve mot venstre: hudtype 6',
    '🤜🏻' => 'knyttneve mot høyre: hudtype 1–2',
    '🤜🏼' => 'knyttneve mot høyre: hudtype 3',
    '🤜🏽' => 'knyttneve mot høyre: hudtype 4',
    '🤜🏾' => 'knyttneve mot høyre: hudtype 5',
    '🤜🏿' => 'knyttneve mot høyre: hudtype 6',
    '👏🏻' => 'klappende hender: hudtype 1–2',
    '👏🏼' => 'klappende hender: hudtype 3',
    '👏🏽' => 'klappende hender: hudtype 4',
    '👏🏾' => 'klappende hender: hudtype 5',
    '👏🏿' => 'klappende hender: hudtype 6',
    '🙌🏻' => 'hevede hender: hudtype 1–2',
    '🙌🏼' => 'hevede hender: hudtype 3',
    '🙌🏽' => 'hevede hender: hudtype 4',
    '🙌🏾' => 'hevede hender: hudtype 5',
    '🙌🏿' => 'hevede hender: hudtype 6',
    '🫶🏻' => 'hjertehender: hudtype 1–2',
    '🫶🏼' => 'hjertehender: hudtype 3',
    '🫶🏽' => 'hjertehender: hudtype 4',
    '🫶🏾' => 'hjertehender: hudtype 5',
    '🫶🏿' => 'hjertehender: hudtype 6',
    '👐🏻' => 'åpne hender: hudtype 1–2',
    '👐🏼' => 'åpne hender: hudtype 3',
    '👐🏽' => 'åpne hender: hudtype 4',
    '👐🏾' => 'åpne hender: hudtype 5',
    '👐🏿' => 'åpne hender: hudtype 6',
    '🤲🏻' => 'håndflatene sammen: hudtype 1–2',
    '🤲🏼' => 'håndflatene sammen: hudtype 3',
    '🤲🏽' => 'håndflatene sammen: hudtype 4',
    '🤲🏾' => 'håndflatene sammen: hudtype 5',
    '🤲🏿' => 'håndflatene sammen: hudtype 6',
    '🤝🏻' => 'håndhilse: hudtype 1–2',
    '🤝🏼' => 'håndhilse: hudtype 3',
    '🤝🏽' => 'håndhilse: hudtype 4',
    '🤝🏾' => 'håndhilse: hudtype 5',
    '🤝🏿' => 'håndhilse: hudtype 6',
    '🙏🏻' => 'foldede hender: hudtype 1–2',
    '🙏🏼' => 'foldede hender: hudtype 3',
    '🙏🏽' => 'foldede hender: hudtype 4',
    '🙏🏾' => 'foldede hender: hudtype 5',
    '🙏🏿' => 'foldede hender: hudtype 6',
    '✍🏻' => 'skrivende hånd: hudtype 1–2',
    '✍🏼' => 'skrivende hånd: hudtype 3',
    '✍🏽' => 'skrivende hånd: hudtype 4',
    '✍🏾' => 'skrivende hånd: hudtype 5',
    '✍🏿' => 'skrivende hånd: hudtype 6',
    '💅🏻' => 'neglelakk: hudtype 1–2',
    '💅🏼' => 'neglelakk: hudtype 3',
    '💅🏽' => 'neglelakk: hudtype 4',
    '💅🏾' => 'neglelakk: hudtype 5',
    '💅🏿' => 'neglelakk: hudtype 6',
    '🤳🏻' => 'selfie: hudtype 1–2',
    '🤳🏼' => 'selfie: hudtype 3',
    '🤳🏽' => 'selfie: hudtype 4',
    '🤳🏾' => 'selfie: hudtype 5',
    '🤳🏿' => 'selfie: hudtype 6',
    '💪🏻' => 'biceps: hudtype 1–2',
    '💪🏼' => 'biceps: hudtype 3',
    '💪🏽' => 'biceps: hudtype 4',
    '💪🏾' => 'biceps: hudtype 5',
    '💪🏿' => 'biceps: hudtype 6',
    '🦵🏻' => 'bein: hudtype 1–2',
    '🦵🏼' => 'bein: hudtype 3',
    '🦵🏽' => 'bein: hudtype 4',
    '🦵🏾' => 'bein: hudtype 5',
    '🦵🏿' => 'bein: hudtype 6',
    '🦶🏻' => 'fot: hudtype 1–2',
    '🦶🏼' => 'fot: hudtype 3',
    '🦶🏽' => 'fot: hudtype 4',
    '🦶🏾' => 'fot: hudtype 5',
    '🦶🏿' => 'fot: hudtype 6',
    '👂🏻' => 'øre: hudtype 1–2',
    '👂🏼' => 'øre: hudtype 3',
    '👂🏽' => 'øre: hudtype 4',
    '👂🏾' => 'øre: hudtype 5',
    '👂🏿' => 'øre: hudtype 6',
    '🦻🏻' => 'øre med høreapparat: hudtype 1–2',
    '🦻🏼' => 'øre med høreapparat: hudtype 3',
    '🦻🏽' => 'øre med høreapparat: hudtype 4',
    '🦻🏾' => 'øre med høreapparat: hudtype 5',
    '🦻🏿' => 'øre med høreapparat: hudtype 6',
    '👃🏻' => 'nese: hudtype 1–2',
    '👃🏼' => 'nese: hudtype 3',
    '👃🏽' => 'nese: hudtype 4',
    '👃🏾' => 'nese: hudtype 5',
    '👃🏿' => 'nese: hudtype 6',
    '👶🏻' => 'baby: hudtype 1–2',
    '👶🏼' => 'baby: hudtype 3',
    '👶🏽' => 'baby: hudtype 4',
    '👶🏾' => 'baby: hudtype 5',
    '👶🏿' => 'baby: hudtype 6',
    '🧒🏻' => 'barn: hudtype 1–2',
    '🧒🏼' => 'barn: hudtype 3',
    '🧒🏽' => 'barn: hudtype 4',
    '🧒🏾' => 'barn: hudtype 5',
    '🧒🏿' => 'barn: hudtype 6',
    '👦🏻' => 'gutt: hudtype 1–2',
    '👦🏼' => 'gutt: hudtype 3',
    '👦🏽' => 'gutt: hudtype 4',
    '👦🏾' => 'gutt: hudtype 5',
    '👦🏿' => 'gutt: hudtype 6',
    '👧🏻' => 'jente: hudtype 1–2',
    '👧🏼' => 'jente: hudtype 3',
    '👧🏽' => 'jente: hudtype 4',
    '👧🏾' => 'jente: hudtype 5',
    '👧🏿' => 'jente: hudtype 6',
    '🧑🏻' => 'voksen: hudtype 1–2',
    '🧑🏼' => 'voksen: hudtype 3',
    '🧑🏽' => 'voksen: hudtype 4',
    '🧑🏾' => 'voksen: hudtype 5',
    '🧑🏿' => 'voksen: hudtype 6',
    '👱🏻' => 'Person: hudtype 1–2, blond',
    '👱🏼' => 'Person: hudtype 3, blond',
    '👱🏽' => 'Person: hudtype 4, blond',
    '👱🏾' => 'Person: hudtype 5, blond',
    '👱🏿' => 'Person: hudtype 6, blond',
    '👨🏻' => 'mann: hudtype 1–2',
    '👨🏼' => 'mann: hudtype 3',
    '👨🏽' => 'mann: hudtype 4',
    '👨🏾' => 'mann: hudtype 5',
    '👨🏿' => 'mann: hudtype 6',
    '🧔🏻' => 'person: hudtype 1–2, skjegg',
    '🧔🏼' => 'person: hudtype 3, skjegg',
    '🧔🏽' => 'person: hudtype 4, skjegg',
    '🧔🏾' => 'person: hudtype 5, skjegg',
    '🧔🏿' => 'person: hudtype 6, skjegg',
    '👩🏻' => 'kvinne: hudtype 1–2',
    '👩🏼' => 'kvinne: hudtype 3',
    '👩🏽' => 'kvinne: hudtype 4',
    '👩🏾' => 'kvinne: hudtype 5',
    '👩🏿' => 'kvinne: hudtype 6',
    '🧓🏻' => 'eldre voksen: hudtype 1–2',
    '🧓🏼' => 'eldre voksen: hudtype 3',
    '🧓🏽' => 'eldre voksen: hudtype 4',
    '🧓🏾' => 'eldre voksen: hudtype 5',
    '🧓🏿' => 'eldre voksen: hudtype 6',
    '👴🏻' => 'eldre mann: hudtype 1–2',
    '👴🏼' => 'eldre mann: hudtype 3',
    '👴🏽' => 'eldre mann: hudtype 4',
    '👴🏾' => 'eldre mann: hudtype 5',
    '👴🏿' => 'eldre mann: hudtype 6',
    '👵🏻' => 'eldre kvinne: hudtype 1–2',
    '👵🏼' => 'eldre kvinne: hudtype 3',
    '👵🏽' => 'eldre kvinne: hudtype 4',
    '👵🏾' => 'eldre kvinne: hudtype 5',
    '👵🏿' => 'eldre kvinne: hudtype 6',
    '🙍🏻' => 'rynker brynene: hudtype 1–2',
    '🙍🏼' => 'rynker brynene: hudtype 3',
    '🙍🏽' => 'rynker brynene: hudtype 4',
    '🙍🏾' => 'rynker brynene: hudtype 5',
    '🙍🏿' => 'rynker brynene: hudtype 6',
    '🙎🏻' => 'furter: hudtype 1–2',
    '🙎🏼' => 'furter: hudtype 3',
    '🙎🏽' => 'furter: hudtype 4',
    '🙎🏾' => 'furter: hudtype 5',
    '🙎🏿' => 'furter: hudtype 6',
    '🙅🏻' => 'gestikulerer NEI: hudtype 1–2',
    '🙅🏼' => 'gestikulerer NEI: hudtype 3',
    '🙅🏽' => 'gestikulerer NEI: hudtype 4',
    '🙅🏾' => 'gestikulerer NEI: hudtype 5',
    '🙅🏿' => 'gestikulerer NEI: hudtype 6',
    '🙆🏻' => 'gestikulerer OK: hudtype 1–2',
    '🙆🏼' => 'gestikulerer OK: hudtype 3',
    '🙆🏽' => 'gestikulerer OK: hudtype 4',
    '🙆🏾' => 'gestikulerer OK: hudtype 5',
    '🙆🏿' => 'gestikulerer OK: hudtype 6',
    '💁🏻' => 'hjelpende person: hudtype 1–2',
    '💁🏼' => 'hjelpende person: hudtype 3',
    '💁🏽' => 'hjelpende person: hudtype 4',
    '💁🏾' => 'hjelpende person: hudtype 5',
    '💁🏿' => 'hjelpende person: hudtype 6',
    '🙋🏻' => 'rekker opp hånden: hudtype 1–2',
    '🙋🏼' => 'rekker opp hånden: hudtype 3',
    '🙋🏽' => 'rekker opp hånden: hudtype 4',
    '🙋🏾' => 'rekker opp hånden: hudtype 5',
    '🙋🏿' => 'rekker opp hånden: hudtype 6',
    '🧏🏻' => 'døv person: hudtype 1–2',
    '🧏🏼' => 'døv person: hudtype 3',
    '🧏🏽' => 'døv person: hudtype 4',
    '🧏🏾' => 'døv person: hudtype 5',
    '🧏🏿' => 'døv person: hudtype 6',
    '🙇🏻' => 'bukker: hudtype 1–2',
    '🙇🏼' => 'bukker: hudtype 3',
    '🙇🏽' => 'bukker: hudtype 4',
    '🙇🏾' => 'bukker: hudtype 5',
    '🙇🏿' => 'bukker: hudtype 6',
    '🤦🏻' => 'slår hånden mot pannen: hudtype 1–2',
    '🤦🏼' => 'slår hånden mot pannen: hudtype 3',
    '🤦🏽' => 'slår hånden mot pannen: hudtype 4',
    '🤦🏾' => 'slår hånden mot pannen: hudtype 5',
    '🤦🏿' => 'slår hånden mot pannen: hudtype 6',
    '🤷🏻' => 'trekker på skuldrene: hudtype 1–2',
    '🤷🏼' => 'trekker på skuldrene: hudtype 3',
    '🤷🏽' => 'trekker på skuldrene: hudtype 4',
    '🤷🏾' => 'trekker på skuldrene: hudtype 5',
    '🤷🏿' => 'trekker på skuldrene: hudtype 6',
    '👮🏻' => 'politibetjent: hudtype 1–2',
    '👮🏼' => 'politibetjent: hudtype 3',
    '👮🏽' => 'politibetjent: hudtype 4',
    '👮🏾' => 'politibetjent: hudtype 5',
    '👮🏿' => 'politibetjent: hudtype 6',
    '🕵🏻' => 'detektiv: hudtype 1–2',
    '🕵🏼' => 'detektiv: hudtype 3',
    '🕵🏽' => 'detektiv: hudtype 4',
    '🕵🏾' => 'detektiv: hudtype 5',
    '🕵🏿' => 'detektiv: hudtype 6',
    '💂🏻' => 'gardist: hudtype 1–2',
    '💂🏼' => 'gardist: hudtype 3',
    '💂🏽' => 'gardist: hudtype 4',
    '💂🏾' => 'gardist: hudtype 5',
    '💂🏿' => 'gardist: hudtype 6',
    '🥷🏻' => 'ninja: hudtype 1–2',
    '🥷🏼' => 'ninja: hudtype 3',
    '🥷🏽' => 'ninja: hudtype 4',
    '🥷🏾' => 'ninja: hudtype 5',
    '🥷🏿' => 'ninja: hudtype 6',
    '👷🏻' => 'anleggsarbeider: hudtype 1–2',
    '👷🏼' => 'anleggsarbeider: hudtype 3',
    '👷🏽' => 'anleggsarbeider: hudtype 4',
    '👷🏾' => 'anleggsarbeider: hudtype 5',
    '👷🏿' => 'anleggsarbeider: hudtype 6',
    '🫅🏻' => 'person med krone: hudtype 1–2',
    '🫅🏼' => 'person med krone: hudtype 3',
    '🫅🏽' => 'person med krone: hudtype 4',
    '🫅🏾' => 'person med krone: hudtype 5',
    '🫅🏿' => 'person med krone: hudtype 6',
    '🤴🏻' => 'prins: hudtype 1–2',
    '🤴🏼' => 'prins: hudtype 3',
    '🤴🏽' => 'prins: hudtype 4',
    '🤴🏾' => 'prins: hudtype 5',
    '🤴🏿' => 'prins: hudtype 6',
    '👸🏻' => 'prinsesse: hudtype 1–2',
    '👸🏼' => 'prinsesse: hudtype 3',
    '👸🏽' => 'prinsesse: hudtype 4',
    '👸🏾' => 'prinsesse: hudtype 5',
    '👸🏿' => 'prinsesse: hudtype 6',
    '👳🏻' => 'turbankledd person: hudtype 1–2',
    '👳🏼' => 'turbankledd person: hudtype 3',
    '👳🏽' => 'turbankledd person: hudtype 4',
    '👳🏾' => 'turbankledd person: hudtype 5',
    '👳🏿' => 'turbankledd person: hudtype 6',
    '👲🏻' => 'mann med kinesisk lue: hudtype 1–2',
    '👲🏼' => 'mann med kinesisk lue: hudtype 3',
    '👲🏽' => 'mann med kinesisk lue: hudtype 4',
    '👲🏾' => 'mann med kinesisk lue: hudtype 5',
    '👲🏿' => 'mann med kinesisk lue: hudtype 6',
    '🧕🏻' => 'kvinne med hodeslør: hudtype 1–2',
    '🧕🏼' => 'kvinne med hodeslør: hudtype 3',
    '🧕🏽' => 'kvinne med hodeslør: hudtype 4',
    '🧕🏾' => 'kvinne med hodeslør: hudtype 5',
    '🧕🏿' => 'kvinne med hodeslør: hudtype 6',
    '🤵🏻' => 'person i smoking: hudtype 1–2',
    '🤵🏼' => 'person i smoking: hudtype 3',
    '🤵🏽' => 'person i smoking: hudtype 4',
    '🤵🏾' => 'person i smoking: hudtype 5',
    '🤵🏿' => 'person i smoking: hudtype 6',
    '👰🏻' => 'person med slør: hudtype 1–2',
    '👰🏼' => 'person med slør: hudtype 3',
    '👰🏽' => 'person med slør: hudtype 4',
    '👰🏾' => 'person med slør: hudtype 5',
    '👰🏿' => 'person med slør: hudtype 6',
    '🤰🏻' => 'gravid kvinne: hudtype 1–2',
    '🤰🏼' => 'gravid kvinne: hudtype 3',
    '🤰🏽' => 'gravid kvinne: hudtype 4',
    '🤰🏾' => 'gravid kvinne: hudtype 5',
    '🤰🏿' => 'gravid kvinne: hudtype 6',
    '🫃🏻' => 'gravid mann: hudtype 1–2',
    '🫃🏼' => 'gravid mann: hudtype 3',
    '🫃🏽' => 'gravid mann: hudtype 4',
    '🫃🏾' => 'gravid mann: hudtype 5',
    '🫃🏿' => 'gravid mann: hudtype 6',
    '🫄🏻' => 'gravid person: hudtype 1–2',
    '🫄🏼' => 'gravid person: hudtype 3',
    '🫄🏽' => 'gravid person: hudtype 4',
    '🫄🏾' => 'gravid person: hudtype 5',
    '🫄🏿' => 'gravid person: hudtype 6',
    '🤱🏻' => 'ammer: hudtype 1–2',
    '🤱🏼' => 'ammer: hudtype 3',
    '🤱🏽' => 'ammer: hudtype 4',
    '🤱🏾' => 'ammer: hudtype 5',
    '🤱🏿' => 'ammer: hudtype 6',
    '👼🏻' => 'babyengel: hudtype 1–2',
    '👼🏼' => 'babyengel: hudtype 3',
    '👼🏽' => 'babyengel: hudtype 4',
    '👼🏾' => 'babyengel: hudtype 5',
    '👼🏿' => 'babyengel: hudtype 6',
    '🎅🏻' => 'julenissen: hudtype 1–2',
    '🎅🏼' => 'julenissen: hudtype 3',
    '🎅🏽' => 'julenissen: hudtype 4',
    '🎅🏾' => 'julenissen: hudtype 5',
    '🎅🏿' => 'julenissen: hudtype 6',
    '🤶🏻' => 'julenissemor: hudtype 1–2',
    '🤶🏼' => 'julenissemor: hudtype 3',
    '🤶🏽' => 'julenissemor: hudtype 4',
    '🤶🏾' => 'julenissemor: hudtype 5',
    '🤶🏿' => 'julenissemor: hudtype 6',
    '🦸🏻' => 'superhelt: hudtype 1–2',
    '🦸🏼' => 'superhelt: hudtype 3',
    '🦸🏽' => 'superhelt: hudtype 4',
    '🦸🏾' => 'superhelt: hudtype 5',
    '🦸🏿' => 'superhelt: hudtype 6',
    '🦹🏻' => 'superskurk: hudtype 1–2',
    '🦹🏼' => 'superskurk: hudtype 3',
    '🦹🏽' => 'superskurk: hudtype 4',
    '🦹🏾' => 'superskurk: hudtype 5',
    '🦹🏿' => 'superskurk: hudtype 6',
    '🧙🏻' => 'trollperson: hudtype 1–2',
    '🧙🏼' => 'trollperson: hudtype 3',
    '🧙🏽' => 'trollperson: hudtype 4',
    '🧙🏾' => 'trollperson: hudtype 5',
    '🧙🏿' => 'trollperson: hudtype 6',
    '🧚🏻' => 'fe: hudtype 1–2',
    '🧚🏼' => 'fe: hudtype 3',
    '🧚🏽' => 'fe: hudtype 4',
    '🧚🏾' => 'fe: hudtype 5',
    '🧚🏿' => 'fe: hudtype 6',
    '🧛🏻' => 'vampyr: hudtype 1–2',
    '🧛🏼' => 'vampyr: hudtype 3',
    '🧛🏽' => 'vampyr: hudtype 4',
    '🧛🏾' => 'vampyr: hudtype 5',
    '🧛🏿' => 'vampyr: hudtype 6',
    '🧜🏻' => 'havperson: hudtype 1–2',
    '🧜🏼' => 'havperson: hudtype 3',
    '🧜🏽' => 'havperson: hudtype 4',
    '🧜🏾' => 'havperson: hudtype 5',
    '🧜🏿' => 'havperson: hudtype 6',
    '🧝🏻' => 'alv: hudtype 1–2',
    '🧝🏼' => 'alv: hudtype 3',
    '🧝🏽' => 'alv: hudtype 4',
    '🧝🏾' => 'alv: hudtype 5',
    '🧝🏿' => 'alv: hudtype 6',
    '💆🏻' => 'ansiktsmassasje: hudtype 1–2',
    '💆🏼' => 'ansiktsmassasje: hudtype 3',
    '💆🏽' => 'ansiktsmassasje: hudtype 4',
    '💆🏾' => 'ansiktsmassasje: hudtype 5',
    '💆🏿' => 'ansiktsmassasje: hudtype 6',
    '💇🏻' => 'hårklipp: hudtype 1–2',
    '💇🏼' => 'hårklipp: hudtype 3',
    '💇🏽' => 'hårklipp: hudtype 4',
    '💇🏾' => 'hårklipp: hudtype 5',
    '💇🏿' => 'hårklipp: hudtype 6',
    '🚶🏻' => 'fotgjenger: hudtype 1–2',
    '🚶🏼' => 'fotgjenger: hudtype 3',
    '🚶🏽' => 'fotgjenger: hudtype 4',
    '🚶🏾' => 'fotgjenger: hudtype 5',
    '🚶🏿' => 'fotgjenger: hudtype 6',
    '🧍🏻' => 'person som står: hudtype 1–2',
    '🧍🏼' => 'person som står: hudtype 3',
    '🧍🏽' => 'person som står: hudtype 4',
    '🧍🏾' => 'person som står: hudtype 5',
    '🧍🏿' => 'person som står: hudtype 6',
    '🧎🏻' => 'person som kneler: hudtype 1–2',
    '🧎🏼' => 'person som kneler: hudtype 3',
    '🧎🏽' => 'person som kneler: hudtype 4',
    '🧎🏾' => 'person som kneler: hudtype 5',
    '🧎🏿' => 'person som kneler: hudtype 6',
    '🏃🏻' => 'løper: hudtype 1–2',
    '🏃🏼' => 'løper: hudtype 3',
    '🏃🏽' => 'løper: hudtype 4',
    '🏃🏾' => 'løper: hudtype 5',
    '🏃🏿' => 'løper: hudtype 6',
    '💃🏻' => 'dansende kvinne: hudtype 1–2',
    '💃🏼' => 'dansende kvinne: hudtype 3',
    '💃🏽' => 'dansende kvinne: hudtype 4',
    '💃🏾' => 'dansende kvinne: hudtype 5',
    '💃🏿' => 'dansende kvinne: hudtype 6',
    '🕺🏻' => 'dansende mann: hudtype 1–2',
    '🕺🏼' => 'dansende mann: hudtype 3',
    '🕺🏽' => 'dansende mann: hudtype 4',
    '🕺🏾' => 'dansende mann: hudtype 5',
    '🕺🏿' => 'dansende mann: hudtype 6',
    '🕴🏻' => 'svevende mann i dress: hudtype 1–2',
    '🕴🏼' => 'svevende mann i dress: hudtype 3',
    '🕴🏽' => 'svevende mann i dress: hudtype 4',
    '🕴🏾' => 'svevende mann i dress: hudtype 5',
    '🕴🏿' => 'svevende mann i dress: hudtype 6',
    '👯🏻' => 'personer med kaninører: hudtype 1–2',
    '👯🏼' => 'personer med kaninører: hudtype 3',
    '👯🏽' => 'personer med kaninører: hudtype 4',
    '👯🏾' => 'personer med kaninører: hudtype 5',
    '👯🏿' => 'personer med kaninører: hudtype 6',
    '🧖🏻' => 'person i badstu: hudtype 1–2',
    '🧖🏼' => 'person i badstu: hudtype 3',
    '🧖🏽' => 'person i badstu: hudtype 4',
    '🧖🏾' => 'person i badstu: hudtype 5',
    '🧖🏿' => 'person i badstu: hudtype 6',
    '🧗🏻' => 'klatrer: hudtype 1–2',
    '🧗🏼' => 'klatrer: hudtype 3',
    '🧗🏽' => 'klatrer: hudtype 4',
    '🧗🏾' => 'klatrer: hudtype 5',
    '🧗🏿' => 'klatrer: hudtype 6',
    '🏇🏻' => 'hesteveddeløp: hudtype 1–2',
    '🏇🏼' => 'hesteveddeløp: hudtype 3',
    '🏇🏽' => 'hesteveddeløp: hudtype 4',
    '🏇🏾' => 'hesteveddeløp: hudtype 5',
    '🏇🏿' => 'hesteveddeløp: hudtype 6',
    '🏂🏻' => 'snowboarder: hudtype 1–2',
    '🏂🏼' => 'snowboarder: hudtype 3',
    '🏂🏽' => 'snowboarder: hudtype 4',
    '🏂🏾' => 'snowboarder: hudtype 5',
    '🏂🏿' => 'snowboarder: hudtype 6',
    '🏌🏻' => 'golfspiller: hudtype 1–2',
    '🏌🏼' => 'golfspiller: hudtype 3',
    '🏌🏽' => 'golfspiller: hudtype 4',
    '🏌🏾' => 'golfspiller: hudtype 5',
    '🏌🏿' => 'golfspiller: hudtype 6',
    '🏄🏻' => 'surfer: hudtype 1–2',
    '🏄🏼' => 'surfer: hudtype 3',
    '🏄🏽' => 'surfer: hudtype 4',
    '🏄🏾' => 'surfer: hudtype 5',
    '🏄🏿' => 'surfer: hudtype 6',
    '🚣🏻' => 'person i robåt: hudtype 1–2',
    '🚣🏼' => 'person i robåt: hudtype 3',
    '🚣🏽' => 'person i robåt: hudtype 4',
    '🚣🏾' => 'person i robåt: hudtype 5',
    '🚣🏿' => 'person i robåt: hudtype 6',
    '🏊🏻' => 'svømmer: hudtype 1–2',
    '🏊🏼' => 'svømmer: hudtype 3',
    '🏊🏽' => 'svømmer: hudtype 4',
    '🏊🏾' => 'svømmer: hudtype 5',
    '🏊🏿' => 'svømmer: hudtype 6',
    '⛹🏻' => 'person med ball: hudtype 1–2',
    '⛹🏼' => 'person med ball: hudtype 3',
    '⛹🏽' => 'person med ball: hudtype 4',
    '⛹🏾' => 'person med ball: hudtype 5',
    '⛹🏿' => 'person med ball: hudtype 6',
    '🏋🏻' => 'vektløfter: hudtype 1–2',
    '🏋🏼' => 'vektløfter: hudtype 3',
    '🏋🏽' => 'vektløfter: hudtype 4',
    '🏋🏾' => 'vektløfter: hudtype 5',
    '🏋🏿' => 'vektløfter: hudtype 6',
    '🚴🏻' => 'syklist: hudtype 1–2',
    '🚴🏼' => 'syklist: hudtype 3',
    '🚴🏽' => 'syklist: hudtype 4',
    '🚴🏾' => 'syklist: hudtype 5',
    '🚴🏿' => 'syklist: hudtype 6',
    '🚵🏻' => 'terrengsyklist: hudtype 1–2',
    '🚵🏼' => 'terrengsyklist: hudtype 3',
    '🚵🏽' => 'terrengsyklist: hudtype 4',
    '🚵🏾' => 'terrengsyklist: hudtype 5',
    '🚵🏿' => 'terrengsyklist: hudtype 6',
    '🤸🏻' => 'slå hjul: hudtype 1–2',
    '🤸🏼' => 'slå hjul: hudtype 3',
    '🤸🏽' => 'slå hjul: hudtype 4',
    '🤸🏾' => 'slå hjul: hudtype 5',
    '🤸🏿' => 'slå hjul: hudtype 6',
    '🤼🏻' => 'brytere: hudtype 1–2',
    '🤼🏼' => 'brytere: hudtype 3',
    '🤼🏽' => 'brytere: hudtype 4',
    '🤼🏾' => 'brytere: hudtype 5',
    '🤼🏿' => 'brytere: hudtype 6',
    '🤽🏻' => 'vannpolo: hudtype 1–2',
    '🤽🏼' => 'vannpolo: hudtype 3',
    '🤽🏽' => 'vannpolo: hudtype 4',
    '🤽🏾' => 'vannpolo: hudtype 5',
    '🤽🏿' => 'vannpolo: hudtype 6',
    '🤾🏻' => 'håndball: hudtype 1–2',
    '🤾🏼' => 'håndball: hudtype 3',
    '🤾🏽' => 'håndball: hudtype 4',
    '🤾🏾' => 'håndball: hudtype 5',
    '🤾🏿' => 'håndball: hudtype 6',
    '🤹🏻' => 'sjonglering: hudtype 1–2',
    '🤹🏼' => 'sjonglering: hudtype 3',
    '🤹🏽' => 'sjonglering: hudtype 4',
    '🤹🏾' => 'sjonglering: hudtype 5',
    '🤹🏿' => 'sjonglering: hudtype 6',
    '🧘🏻' => 'lotusstilling: hudtype 1–2',
    '🧘🏼' => 'lotusstilling: hudtype 3',
    '🧘🏽' => 'lotusstilling: hudtype 4',
    '🧘🏾' => 'lotusstilling: hudtype 5',
    '🧘🏿' => 'lotusstilling: hudtype 6',
    '🛀🏻' => 'person i badekar: hudtype 1–2',
    '🛀🏼' => 'person i badekar: hudtype 3',
    '🛀🏽' => 'person i badekar: hudtype 4',
    '🛀🏾' => 'person i badekar: hudtype 5',
    '🛀🏿' => 'person i badekar: hudtype 6',
    '🛌🏻' => 'person i seng: hudtype 1–2',
    '🛌🏼' => 'person i seng: hudtype 3',
    '🛌🏽' => 'person i seng: hudtype 4',
    '🛌🏾' => 'person i seng: hudtype 5',
    '🛌🏿' => 'person i seng: hudtype 6',
    '👭🏻' => 'kvinner som leier: hudtype 1–2',
    '👭🏼' => 'kvinner som leier: hudtype 3',
    '👭🏽' => 'kvinner som leier: hudtype 4',
    '👭🏾' => 'kvinner som leier: hudtype 5',
    '👭🏿' => 'kvinner som leier: hudtype 6',
    '👫🏻' => 'mann og kvinne som leier: hudtype 1–2',
    '👫🏼' => 'mann og kvinne som leier: hudtype 3',
    '👫🏽' => 'mann og kvinne som leier: hudtype 4',
    '👫🏾' => 'mann og kvinne som leier: hudtype 5',
    '👫🏿' => 'mann og kvinne som leier: hudtype 6',
    '👬🏻' => 'menn som leier: hudtype 1–2',
    '👬🏼' => 'menn som leier: hudtype 3',
    '👬🏽' => 'menn som leier: hudtype 4',
    '👬🏾' => 'menn som leier: hudtype 5',
    '👬🏿' => 'menn som leier: hudtype 6',
    '💏🏻' => 'kyss: hudtype 1–2',
    '💏🏼' => 'kyss: hudtype 3',
    '💏🏽' => 'kyss: hudtype 4',
    '💏🏾' => 'kyss: hudtype 5',
    '💏🏿' => 'kyss: hudtype 6',
    '💑🏻' => 'par med hjerte: hudtype 1–2',
    '💑🏼' => 'par med hjerte: hudtype 3',
    '💑🏽' => 'par med hjerte: hudtype 4',
    '💑🏾' => 'par med hjerte: hudtype 5',
    '💑🏿' => 'par med hjerte: hudtype 6',
    '🇦🇨' => 'flagg: Ascension',
    '🇦🇩' => 'flagg: Andorra',
    '🇦🇪' => 'flagg: De forente arabiske emirater',
    '🇦🇫' => 'flagg: Afghanistan',
    '🇦🇬' => 'flagg: Antigua og Barbuda',
    '🇦🇮' => 'flagg: Anguilla',
    '🇦🇱' => 'flagg: Albania',
    '🇦🇲' => 'flagg: Armenia',
    '🇦🇴' => 'flagg: Angola',
    '🇦🇶' => 'flagg: Antarktis',
    '🇦🇷' => 'flagg: Argentina',
    '🇦🇸' => 'flagg: Amerikansk Samoa',
    '🇦🇹' => 'flagg: Østerrike',
    '🇦🇺' => 'flagg: Australia',
    '🇦🇼' => 'flagg: Aruba',
    '🇦🇽' => 'flagg: Åland',
    '🇦🇿' => 'flagg: Aserbajdsjan',
    '🇧🇦' => 'flagg: Bosnia-Hercegovina',
    '🇧🇧' => 'flagg: Barbados',
    '🇧🇩' => 'flagg: Bangladesh',
    '🇧🇪' => 'flagg: Belgia',
    '🇧🇫' => 'flagg: Burkina Faso',
    '🇧🇬' => 'flagg: Bulgaria',
    '🇧🇭' => 'flagg: Bahrain',
    '🇧🇮' => 'flagg: Burundi',
    '🇧🇯' => 'flagg: Benin',
    '🇧🇱' => 'flagg: Saint-Barthélemy',
    '🇧🇲' => 'flagg: Bermuda',
    '🇧🇳' => 'flagg: Brunei',
    '🇧🇴' => 'flagg: Bolivia',
    '🇧🇶' => 'flagg: Karibisk Nederland',
    '🇧🇷' => 'flagg: Brasil',
    '🇧🇸' => 'flagg: Bahamas',
    '🇧🇹' => 'flagg: Bhutan',
    '🇧🇻' => 'flagg: Bouvetøya',
    '🇧🇼' => 'flagg: Botswana',
    '🇧🇾' => 'flagg: Belarus',
    '🇧🇿' => 'flagg: Belize',
    '🇨🇦' => 'flagg: Canada',
    '🇨🇨' => 'flagg: Kokosøyene',
    '🇨🇩' => 'flagg: Kongo',
    '🇨🇫' => 'flagg: Den sentralafrikanske republikk',
    '🇨🇬' => 'flagg: Kongo-Brazzaville',
    '🇨🇭' => 'flagg: Sveits',
    '🇨🇮' => 'flagg: Elfenbenskysten',
    '🇨🇰' => 'flagg: Cookøyene',
    '🇨🇱' => 'flagg: Chile',
    '🇨🇲' => 'flagg: Kamerun',
    '🇨🇳' => 'flagg: Kina',
    '🇨🇴' => 'flagg: Colombia',
    '🇨🇵' => 'flagg: Clippertonøya',
    '🇨🇶' => 'flagg: Sark',
    '🇨🇷' => 'flagg: Costa Rica',
    '🇨🇺' => 'flagg: Cuba',
    '🇨🇻' => 'flagg: Kapp Verde',
    '🇨🇼' => 'flagg: Curaçao',
    '🇨🇽' => 'flagg: Christmasøya',
    '🇨🇾' => 'flagg: Kypros',
    '🇨🇿' => 'flagg: Tsjekkia',
    '🇩🇪' => 'flagg: Tyskland',
    '🇩🇬' => 'flagg: Diego Garcia',
    '🇩🇯' => 'flagg: Djibouti',
    '🇩🇰' => 'flagg: Danmark',
    '🇩🇲' => 'flagg: Dominica',
    '🇩🇴' => 'flagg: Den dominikanske republikk',
    '🇩🇿' => 'flagg: Algerie',
    '🇪🇦' => 'flagg: Ceuta og Melilla',
    '🇪🇨' => 'flagg: Ecuador',
    '🇪🇪' => 'flagg: Estland',
    '🇪🇬' => 'flagg: Egypt',
    '🇪🇭' => 'flagg: Vest-Sahara',
    '🇪🇷' => 'flagg: Eritrea',
    '🇪🇸' => 'flagg: Spania',
    '🇪🇹' => 'flagg: Etiopia',
    '🇪🇺' => 'flagg: Den europeiske union',
    '🇫🇮' => 'flagg: Finland',
    '🇫🇯' => 'flagg: Fiji',
    '🇫🇰' => 'flagg: Falklandsøyene',
    '🇫🇲' => 'flagg: Mikronesiaføderasjonen',
    '🇫🇴' => 'flagg: Færøyene',
    '🇫🇷' => 'flagg: Frankrike',
    '🇬🇦' => 'flagg: Gabon',
    '🇬🇧' => 'flagg: Storbritannia',
    '🇬🇩' => 'flagg: Grenada',
    '🇬🇪' => 'flagg: Georgia',
    '🇬🇫' => 'flagg: Fransk Guyana',
    '🇬🇬' => 'flagg: Guernsey',
    '🇬🇭' => 'flagg: Ghana',
    '🇬🇮' => 'flagg: Gibraltar',
    '🇬🇱' => 'flagg: Grønland',
    '🇬🇲' => 'flagg: Gambia',
    '🇬🇳' => 'flagg: Guinea',
    '🇬🇵' => 'flagg: Guadeloupe',
    '🇬🇶' => 'flagg: Ekvatorial-Guinea',
    '🇬🇷' => 'flagg: Hellas',
    '🇬🇸' => 'flagg: Sør-Georgia og Sør-Sandwichøyene',
    '🇬🇹' => 'flagg: Guatemala',
    '🇬🇺' => 'flagg: Guam',
    '🇬🇼' => 'flagg: Guinea-Bissau',
    '🇬🇾' => 'flagg: Guyana',
    '🇭🇰' => 'flagg: Hongkong SAR Kina',
    '🇭🇲' => 'flagg: Heard- og McDonaldøyene',
    '🇭🇳' => 'flagg: Honduras',
    '🇭🇷' => 'flagg: Kroatia',
    '🇭🇹' => 'flagg: Haiti',
    '🇭🇺' => 'flagg: Ungarn',
    '🇮🇨' => 'flagg: Kanariøyene',
    '🇮🇩' => 'flagg: Indonesia',
    '🇮🇪' => 'flagg: Irland',
    '🇮🇱' => 'flagg: Israel',
    '🇮🇲' => 'flagg: Man',
    '🇮🇳' => 'flagg: India',
    '🇮🇴' => 'flagg: Det britiske territoriet i Indiahavet',
    '🇮🇶' => 'flagg: Irak',
    '🇮🇷' => 'flagg: Iran',
    '🇮🇸' => 'flagg: Island',
    '🇮🇹' => 'flagg: Italia',
    '🇯🇪' => 'flagg: Jersey',
    '🇯🇲' => 'flagg: Jamaica',
    '🇯🇴' => 'flagg: Jordan',
    '🇯🇵' => 'flagg: Japan',
    '🇰🇪' => 'flagg: Kenya',
    '🇰🇬' => 'flagg: Kirgisistan',
    '🇰🇭' => 'flagg: Kambodsja',
    '🇰🇮' => 'flagg: Kiribati',
    '🇰🇲' => 'flagg: Komorene',
    '🇰🇳' => 'flagg: Saint Kitts og Nevis',
    '🇰🇵' => 'flagg: Nord-Korea',
    '🇰🇷' => 'flagg: Sør-Korea',
    '🇰🇼' => 'flagg: Kuwait',
    '🇰🇾' => 'flagg: Caymanøyene',
    '🇰🇿' => 'flagg: Kasakhstan',
    '🇱🇦' => 'flagg: Laos',
    '🇱🇧' => 'flagg: Libanon',
    '🇱🇨' => 'flagg: St. Lucia',
    '🇱🇮' => 'flagg: Liechtenstein',
    '🇱🇰' => 'flagg: Sri Lanka',
    '🇱🇷' => 'flagg: Liberia',
    '🇱🇸' => 'flagg: Lesotho',
    '🇱🇹' => 'flagg: Litauen',
    '🇱🇺' => 'flagg: Luxemburg',
    '🇱🇻' => 'flagg: Latvia',
    '🇱🇾' => 'flagg: Libya',
    '🇲🇦' => 'flagg: Marokko',
    '🇲🇨' => 'flagg: Monaco',
    '🇲🇩' => 'flagg: Moldova',
    '🇲🇪' => 'flagg: Montenegro',
    '🇲🇫' => 'flagg: Saint-Martin',
    '🇲🇬' => 'flagg: Madagaskar',
    '🇲🇭' => 'flagg: Marshalløyene',
    '🇲🇰' => 'flagg: Nord-Makedonia',
    '🇲🇱' => 'flagg: Mali',
    '🇲🇲' => 'flagg: Myanmar (Burma)',
    '🇲🇳' => 'flagg: Mongolia',
    '🇲🇴' => 'flagg: Macao SAR Kina',
    '🇲🇵' => 'flagg: Nord-Marianene',
    '🇲🇶' => 'flagg: Martinique',
    '🇲🇷' => 'flagg: Mauritania',
    '🇲🇸' => 'flagg: Montserrat',
    '🇲🇹' => 'flagg: Malta',
    '🇲🇺' => 'flagg: Mauritius',
    '🇲🇻' => 'flagg: Maldivene',
    '🇲🇼' => 'flagg: Malawi',
    '🇲🇽' => 'flagg: Mexico',
    '🇲🇾' => 'flagg: Malaysia',
    '🇲🇿' => 'flagg: Mosambik',
    '🇳🇦' => 'flagg: Namibia',
    '🇳🇨' => 'flagg: Ny-Caledonia',
    '🇳🇪' => 'flagg: Niger',
    '🇳🇫' => 'flagg: Norfolkøya',
    '🇳🇬' => 'flagg: Nigeria',
    '🇳🇮' => 'flagg: Nicaragua',
    '🇳🇱' => 'flagg: Nederland',
    '🇳🇴' => 'flagg: Norge',
    '🇳🇵' => 'flagg: Nepal',
    '🇳🇷' => 'flagg: Nauru',
    '🇳🇺' => 'flagg: Niue',
    '🇳🇿' => 'flagg: New Zealand',
    '🇴🇲' => 'flagg: Oman',
    '🇵🇦' => 'flagg: Panama',
    '🇵🇪' => 'flagg: Peru',
    '🇵🇫' => 'flagg: Fransk Polynesia',
    '🇵🇬' => 'flagg: Papua Ny-Guinea',
    '🇵🇭' => 'flagg: Filippinene',
    '🇵🇰' => 'flagg: Pakistan',
    '🇵🇱' => 'flagg: Polen',
    '🇵🇲' => 'flagg: Saint-Pierre-et-Miquelon',
    '🇵🇳' => 'flagg: Pitcairnøyene',
    '🇵🇷' => 'flagg: Puerto Rico',
    '🇵🇸' => 'flagg: Det palestinske området',
    '🇵🇹' => 'flagg: Portugal',
    '🇵🇼' => 'flagg: Palau',
    '🇵🇾' => 'flagg: Paraguay',
    '🇶🇦' => 'flagg: Qatar',
    '🇷🇪' => 'flagg: Réunion',
    '🇷🇴' => 'flagg: Romania',
    '🇷🇸' => 'flagg: Serbia',
    '🇷🇺' => 'flagg: Russland',
    '🇷🇼' => 'flagg: Rwanda',
    '🇸🇦' => 'flagg: Saudi-Arabia',
    '🇸🇧' => 'flagg: Salomonøyene',
    '🇸🇨' => 'flagg: Seychellene',
    '🇸🇩' => 'flagg: Sudan',
    '🇸🇪' => 'flagg: Sverige',
    '🇸🇬' => 'flagg: Singapore',
    '🇸🇭' => 'flagg: St. Helena',
    '🇸🇮' => 'flagg: Slovenia',
    '🇸🇯' => 'flagg: Svalbard og Jan Mayen',
    '🇸🇰' => 'flagg: Slovakia',
    '🇸🇱' => 'flagg: Sierra Leone',
    '🇸🇲' => 'flagg: San Marino',
    '🇸🇳' => 'flagg: Senegal',
    '🇸🇴' => 'flagg: Somalia',
    '🇸🇷' => 'flagg: Surinam',
    '🇸🇸' => 'flagg: Sør-Sudan',
    '🇸🇹' => 'flagg: São Tomé og Príncipe',
    '🇸🇻' => 'flagg: El Salvador',
    '🇸🇽' => 'flagg: Sint Maarten',
    '🇸🇾' => 'flagg: Syria',
    '🇸🇿' => 'flagg: Eswatini',
    '🇹🇦' => 'flagg: Tristan da Cunha',
    '🇹🇨' => 'flagg: Turks- og Caicosøyene',
    '🇹🇩' => 'flagg: Tsjad',
    '🇹🇫' => 'flagg: De franske sørterritorier',
    '🇹🇬' => 'flagg: Togo',
    '🇹🇭' => 'flagg: Thailand',
    '🇹🇯' => 'flagg: Tadsjikistan',
    '🇹🇰' => 'flagg: Tokelau',
    '🇹🇱' => 'flagg: Øst-Timor',
    '🇹🇲' => 'flagg: Turkmenistan',
    '🇹🇳' => 'flagg: Tunisia',
    '🇹🇴' => 'flagg: Tonga',
    '🇹🇷' => 'flagg: Tyrkia',
    '🇹🇹' => 'flagg: Trinidad og Tobago',
    '🇹🇻' => 'flagg: Tuvalu',
    '🇹🇼' => 'flagg: Taiwan',
    '🇹🇿' => 'flagg: Tanzania',
    '🇺🇦' => 'flagg: Ukraina',
    '🇺🇬' => 'flagg: Uganda',
    '🇺🇲' => 'flagg: USAs ytre øyer',
    '🇺🇳' => 'flagg: FN',
    '🇺🇸' => 'flagg: USA',
    '🇺🇾' => 'flagg: Uruguay',
    '🇺🇿' => 'flagg: Usbekistan',
    '🇻🇦' => 'flagg: Vatikanstaten',
    '🇻🇨' => 'flagg: St. Vincent og Grenadinene',
    '🇻🇪' => 'flagg: Venezuela',
    '🇻🇬' => 'flagg: De britiske jomfruøyene',
    '🇻🇮' => 'flagg: De amerikanske jomfruøyene',
    '🇻🇳' => 'flagg: Vietnam',
    '🇻🇺' => 'flagg: Vanuatu',
    '🇼🇫' => 'flagg: Wallis og Futuna',
    '🇼🇸' => 'flagg: Samoa',
    '🇽🇰' => 'flagg: Kosovo',
    '🇾🇪' => 'flagg: Jemen',
    '🇾🇹' => 'flagg: Mayotte',
    '🇿🇦' => 'flagg: Sør-Afrika',
    '🇿🇲' => 'flagg: Zambia',
    '🇿🇼' => 'flagg: Zimbabwe',
    '🔟' => 'taster: 10',
    '🏻' => 'hudtype 1–2',
    '🏼' => 'hudtype 3',
    '🏽' => 'hudtype 4',
    '🏾' => 'hudtype 5',
    '🏿' => 'hudtype 6',
    '😀' => 'glisefjes',
    '😃' => 'glisende fjes med vidåpne øyne',
    '😄' => 'glisende fjes med smilende øyne',
    '😁' => 'glisefjes med smilende øyne',
    '😆' => 'smil med sammenknepne øyne',
    '😅' => 'glisende fjes som svetter',
    '🤣' => 'ruller rundt på gulvet i latter',
    '😂' => 'gledestårer',
    '🙂' => 'smiler litt',
    '🙃' => 'fjes som er opp-ned',
    '🫠' => 'fjes som smelter',
    '😉' => 'blunkende ansikt',
    '😊' => 'smil med smilende øyne',
    '😇' => 'smil med glorie',
    '🥰' => 'smilefjes med hjerter',
    '😍' => 'smilefjes med hjerteøyne',
    '🤩' => 'stjerner i øynene',
    '😘' => 'slengkyss',
    '😗' => 'kyssefjes',
    '☺' => 'smilefjes',
    '😚' => 'kyss med lukkede øyne',
    '😙' => 'kyss med smilende øyne',
    '🥲' => 'smilefjes med tåre',
    '😋' => 'nam-nam',
    '😛' => 'rekker tunge',
    '😜' => 'blunker og rekker tunge',
    '🤪' => 'gal',
    '😝' => 'æsj',
    '🤑' => 'pengegal',
    '🤗' => 'fjes som gir klem',
    '🤭' => 'hånden over munnen',
    '🫢' => 'fjes med åpne øyne og hånd over munnen',
    '🫣' => 'fjes som titter frem bak hendene',
    '🤫' => 'hysj',
    '🤔' => 'tenkefjes',
    '🫡' => 'fjes som viser honnør',
    '🤐' => 'fjes med glidelåsmunn',
    '🤨' => 'hevet øyenbryn',
    '😐' => 'nøytral',
    '😑' => 'uttrykksløs',
    '😶' => 'uten munn',
    '🫥' => 'fjes med stiplet omriss',
    '😏' => 'lurt smil',
    '😒' => 'misfornøyd',
    '🙄' => 'himler med øynene',
    '😬' => 'grimase',
    '🤥' => 'lyver',
    '🫨' => 'skjelvende fjes',
    '😌' => 'lettet',
    '😔' => 'tankefull',
    '😪' => 'søvnig',
    '🤤' => 'sikler',
    '😴' => 'sover',
    '🫩' => 'fjes med poser under øynene',
    '😷' => 'fjes med munnbind',
    '🤒' => 'fjes med termometer',
    '🤕' => 'bandasjert hode',
    '🤢' => 'kvalm',
    '🤮' => 'kaster opp',
    '🤧' => 'nyser',
    '🥵' => 'varmt fjes',
    '🥶' => 'kaldt fjes',
    '🥴' => 'svimmelt fjes',
    '😵' => 'ør',
    '🤯' => 'eksploderende hode',
    '🤠' => 'fjes med cowboyhatt',
    '🥳' => 'partyfjes',
    '🥸' => 'fjes med forkledning',
    '😎' => 'smilefjes med solbriller',
    '🤓' => 'nerdefjes',
    '🧐' => 'fjes med monokkel',
    '😕' => 'forvirret',
    '🫤' => 'fjes med diagonal munn',
    '😟' => 'bekymret',
    '🙁' => 'litt surt fjes',
    '☹' => 'surt fjes',
    '😮' => 'forbauset',
    '😯' => 'overrasket',
    '😲' => 'sjokkert',
    '😳' => 'rødmer',
    '🫪' => 'fordreid fjes',
    '🥺' => 'bedende fjes',
    '🥹' => 'fjes som holder tilbake tårene',
    '😦' => 'oppgitt',
    '😧' => 'pine',
    '😨' => 'redd',
    '😰' => 'engstelig og svetter',
    '😥' => 'puh!',
    '😢' => 'gråter',
    '😭' => 'strigråter',
    '😱' => 'livredd',
    '😖' => 'fortvilet',
    '😣' => 'bommert',
    '😞' => 'skuffet',
    '😓' => 'kaldsvetter',
    '😩' => 'sliten',
    '😫' => 'trøtt fjes',
    '🥱' => 'gjespende fjes',
    '😤' => 'triumferende',
    '😡' => 'rasende',
    '😠' => 'sint',
    '🤬' => 'fjes med symboler over munnen',
    '😈' => 'smilende djevel',
    '👿' => 'sint djevel',
    '💀' => 'hodeskalle',
    '☠' => 'dødningehode',
    '💩' => 'bæsj',
    '🤡' => 'klovnefjes',
    '👹' => 'japansk troll',
    '👺' => 'tengu',
    '👻' => 'spøkelse',
    '👽' => 'romvesen',
    '👾' => 'rommonster',
    '🤖' => 'robot',
    '😺' => 'smilende katt med åpen munn',
    '😸' => 'flirende katt med smilende øyne',
    '😹' => 'katt med gledestårer',
    '😻' => 'smilende katt med hjerteøyne',
    '😼' => 'katt med ironisk smil',
    '😽' => 'kyssende katt',
    '🙀' => 'sliten katt',
    '😿' => 'gråtende katt',
    '😾' => 'surmulende katt',
    '🙈' => 'ser ingenting ondt',
    '🙉' => 'hører ingenting ondt',
    '🙊' => 'sier ingenting ondt',
    '💌' => 'kjærlighesbrev',
    '💘' => 'hjerte med pil',
    '💝' => 'hjerte med bånd',
    '💖' => 'skinnende hjerte',
    '💗' => 'voksende hjerte',
    '💓' => 'bankende hjerte',
    '💞' => 'snurrende hjerter',
    '💕' => 'to hjerter',
    '💟' => 'hjertedekorasjon',
    '❣' => 'utropstegn med hjerte',
    '💔' => 'knust hjerte',
    '❤' => 'rødt hjerte',
    '🩷' => 'rosa hjerte',
    '🧡' => 'oransje hjerte',
    '💛' => 'gult hjerte',
    '💚' => 'grønt hjerte',
    '💙' => 'blått hjerte',
    '🩵' => 'lyseblått hjerte',
    '💜' => 'lilla hjerte',
    '🤎' => 'brunt hjerte',
    '🖤' => 'svart hjerte',
    '🩶' => 'grått hjerte',
    '🤍' => 'hvitt hjerte',
    '💋' => 'kyssemerke',
    '💯' => 'hundre poeng',
    '💢' => 'sinne',
    '🫯' => 'slåsskampsky',
    '💥' => 'krasj',
    '💫' => 'svimmel',
    '💦' => 'svettedråper',
    '💨' => 'stikker av',
    '🕳' => 'hull i bakken',
    '💬' => 'snakkeboble',
    '🗨' => 'snakkeboble mot venstre',
    '🗯' => 'sint snakkeboble mot høyre',
    '💭' => 'tankeboble',
    '💤' => 'zzz',
    '👋' => 'vinkende hånd',
    '🤚' => 'løftet håndbak',
    '🖐' => 'flat hånd med spredte fingre',
    '✋' => 'hevet hånd',
    '🖖' => 'Vulcan-hilsen',
    '🫱' => 'hånd mot høyre',
    '🫲' => 'hånd mot venstre',
    '🫳' => 'håndflaten ned',
    '🫴' => 'håndflaten opp',
    '🫷' => 'håndflate hevet mot venstre',
    '🫸' => 'håndflate hevet mot høyre',
    '👌' => 'OK-hånd',
    '🤌' => 'hånd med fingertuppene sammen',
    '🤏' => 'hånd som klyper',
    '✌' => 'seierstegn',
    '🤞' => 'kryssede fingre',
    '🫰' => 'hånd med pekefinger og tommel krysset',
    '🤟' => 'glad i deg-tegn',
    '🤘' => 'rock’n’roll',
    '🤙' => 'ring meg-hånd',
    '👈' => 'peker mot venstre – bakhånd',
    '👉' => 'peker mot høyre – bakhånd',
    '👆' => 'peker opp – bakhånd',
    '🖕' => 'langfinger',
    '👇' => 'peker ned – bakhånd',
    '☝' => 'peker opp',
    '🫵' => 'pekefinger peker på leseren',
    '👍' => 'tommel opp',
    '👎' => 'tommel ned',
    '✊' => 'hevet knyttneve',
    '👊' => 'knyttneve',
    '🤛' => 'knyttneve mot venstre',
    '🤜' => 'knyttneve mot høyre',
    '👏' => 'klappende hender',
    '🙌' => 'hevede hender',
    '🫶' => 'hjertehender',
    '👐' => 'åpne hender',
    '🤲' => 'håndflatene sammen',
    '🤝' => 'håndhilse',
    '🙏' => 'foldede hender',
    '✍' => 'skrivende hånd',
    '💅' => 'neglelakk',
    '🤳' => 'selfie',
    '💪' => 'biceps',
    '🦾' => 'mekanisk arm',
    '🦿' => 'mekanisk bein',
    '🦵' => 'bein',
    '🦶' => 'fot',
    '👂' => 'øre',
    '🦻' => 'øre med høreapparat',
    '👃' => 'nese',
    '🧠' => 'hjerne',
    '🫀' => 'hjertemuskel',
    '🫁' => 'lunger',
    '🦷' => 'tann',
    '🦴' => 'knokkel',
    '👀' => 'øyne',
    '👁' => 'øye',
    '👅' => 'tunge',
    '👄' => 'munn',
    '🫦' => 'bite seg i leppen',
    '👶' => 'baby',
    '🧒' => 'barn',
    '👦' => 'gutt',
    '👧' => 'jente',
    '🧑' => 'voksen',
    '👱' => 'Person: blond',
    '👨' => 'mann',
    '🧔' => 'person: skjegg',
    '👩' => 'kvinne',
    '🧓' => 'eldre voksen',
    '👴' => 'eldre mann',
    '👵' => 'eldre kvinne',
    '🙍' => 'rynker brynene',
    '🙎' => 'furter',
    '🙅' => 'gestikulerer NEI',
    '🙆' => 'gestikulerer OK',
    '💁' => 'hjelpende person',
    '🙋' => 'rekker opp hånden',
    '🧏' => 'døv person',
    '🙇' => 'bukker',
    '🤦' => 'slår hånden mot pannen',
    '🤷' => 'trekker på skuldrene',
    '👮' => 'politibetjent',
    '🕵' => 'detektiv',
    '💂' => 'gardist',
    '🥷' => 'ninja',
    '👷' => 'anleggsarbeider',
    '🫅' => 'person med krone',
    '🤴' => 'prins',
    '👸' => 'prinsesse',
    '👳' => 'turbankledd person',
    '👲' => 'mann med kinesisk lue',
    '🧕' => 'kvinne med hodeslør',
    '🤵' => 'person i smoking',
    '👰' => 'person med slør',
    '🤰' => 'gravid kvinne',
    '🫃' => 'gravid mann',
    '🫄' => 'gravid person',
    '🤱' => 'ammer',
    '👼' => 'babyengel',
    '🎅' => 'julenissen',
    '🤶' => 'julenissemor',
    '🦸' => 'superhelt',
    '🦹' => 'superskurk',
    '🧙' => 'trollperson',
    '🧚' => 'fe',
    '🧛' => 'vampyr',
    '🧜' => 'havperson',
    '🧝' => 'alv',
    '🧞' => 'ånd',
    '🧟' => 'zombie',
    '🧌' => 'troll',
    '🫈' => 'hårete vesen',
    '💆' => 'ansiktsmassasje',
    '💇' => 'hårklipp',
    '🚶' => 'fotgjenger',
    '🧍' => 'person som står',
    '🧎' => 'person som kneler',
    '🏃' => 'løper',
    '💃' => 'dansende kvinne',
    '🕺' => 'dansende mann',
    '🕴' => 'svevende mann i dress',
    '👯' => 'personer med kaninører',
    '🧖' => 'person i badstu',
    '🧗' => 'klatrer',
    '🤺' => 'fekter',
    '🏇' => 'hesteveddeløp',
    '⛷' => 'skiløper',
    '🏂' => 'snowboarder',
    '🏌' => 'golfspiller',
    '🏄' => 'surfer',
    '🚣' => 'person i robåt',
    '🏊' => 'svømmer',
    '⛹' => 'person med ball',
    '🏋' => 'vektløfter',
    '🚴' => 'syklist',
    '🚵' => 'terrengsyklist',
    '🤸' => 'slå hjul',
    '🤼' => 'brytere',
    '🤽' => 'vannpolo',
    '🤾' => 'håndball',
    '🤹' => 'sjonglering',
    '🧘' => 'lotusstilling',
    '🛀' => 'person i badekar',
    '🛌' => 'person i seng',
    '👭' => 'kvinner som leier',
    '👫' => 'mann og kvinne som leier',
    '👬' => 'menn som leier',
    '💏' => 'kyss',
    '💑' => 'par med hjerte',
    '🗣' => 'snakkende hode i profil',
    '👤' => 'silhuett av byste',
    '👥' => 'silhuett av byster',
    '🫂' => 'klem',
    '👪' => 'familie',
    '👣' => 'fotavtrykk',
    '🫆' => 'fingeravtrykk',
    '🦰' => 'rødt hår',
    '🦱' => 'kruset hår',
    '🦳' => 'grått hår',
    '🦲' => 'skallet',
    '🐵' => 'apefjes',
    '🐒' => 'ape',
    '🦍' => 'gorilla',
    '🦧' => 'orangutang',
    '🐶' => 'hundefjes',
    '🐕' => 'hund',
    '🦮' => 'førerhund',
    '🐩' => 'puddel',
    '🐺' => 'ulv',
    '🦊' => 'rev',
    '🦝' => 'vaskebjørn',
    '🐱' => 'kattefjes',
    '🐈' => 'katt',
    '🦁' => 'løve',
    '🐯' => 'tigerfjes',
    '🐅' => 'tiger',
    '🐆' => 'leopard',
    '🐴' => 'hestefjes',
    '🫎' => 'elg',
    '🫏' => 'esel',
    '🐎' => 'hest',
    '🦄' => 'enhjørning',
    '🦓' => 'sebra',
    '🦌' => 'hjort',
    '🦬' => 'bison',
    '🐮' => 'kufjes',
    '🐂' => 'okse',
    '🐃' => 'vannbøffel',
    '🐄' => 'ku',
    '🐷' => 'grisefjes',
    '🐖' => 'gris',
    '🐗' => 'villsvin',
    '🐽' => 'grisetryne',
    '🐏' => 'bukk',
    '🐑' => 'søye',
    '🐐' => 'geit',
    '🐪' => 'dromedar',
    '🐫' => 'kamel',
    '🦙' => 'lama',
    '🦒' => 'sjiraff',
    '🐘' => 'elefant',
    '🦣' => 'mammut',
    '🦏' => 'neshorn',
    '🦛' => 'flodhest',
    '🐭' => 'musefjes',
    '🐁' => 'mus',
    '🐀' => 'rotte',
    '🐹' => 'hamster',
    '🐰' => 'kaninfjes',
    '🐇' => 'kanin',
    '🐿' => 'ekorn',
    '🦫' => 'bever',
    '🦔' => 'pinnsvin',
    '🦇' => 'flaggermus',
    '🐻' => 'bjørn',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'dovendyr',
    '🦦' => 'oter',
    '🦨' => 'stinkdyr',
    '🦘' => 'kenguru',
    '🦡' => 'grevling',
    '🐾' => 'poteavtrykk',
    '🦃' => 'kalkun',
    '🐔' => 'høne',
    '🐓' => 'hane',
    '🐣' => 'nyklekket kylling',
    '🐤' => 'kylling',
    '🐥' => 'kylling forfra',
    '🐦' => 'fugl',
    '🐧' => 'pingvin',
    '🕊' => 'fredsdue',
    '🦅' => 'ørn',
    '🦆' => 'and',
    '🦢' => 'svane',
    '🦉' => 'ugle',
    '🦤' => 'dronte',
    '🪶' => 'fjær',
    '🦩' => 'flamingo',
    '🦚' => 'påfugl',
    '🦜' => 'papegøye',
    '🪽' => 'vinge',
    '🪿' => 'gås',
    '🐸' => 'frosk',
    '🐊' => 'krokodille',
    '🐢' => 'skilpadde',
    '🦎' => 'firfisle',
    '🐍' => 'slange',
    '🐲' => 'dragefjes',
    '🐉' => 'drage',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'sprutende hval',
    '🐋' => 'hval',
    '🐬' => 'delfin',
    '🫍' => 'spekkhogger',
    '🦭' => 'sel',
    '🐟' => 'fisk',
    '🐠' => 'tropisk fisk',
    '🐡' => 'kulefisk',
    '🦈' => 'hai',
    '🐙' => 'blekksprut',
    '🐚' => 'spiralskjell',
    '🪸' => 'korall',
    '🪼' => 'manet',
    '🦀' => 'krabbe',
    '🦞' => 'hummer',
    '🦐' => 'reke',
    '🦑' => 'akkar',
    '🦪' => 'østers',
    '🐌' => 'snegle',
    '🦋' => 'sommerfugl',
    '🐛' => 'insekt',
    '🐜' => 'maur',
    '🐝' => 'honningbie',
    '🪲' => 'bille',
    '🐞' => 'marihøne',
    '🦗' => 'gresshoppe',
    '🪳' => 'kakerlakk',
    '🕷' => 'edderkopp',
    '🕸' => 'spindelvev',
    '🦂' => 'skorpion',
    '🦟' => 'mygg',
    '🪰' => 'flue',
    '🪱' => 'mark',
    '🦠' => 'mikrobe',
    '💐' => 'bukett',
    '🌸' => 'kirsebærblomst',
    '💮' => 'hvit blomst',
    '🪷' => 'lotusblomst',
    '🏵' => 'rosett',
    '🌹' => 'rose',
    '🥀' => 'vissen blomst',
    '🌺' => 'hibiskus',
    '🌻' => 'solsikke',
    '🌼' => 'blomst',
    '🌷' => 'tulipan',
    '🪻' => 'hyasint',
    '🌱' => 'spire',
    '🪴' => 'potteplante',
    '🌲' => 'bartre',
    '🌳' => 'løvtre',
    '🌴' => 'palme',
    '🌵' => 'kaktus',
    '🌾' => 'risplante',
    '🌿' => 'urteblader',
    '☘' => 'trekløver',
    '🍀' => 'firkløver',
    '🍁' => 'lønneblad',
    '🍂' => 'høstblad',
    '🍃' => 'blader i vind',
    '🪹' => 'tomt rede',
    '🪺' => 'rede med egg',
    '🍄' => 'sopp',
    '🪾' => 'bladløst tre',
    '🍇' => 'druer',
    '🍈' => 'melon',
    '🍉' => 'vannmelon',
    '🍊' => 'mandarin',
    '🍋' => 'sitron',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'rødt eple',
    '🍏' => 'grønt eple',
    '🍐' => 'pære',
    '🍑' => 'fersken',
    '🍒' => 'kirsebær',
    '🍓' => 'jordbær',
    '🫐' => 'blåbær',
    '🥝' => 'kiwi',
    '🍅' => 'tomat',
    '🫒' => 'oliven',
    '🥥' => 'kokosnøtt',
    '🥑' => 'avokado',
    '🍆' => 'aubergine',
    '🥔' => 'potet',
    '🥕' => 'gulrot',
    '🌽' => 'maiskolbe',
    '🌶' => 'rød chili',
    '🫑' => 'paprika',
    '🥒' => 'agurk',
    '🥬' => 'bladgrønnsaker',
    '🥦' => 'brokkoli',
    '🧄' => 'hvitløk',
    '🧅' => 'løk',
    '🥜' => 'peanøtter',
    '🫘' => 'bønner',
    '🌰' => 'kastanje',
    '🫚' => 'ingefærrot',
    '🫛' => 'ertebelg',
    '🫜' => 'rotgrønnsak',
    '🍞' => 'brød',
    '🥐' => 'croissant',
    '🥖' => 'bagett',
    '🫓' => 'pitabrød',
    '🥨' => 'saltkringle',
    '🥯' => 'bagel',
    '🥞' => 'pannekaker',
    '🧇' => 'belgisk vaffel',
    '🧀' => 'ostestykke',
    '🍖' => 'kjøtt med bein',
    '🍗' => 'kyllinglår',
    '🥩' => 'kjøttstykke',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'pommes frites',
    '🍕' => 'pizzastykke',
    '🌭' => 'pølse med brød',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'fylt pitabrød',
    '🧆' => 'falafel',
    '🥚' => 'egg',
    '🍳' => 'matlaging',
    '🥘' => 'lav gryte med mat',
    '🍲' => 'gryterett',
    '🫕' => 'fondy',
    '🥣' => 'bolle med skje',
    '🥗' => 'grønn salat',
    '🍿' => 'popkorn',
    '🧈' => 'smør',
    '🧂' => 'salt',
    '🥫' => 'hermetikk',
    '🍱' => 'bento-boks',
    '🍘' => 'riskjeks',
    '🍙' => 'risball',
    '🍚' => 'kokt ris',
    '🍛' => 'karriris',
    '🍜' => 'matbolle som damper',
    '🍝' => 'spagetti',
    '🍠' => 'bakt søtpotet',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'fritert reke',
    '🍥' => 'fiskekake med mønster',
    '🥮' => 'månekake',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'lykkekake',
    '🥡' => 'takeaway-eske',
    '🍦' => 'soft-is',
    '🍧' => 'slush-is',
    '🍨' => 'iskrem',
    '🍩' => 'donut',
    '🍪' => 'kjeks',
    '🎂' => 'bursdagskake',
    '🍰' => 'kakestykke',
    '🧁' => 'cupcake',
    '🥧' => 'pai',
    '🍫' => 'sjokoladeplate',
    '🍬' => 'godteri',
    '🍭' => 'kjærlighet på pinne',
    '🍮' => 'pudding',
    '🍯' => 'honningkrukke',
    '🍼' => 'tåteflaske',
    '🥛' => 'melkeglass',
    '☕' => 'varm drikke',
    '🫖' => 'tekanne',
    '🍵' => 'tekopp',
    '🍶' => 'sake',
    '🍾' => 'flaske med sprettkork',
    '🍷' => 'vinglass',
    '🍸' => 'cocktailglass',
    '🍹' => 'tropisk drink',
    '🍺' => 'ølkrus',
    '🍻' => 'ølkrus som skåler',
    '🥂' => 'glass som skåler',
    '🥃' => 'whiskyglass',
    '🫗' => 'helle væske',
    '🥤' => 'kopp med sugerør',
    '🧋' => 'boble-te',
    '🧃' => 'drikkekartong',
    '🧉' => 'mate',
    '🧊' => 'isterning',
    '🥢' => 'spisepinner',
    '🍽' => 'tallerken med kniv og gaffel',
    '🍴' => 'kniv og gaffel',
    '🥄' => 'skje',
    '🔪' => 'kokkekniv',
    '🫙' => 'krukke',
    '🏺' => 'amfora',
    '🌍' => 'jordklode med Europa og Afrika',
    '🌎' => 'jordklode med Amerika',
    '🌏' => 'jordklode med Asia og Australia',
    '🌐' => 'jordklode med meridianer',
    '🗺' => 'verdenskart',
    '🗾' => 'kart over Japan',
    '🧭' => 'kompass',
    '🏔' => 'snødekt fjell',
    '⛰' => 'fjell',
    '🛘' => 'jordskred',
    '🌋' => 'vulkan',
    '🗻' => 'Fuji-fjellet',
    '🏕' => 'telttur',
    '🏖' => 'strand med parasoll',
    '🏜' => 'ørken',
    '🏝' => 'øde øy',
    '🏞' => 'nasjonalpark',
    '🏟' => 'stadion',
    '🏛' => 'klassisk bygning',
    '🏗' => 'bygning under konstruksjon',
    '🧱' => 'murstein',
    '🪨' => 'stein',
    '🪵' => 'tre',
    '🛖' => 'hytte',
    '🏘' => 'boliger',
    '🏚' => 'falleferdig hus',
    '🏠' => 'hus',
    '🏡' => 'hus med hage',
    '🏢' => 'kontorbygg',
    '🏣' => 'japansk postkontor',
    '🏤' => 'postkontor',
    '🏥' => 'sykehus',
    '🏦' => 'bank',
    '🏨' => 'hotell',
    '🏩' => 'kjærlighetshotell',
    '🏪' => 'dagligvarebutikk',
    '🏫' => 'skole',
    '🏬' => 'kjøpesenter',
    '🏭' => 'fabrikk',
    '🏯' => 'japansk slott',
    '🏰' => 'slott',
    '💒' => 'bryllup',
    '🗼' => 'Tokyo-tårnet',
    '🗽' => 'Frihetsgudinnen',
    '⛪' => 'kirke',
    '🕌' => 'moské',
    '🛕' => 'hindutempel',
    '🕍' => 'synagoge',
    '⛩' => 'Shinto-alter',
    '🕋' => 'Kaba',
    '⛲' => 'fontene',
    '⛺' => 'telt',
    '🌁' => 'tåkete',
    '🌃' => 'stjernenatt',
    '🏙' => 'bylandskap',
    '🌄' => 'soloppgang over fjell',
    '🌅' => 'soloppgang',
    '🌆' => 'bylandskap i skumring',
    '🌇' => 'solnedgang',
    '🌉' => 'bro om natten',
    '♨' => 'varme kilder',
    '🎠' => 'karusellhest',
    '🛝' => 'sklie',
    '🎡' => 'pariserhjul',
    '🎢' => 'berg-og-dal-bane',
    '💈' => 'barberskilt',
    '🎪' => 'sirkustelt',
    '🚂' => 'lokomotiv',
    '🚃' => 'togvogn',
    '🚄' => 'høyhastighetstog',
    '🚅' => 'høyhastighetstog med kulenese',
    '🚆' => 'tog',
    '🚇' => 'tunnelbane',
    '🚈' => 'lokaltog',
    '🚉' => 'togstasjon',
    '🚊' => 'trikk',
    '🚝' => 'monorail',
    '🚞' => 'fjellbane',
    '🚋' => 'trikkevogn',
    '🚌' => 'buss',
    '🚍' => 'motgående buss',
    '🚎' => 'trolleybuss',
    '🚐' => 'minibuss',
    '🚑' => 'ambulanse',
    '🚒' => 'brannbil',
    '🚓' => 'politibil',
    '🚔' => 'motgående politibil',
    '🚕' => 'taxi',
    '🚖' => 'motgående taxi',
    '🚗' => 'bil',
    '🚘' => 'motgående bil',
    '🚙' => 'SUV',
    '🛻' => 'pickup',
    '🚚' => 'varebil',
    '🚛' => 'lastebil',
    '🚜' => 'traktor',
    '🏎' => 'racerbil',
    '🏍' => 'motorsykkel',
    '🛵' => 'scooter',
    '🦽' => 'manuell rullestol',
    '🦼' => 'motorisert rullestol',
    '🛺' => 'autorickshaw',
    '🚲' => 'sykkel',
    '🛴' => 'sparkesykkel',
    '🛹' => 'skateboard',
    '🛼' => 'rulleskøyter',
    '🚏' => 'busstopp',
    '🛣' => 'motorvei',
    '🛤' => 'jernbanespor',
    '🛢' => 'oljefat',
    '⛽' => 'bensinpumpe',
    '🛞' => 'hjul',
    '🚨' => 'politilys',
    '🚥' => 'horisontale trafikklys',
    '🚦' => 'vertikale trafiklys',
    '🛑' => 'stoppskilt',
    '🚧' => 'anleggsarbeid',
    '⚓' => 'anker',
    '🛟' => 'livbøye',
    '⛵' => 'seilbåt',
    '🛶' => 'kano',
    '🚤' => 'speedbåt',
    '🛳' => 'passasjerskip',
    '⛴' => 'ferge',
    '🛥' => 'motorbåt',
    '🚢' => 'skip',
    '✈' => 'fly',
    '🛩' => 'lite fly',
    '🛫' => 'fly som tar av',
    '🛬' => 'fly som lander',
    '🪂' => 'fallskjerm',
    '💺' => 'sete',
    '🚁' => 'helikopter',
    '🚟' => 'svevebane',
    '🚠' => 'kabelbane',
    '🚡' => 'taubane',
    '🛰' => 'satellitt',
    '🚀' => 'rakett',
    '🛸' => 'flygende tallerken',
    '🛎' => 'resepsjonsklokke',
    '🧳' => 'bagasje',
    '⌛' => 'ferdig timeglass',
    '⏳' => 'startet timeglass',
    '⌚' => 'armbåndsur',
    '⏰' => 'vekkerklokke',
    '⏱' => 'stoppeklokke',
    '⏲' => 'tidtaker',
    '🕰' => 'peisur',
    '🕛' => 'klokken tolv',
    '🕧' => 'klokken halv ett',
    '🕐' => 'klokken ett',
    '🕜' => 'klokken halv to',
    '🕑' => 'klokken to',
    '🕝' => 'klokken halv tre',
    '🕒' => 'klokken tre',
    '🕞' => 'klokken halv fire',
    '🕓' => 'klokken fire',
    '🕟' => 'klokken halv fem',
    '🕔' => 'klokken fem',
    '🕠' => 'klokken halv seks',
    '🕕' => 'klokken seks',
    '🕡' => 'klokken halv sju',
    '🕖' => 'klokken sju',
    '🕢' => 'klokken halv åtte',
    '🕗' => 'klokken åtte',
    '🕣' => 'klokken halv ni',
    '🕘' => 'klokken ni',
    '🕤' => 'klokken halv ti',
    '🕙' => 'klokken ti',
    '🕥' => 'klokken halv elleve',
    '🕚' => 'klokken elleve',
    '🕦' => 'klokken halv tolv',
    '🌑' => 'nymåne',
    '🌒' => 'voksende nymåne',
    '🌓' => 'voksende halvmåne',
    '🌔' => 'voksende fullmåne',
    '🌕' => 'fullmåne',
    '🌖' => 'avtakende fullmåne',
    '🌗' => 'avtakende halvmåne',
    '🌘' => 'avtakende nemåne',
    '🌙' => 'månesigd',
    '🌚' => 'nymåneansikt',
    '🌛' => 'nymåne med ansikt',
    '🌜' => 'nemåne med ansikt',
    '🌡' => 'termometer',
    '☀' => 'sol',
    '🌝' => 'fullmåneansikt',
    '🌞' => 'solansikt',
    '🪐' => 'planet med ringer',
    '⭐' => 'stjerne',
    '🌟' => 'lysende stjerne',
    '🌠' => 'stjerneskudd',
    '🌌' => 'melkeveien',
    '☁' => 'sky',
    '⛅' => 'sol bak sky',
    '⛈' => 'sky med lyn og regn',
    '🌤' => 'sol bak liten sky',
    '🌥' => 'sol bak stor sky',
    '🌦' => 'sol bak sky med regn',
    '🌧' => 'sky med regn',
    '🌨' => 'sky med snø',
    '🌩' => 'sky med lyn',
    '🌪' => 'tornado',
    '🌫' => 'tåke',
    '🌬' => 'vindansikt',
    '🌀' => 'syklon',
    '🌈' => 'regnbue',
    '🌂' => 'lukket paraply',
    '☂' => 'paraply',
    '☔' => 'paraply med regndråper',
    '⛱' => 'parasoll på bakken',
    '⚡' => 'høyspenning',
    '❄' => 'snøfnugg',
    '☃' => 'snømann',
    '⛄' => 'snømann uten snø',
    '☄' => 'komet',
    '🔥' => 'ild',
    '💧' => 'dråpe',
    '🌊' => 'bølge',
    '🎃' => 'gresskarlykt',
    '🎄' => 'juletre',
    '🎆' => 'fyrverkeri',
    '🎇' => 'stjerneskudd på pinne',
    '🧨' => 'kinaputt',
    '✨' => 'stjerner',
    '🎈' => 'ballong',
    '🎉' => 'smell-bon-bon',
    '🎊' => 'konfettiball',
    '🎋' => 'tanabatatre',
    '🎍' => 'furudekorasjon',
    '🎎' => 'japanske dukker',
    '🎏' => 'koinobori',
    '🎐' => 'vindspill',
    '🎑' => 'månebeskuelsesseremoni',
    '🧧' => 'rød konvolutt',
    '🎀' => 'sløyfe',
    '🎁' => 'gave',
    '🎗' => 'minnesløyfe',
    '🎟' => 'inngangsbilletter',
    '🎫' => 'billett',
    '🎖' => 'militærmedalje',
    '🏆' => 'trofé',
    '🏅' => 'idrettsmedalje',
    '🥇' => 'gullmedalje',
    '🥈' => 'sølvmedalje',
    '🥉' => 'bronsemedalje',
    '⚽' => 'fotball',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'basketball',
    '🏐' => 'volleyball',
    '🏈' => 'amerikansk fotball',
    '🏉' => 'rugby',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'landhockey',
    '🏒' => 'ishockey',
    '🥍' => 'lacrosse',
    '🏓' => 'bordtennis',
    '🏸' => 'badminton',
    '🥊' => 'boksehanske',
    '🥋' => 'kampsportdrakt',
    '🥅' => 'målnett',
    '⛳' => 'golfflagg',
    '⛸' => 'skøyter',
    '🎣' => 'fiskestang',
    '🤿' => 'dykkermaske',
    '🎽' => 'treningstrøye',
    '🎿' => 'ski',
    '🛷' => 'kjelke',
    '🥌' => 'curlingstein',
    '🎯' => 'blink',
    '🪀' => 'jojo',
    '🪁' => 'papirdrage',
    '🔫' => 'vannpistol',
    '🎱' => 'biljard',
    '🔮' => 'krystallkule',
    '🪄' => 'tryllestav',
    '🎮' => 'videospill',
    '🕹' => 'joystick',
    '🎰' => 'spilleautomat',
    '🎲' => 'terning',
    '🧩' => 'puslespillbrikke',
    '🧸' => 'teddybjørn',
    '🪅' => 'piñata',
    '🪩' => 'speilkule',
    '🪆' => 'matrjosjka',
    '♠' => 'spar',
    '♥' => 'hjerter',
    '♦' => 'ruter',
    '♣' => 'kløver',
    '♟' => 'bonde',
    '🃏' => 'joker',
    '🀄' => 'mahjongbrikke med rød drage',
    '🎴' => 'spillkort',
    '🎭' => 'teatermasker',
    '🖼' => 'innrammet bilde',
    '🎨' => 'malerpalett',
    '🧵' => 'tråd',
    '🪡' => 'synål',
    '🧶' => 'garn',
    '🪢' => 'knute',
    '👓' => 'briller',
    '🕶' => 'solbriller',
    '🥽' => 'beskyttelsesbriller',
    '🥼' => 'labfrakk',
    '🦺' => 'refleksvest',
    '👔' => 'slips',
    '👕' => 't-skjorte',
    '👖' => 'bukser',
    '🧣' => 'skjerf',
    '🧤' => 'hansker',
    '🧥' => 'jakke',
    '🧦' => 'sokker',
    '👗' => 'kjole',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'badedrakt',
    '🩲' => 'truse',
    '🩳' => 'shorts',
    '👙' => 'bikini',
    '👚' => 'dameklær',
    '🪭' => 'håndvifte',
    '👛' => 'portemoné',
    '👜' => 'håndveske',
    '👝' => 'clutch-veske',
    '🛍' => 'handleposer',
    '🎒' => 'skolesekk',
    '🩴' => 'flippflopp',
    '👞' => 'herresko',
    '👟' => 'joggesko',
    '🥾' => 'turstøvel',
    '🥿' => 'pumps',
    '👠' => 'høyhælt sko',
    '👡' => 'damesandal',
    '🩰' => 'ballettsko',
    '👢' => 'damestøvlett',
    '🪮' => 'afrokam',
    '👑' => 'krone',
    '👒' => 'damehatt',
    '🎩' => 'flosshatt',
    '🎓' => 'studentlue',
    '🧢' => 'caps',
    '🪖' => 'militærhjelm',
    '⛑' => 'hjelm med hvitt kors',
    '📿' => 'bønnekrans',
    '💄' => 'leppestift',
    '💍' => 'ring',
    '💎' => 'diamant',
    '🔇' => 'dempet høyttaler',
    '🔈' => 'høyttaler med lavt volum',
    '🔉' => 'høyttaler med middels volum',
    '🔊' => 'høyttaler med høyt volum',
    '📢' => 'høyttaler',
    '📣' => 'megafon',
    '📯' => 'posthorn',
    '🔔' => 'bjelle',
    '🔕' => 'overstreket bjelle',
    '🎼' => 'musikk',
    '🎵' => 'note',
    '🎶' => 'noter',
    '🎙' => 'studiomikrofon',
    '🎚' => 'glidebryter',
    '🎛' => 'kontrollbrytere',
    '🎤' => 'mikrofon',
    '🎧' => 'hodetelefoner',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'trompet',
    '🪊' => 'trombone',
    '🪗' => 'trekkspill',
    '🎸' => 'gitar',
    '🎹' => 'piano',
    '🎻' => 'fiolin',
    '🪕' => 'banjo',
    '🥁' => 'tromme',
    '🪘' => 'langtromme',
    '🪇' => 'marakas',
    '🪈' => 'fløyte',
    '🪉' => 'harpe',
    '📱' => 'mobiltelefon',
    '📲' => 'mobiltelefon med pil',
    '☎' => 'telefon',
    '📞' => 'telefonrør',
    '📟' => 'personsøker',
    '📠' => 'faksmaskin',
    '🔋' => 'batteri',
    '🪫' => 'lite batteri',
    '🔌' => 'støpsel',
    '💻' => 'bærbar datamaskin',
    '🖥' => 'stasjonær datamaskin',
    '🖨' => 'skriver',
    '⌨' => 'tastatur',
    '🖱' => 'datamus',
    '🖲' => 'styrekule',
    '💽' => 'datadisk',
    '💾' => 'diskett',
    '💿' => 'optisk plate',
    '📀' => 'DVD',
    '🧮' => 'kuleramme',
    '🎥' => 'filmkamera',
    '🎞' => 'filmruter',
    '📽' => 'filmfremviser',
    '🎬' => 'filmklapper',
    '📺' => 'TV',
    '📷' => 'kamera',
    '📸' => 'kamera med blits',
    '📹' => 'videokamera',
    '📼' => 'videokassett',
    '🔍' => 'forstørrelsesglass mot venstre',
    '🔎' => 'forstørrelsesglass mot høyre',
    '🕯' => 'stearinlys',
    '💡' => 'lyspære',
    '🔦' => 'lommelykt',
    '🏮' => 'rød papirlykt',
    '🪔' => 'åpen oljelampe',
    '📔' => 'dekorert notatbok',
    '📕' => 'lukket bok',
    '📖' => 'åpen bok',
    '📗' => 'grønn bok',
    '📘' => 'blå bok',
    '📙' => 'oransje bok',
    '📚' => 'bøker',
    '📓' => 'notatbok',
    '📒' => 'spiralblokk',
    '📃' => 'side med bøy',
    '📜' => 'pergamentrull',
    '📄' => 'side som vender opp',
    '📰' => 'avis',
    '🗞' => 'sammenrullet avis',
    '📑' => 'bokmerkefane',
    '🔖' => 'bokmerke',
    '🏷' => 'etikett',
    '🪙' => 'mynt',
    '💰' => 'pengesekk',
    '🪎' => 'skattkiste',
    '💴' => 'yenseddel',
    '💵' => 'dollarseddel',
    '💶' => 'euroseddel',
    '💷' => 'pundseddel',
    '💸' => 'penger med vinger',
    '💳' => 'kredittkort',
    '🧾' => 'kvittering',
    '💹' => 'stigende diagram med yen',
    '✉' => 'konvolutt',
    '📧' => 'e-post',
    '📨' => 'innkommende konvolutt',
    '📩' => 'konvolutt med pil',
    '📤' => 'utboks',
    '📥' => 'innboks',
    '📦' => 'pakke',
    '📫' => 'lukket postkasse med flagget oppe',
    '📪' => 'lukket postkasse med flagget nede',
    '📬' => 'åpen postkasse med flagget oppe',
    '📭' => 'åpen postkasse med flagget nede',
    '📮' => 'postkasse',
    '🗳' => 'urne med stemmeseddel',
    '✏' => 'blyant',
    '✒' => 'svart pennesplitt',
    '🖋' => 'fyllepenn',
    '🖊' => 'penn',
    '🖌' => 'pensel',
    '🖍' => 'fargestift',
    '📝' => 'notat',
    '💼' => 'dokumentmappe',
    '📁' => 'arkivmappe',
    '📂' => 'åpen arkivmappe',
    '🗂' => 'skillekort',
    '📅' => 'kalender',
    '📆' => 'veggkalender',
    '🗒' => 'spiralhefte',
    '🗓' => 'spiralkalender',
    '📇' => 'kartotek',
    '📈' => 'diagram som peker oppover',
    '📉' => 'diagram som peker nedover',
    '📊' => 'stolpediagram',
    '📋' => 'skriveplate',
    '📌' => 'stift',
    '📍' => 'rund stift',
    '📎' => 'binders',
    '🖇' => 'sammenlenkede binders',
    '📏' => 'linjal',
    '📐' => 'trekantlinjal',
    '✂' => 'saks',
    '🗃' => 'kartotekboks',
    '🗄' => 'arkivskap',
    '🗑' => 'papirkurv',
    '🔒' => 'låst',
    '🔓' => 'ulåst',
    '🔏' => 'låst med penn',
    '🔐' => 'låst med nøkkel',
    '🔑' => 'nøkkel',
    '🗝' => 'gammeldags nøkkel',
    '🔨' => 'hammer',
    '🪓' => 'øks',
    '⛏' => 'hakke',
    '⚒' => 'hammer og hakke',
    '🛠' => 'hammer og fastnøkkel',
    '🗡' => 'dolk',
    '⚔' => 'sverd i kryss',
    '💣' => 'bombe',
    '🪃' => 'bumerang',
    '🏹' => 'pil og bue',
    '🛡' => 'skjold',
    '🪚' => 'håndsag',
    '🔧' => 'fastnøkkel',
    '🪛' => 'skrutrekker',
    '🔩' => 'mutter og skrue',
    '⚙' => 'tannhjul',
    '🗜' => 'skrutvinge',
    '⚖' => 'likearmet skålvekt',
    '🦯' => 'blindestokk',
    '🔗' => 'lenke',
    '⛓' => 'kjetting',
    '🪝' => 'krok',
    '🧰' => 'verktøykasse',
    '🧲' => 'magnet',
    '🪜' => 'stige',
    '🪏' => 'spade',
    '⚗' => 'destillerkolbe',
    '🧪' => 'prøverør',
    '🧫' => 'petriskål',
    '🧬' => 'dna',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'satellittantenne',
    '💉' => 'sprøyte',
    '🩸' => 'bloddråpe',
    '💊' => 'pille',
    '🩹' => 'plaster',
    '🩼' => 'krykke',
    '🩺' => 'stetoskop',
    '🩻' => 'røntgen',
    '🚪' => 'dør',
    '🛗' => 'heis',
    '🪞' => 'speil',
    '🪟' => 'vindu',
    '🛏' => 'seng',
    '🛋' => 'sofa og lampe',
    '🪑' => 'stol',
    '🚽' => 'toalett',
    '🪠' => 'avløpsåpner',
    '🚿' => 'dusj',
    '🛁' => 'badekar',
    '🪤' => 'musefelle',
    '🪒' => 'barberkniv',
    '🧴' => 'lotionflaske',
    '🧷' => 'sikkerhetsnål',
    '🧹' => 'feiekost',
    '🧺' => 'kurv',
    '🧻' => 'rull med papir',
    '🪣' => 'bøtte',
    '🧼' => 'såpe',
    '🫧' => 'bobler',
    '🪥' => 'tannbørste',
    '🧽' => 'svamp',
    '🧯' => 'brannslukningsapparat',
    '🛒' => 'handlevogn',
    '🚬' => 'sigarett',
    '⚰' => 'kiste',
    '🪦' => 'gravstein',
    '⚱' => 'urne',
    '🧿' => 'nazar',
    '🪬' => 'hamsa',
    '🗿' => 'moai-statue',
    '🪧' => 'plakat',
    '🪪' => 'ID-kort',
    '🏧' => 'minibankskilt',
    '🚮' => 'avfallsskilt',
    '🚰' => 'drikkevann',
    '♿' => 'rullestolsymbol',
    '🚹' => 'herretoalett',
    '🚺' => 'dametoalett',
    '🚻' => 'toalettskilt',
    '🚼' => 'babysymbol',
    '🚾' => 'do',
    '🛂' => 'passkontroll',
    '🛃' => 'toll',
    '🛄' => 'bagasjebånd',
    '🛅' => 'bagasjeoppbevaring',
    '⚠' => 'advarsel',
    '🚸' => 'barn krysser veien',
    '⛔' => 'ingen adgang',
    '🚫' => 'forbudt',
    '🚳' => 'sykler forbudt',
    '🚭' => 'røyking forbudt',
    '🚯' => 'forsøpling ikke tillatt',
    '🚱' => 'ikke drikkevann',
    '🚷' => 'fotgjengere forbudt',
    '📵' => 'mobiltelefon ikke tillatt',
    '🔞' => 'aldersgrense 18 år',
    '☢' => 'radioaktivt',
    '☣' => 'farlig biologisk materiale',
    '⬆' => 'pil opp',
    '↗' => 'pil opp-høyre',
    '➡' => 'pil høyre',
    '↘' => 'pil ned-høyre',
    '⬇' => 'pil ned',
    '↙' => 'pil ned-venstre',
    '⬅' => 'pil venstre',
    '↖' => 'pil opp-venstre',
    '↕' => 'pil opp og ned',
    '↔' => 'pil venstre-høyre',
    '↩' => 'pil som bøyer mot venstre',
    '↪' => 'pil som bøyer mot høyre',
    '⤴' => 'pil som bøyer opp',
    '⤵' => 'pil som bøyer ned',
    '🔃' => 'vertikale piler med klokken',
    '🔄' => 'piler mot klokken',
    '🔙' => 'BACK-pil',
    '🔚' => 'END-pil',
    '🔛' => 'ON!-pil',
    '🔜' => 'SOON-pil',
    '🔝' => 'TOP-pil',
    '🛐' => 'religiøst samlingssted',
    '⚛' => 'atomsymbol',
    '🕉' => 'om',
    '✡' => 'Davidstjerne',
    '☸' => 'dharmas hjul',
    '☯' => 'yin yang',
    '✝' => 'latinsk kors',
    '☦' => 'ortodokst kors',
    '☪' => 'stjerne og halvmåne',
    '☮' => 'fredssymbol',
    '🕎' => 'menora',
    '🔯' => 'sekstagget stjerne med prikk',
    '🪯' => 'khanda',
    '♈' => 'Væren',
    '♉' => 'Tyren',
    '♊' => 'Tvillingene',
    '♋' => 'Krepsen',
    '♌' => 'Løven',
    '♍' => 'Jomfruen',
    '♎' => 'Vekten',
    '♏' => 'Skorpionen',
    '♐' => 'Skytten',
    '♑' => 'Steinbukken',
    '♒' => 'Vannmannen',
    '♓' => 'Fiskene',
    '⛎' => 'Slangebæreren',
    '🔀' => 'bland spor-symbol',
    '🔁' => 'gjenta-knapp',
    '🔂' => 'gjenta ett spor-knapp',
    '▶' => 'avspillingsknapp',
    '⏩' => 'spol framover-knapp',
    '⏭' => 'neste spor-knapp',
    '⏯' => 'spill av/pause-knapp',
    '◀' => 'bakover-knapp',
    '⏪' => 'spol tilbake-knapp',
    '⏮' => 'forrige spor-knapp',
    '🔼' => 'oppover-knapp',
    '⏫' => 'raskt opp-knapp',
    '🔽' => 'nedover-knapp',
    '⏬' => 'raskt ned-knapp',
    '⏸' => 'pause-knapp',
    '⏹' => 'stopp-knapp',
    '⏺' => 'spill inn-knapp',
    '⏏' => 'mat ut-knapp',
    '🎦' => 'kino',
    '🔅' => 'lite lys-knapp',
    '🔆' => 'mye lys-knapp',
    '📶' => 'mobilsignaler',
    '🛜' => 'trådløst',
    '📳' => 'vibreringsmodus',
    '📴' => 'mobiltelefon av',
    '♀' => 'kvinnesymbol',
    '♂' => 'mannssymbol',
    '⚧' => 'transperson-symbol',
    '✖' => 'gange',
    '➕' => 'pluss',
    '➖' => 'minus',
    '➗' => 'dele',
    '🟰' => 'likhetstegn i fet skrift',
    '♾' => 'uendelig',
    '‼' => 'dobbelt utropstegn',
    '⁉' => 'utropstegn og spørsmålstegn',
    '❓' => 'rødt spørsmålstegn',
    '❔' => 'hvitt spørsmålstegn',
    '❕' => 'hvitt utropstegn',
    '❗' => 'rødt utropstegn',
    '〰' => 'bølgestrek',
    '💱' => 'valutaveksling',
    '💲' => 'dollartegn',
    '⚕' => 'legesymbol',
    '♻' => 'resirkuleringssymbol',
    '⚜' => 'fransk lilje',
    '🔱' => 'treforkemblem',
    '📛' => 'navneskilt',
    '🔰' => 'japansk tegn for nybegynner',
    '⭕' => 'tykk rød sirkel',
    '✅' => 'hakemerke i firkant',
    '☑' => 'boks med hakemerke',
    '✔' => 'hakemerke',
    '❌' => 'kryss',
    '❎' => 'kryss i firkant',
    '➰' => 'løkke',
    '➿' => 'dobbel løkke',
    '〽' => 'merke for nytt parti',
    '✳' => 'asterisk med åtte spisser',
    '✴' => 'åttetagget stjerne',
    '❇' => 'gnist',
    '™' => 'varemerke',
    '🫟' => 'sprut',
    '🔠' => 'store bokstaver',
    '🔡' => 'små bokstaver',
    '🔢' => 'tall',
    '🔣' => 'symboler',
    '🔤' => 'latinsk alfabet',
    '🅰' => 'A-knapp (blodtype)',
    '🆎' => 'AB-knapp (blodtype)',
    '🅱' => 'B-knapp (blodtype)',
    '🆑' => 'CL-knapp',
    '🆒' => 'COOL-knapp',
    '🆓' => 'FREE-knapp',
    'ℹ' => 'informasjon',
    '🆔' => 'ID-knapp',
    'Ⓜ' => 'M med ring rundt',
    '🆕' => 'NEW-knapp',
    '🆖' => 'NG-knapp',
    '🅾' => 'O-knapp (blodtype)',
    '🆗' => 'OK-knapp',
    '🅿' => 'P-knapp',
    '🆘' => 'SOS-knapp',
    '🆙' => 'UP!-knapp',
    '🆚' => 'VS-knapp',
    '🈁' => '«her» på japansk',
    '🈂' => '«gebyr» på japansk',
    '🈷' => '«månedlig beløp» på japansk',
    '🈶' => '«ikke gratis» på japansk',
    '🈯' => '«reservert» på japansk',
    '🉐' => '«spesialtilbud» på japansk',
    '🈹' => '«rabatt» på japansk',
    '🈚' => '«gratis» på japansk',
    '🈲' => '«forbudt» på japansk',
    '🉑' => '«akseptabelt» på japansk',
    '🈸' => '«søknad» på japansk',
    '🈴' => '«bestått» på japansk',
    '🈳' => '«ledig» på japansk',
    '㊗' => '«gratulerer» på japansk',
    '㊙' => '«hemmelig» på japansk',
    '🈺' => '«åpen for handel» på japansk',
    '🈵' => '«fullt» på japansk',
    '🔴' => 'rød sirkel',
    '🟠' => 'oransje sirkel',
    '🟡' => 'gul sirkel',
    '🟢' => 'grønn sirkel',
    '🔵' => 'blå sirkel',
    '🟣' => 'lilla sirkel',
    '🟤' => 'brun sirkel',
    '⚫' => 'svart sirkel',
    '⚪' => 'hvit sirkel',
    '🟥' => 'rødt kvadrat',
    '🟧' => 'oransje kvadrat',
    '🟨' => 'gult kvadrat',
    '🟩' => 'grønt kvadrat',
    '🟦' => 'blått kvadrat',
    '🟪' => 'lilla kvadrat',
    '🟫' => 'brunt kvadrat',
    '⬛' => 'stort svart kvadrat',
    '⬜' => 'stort hvitt kvadrat',
    '◼' => 'mellomstort svart kvadrat',
    '◻' => 'mellomstort hvitt kvadrat',
    '◾' => 'lite/mellomstort svart kvadrat',
    '◽' => 'lite/mellomstort hvitt kvadrat',
    '▪' => 'lite, svart kvadrat',
    '▫' => 'lite, hvitt kvadrat',
    '🔶' => 'stort oransje rutersymbol',
    '🔷' => 'stort blått rutersymbol',
    '🔸' => 'lite oransje rutersymbol',
    '🔹' => 'lite blått rutersymbol',
    '🔺' => 'rød trekant som peker opp',
    '🔻' => 'rød trekant som peker ned',
    '💠' => 'diamant med prikk',
    '🔘' => 'radioknapp',
    '🔳' => 'hvit firkantet knapp',
    '🔲' => 'svart firkantet knapp',
    '🏁' => 'rutete flagg',
    '🚩' => 'vimpel',
    '🎌' => 'kryssede flagg',
    '🏴' => 'svart flagg',
    '🏳' => 'hvitt flagg',
];
